@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2013 the original author or authors.
+ * Copyright 2002-2016 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -58,7 +58,6 @@ import org.springframework.util.CollectionUtils;
  * @author Juergen Hoeller
  * @see org.springframework.aop.framework.AopProxy
  */
-@SuppressWarnings("unchecked")
 public class AdvisedSupport extends ProxyConfig implements Advised {
 
 	/** use serialVersionUID from Spring 2.0 for interoperability */
@@ -88,7 +87,7 @@ public class AdvisedSupport extends ProxyConfig implements Advised {
 	 * Interfaces to be implemented by the proxy. Held in List to keep the order
 	 * of registration, to create JDK proxy with specified order of interfaces.
 	 */
-	private List<Class> interfaces = new ArrayList<Class>();
+	private List<Class<?>> interfaces = new ArrayList<Class<?>>();
 
 	/**
 	 * List of Advisors. If an Advice is added, it will be wrapped
@@ -114,7 +113,7 @@ public class AdvisedSupport extends ProxyConfig implements Advised {
 	 * Create a AdvisedSupport instance with the given parameters.
 	 * @param interfaces the proxied interfaces
 	 */
-	public AdvisedSupport(Class[] interfaces) {
+	public AdvisedSupport(Class<?>... interfaces) {
 		this();
 		setInterfaces(interfaces);
 	}
@@ -137,10 +136,12 @@ public class AdvisedSupport extends ProxyConfig implements Advised {
 		setTargetSource(new SingletonTargetSource(target));
 	}
 
+	@Override
 	public void setTargetSource(TargetSource targetSource) {
 		this.targetSource = (targetSource != null ? targetSource : EMPTY_TARGET_SOURCE);
 	}
 
+	@Override
 	public TargetSource getTargetSource() {
 		return this.targetSource;
 	}
@@ -162,14 +163,17 @@ public class AdvisedSupport extends ProxyConfig implements Advised {
 		this.targetSource = EmptyTargetSource.forClass(targetClass);
 	}
 
+	@Override
 	public Class<?> getTargetClass() {
 		return this.targetSource.getTargetClass();
 	}
 
+	@Override
 	public void setPreFiltered(boolean preFiltered) {
 		this.preFiltered = preFiltered;
 	}
 
+	@Override
 	public boolean isPreFiltered() {
 		return this.preFiltered;
 	}
@@ -197,7 +201,7 @@ public class AdvisedSupport extends ProxyConfig implements Advised {
 	public void setInterfaces(Class<?>... interfaces) {
 		Assert.notNull(interfaces, "Interfaces must not be null");
 		this.interfaces.clear();
-		for (Class ifc : interfaces) {
+		for (Class<?> ifc : interfaces) {
 			addInterface(ifc);
 		}
 	}
@@ -228,12 +232,14 @@ public class AdvisedSupport extends ProxyConfig implements Advised {
 		return this.interfaces.remove(intf);
 	}
 
+	@Override
 	public Class<?>[] getProxiedInterfaces() {
-		return this.interfaces.toArray(new Class[this.interfaces.size()]);
+		return this.interfaces.toArray(new Class<?>[this.interfaces.size()]);
 	}
 
+	@Override
 	public boolean isInterfaceProxied(Class<?> intf) {
-		for (Class proxyIntf : this.interfaces) {
+		for (Class<?> proxyIntf : this.interfaces) {
 			if (intf.isAssignableFrom(proxyIntf)) {
 				return true;
 			}
@@ -242,15 +248,18 @@ public class AdvisedSupport extends ProxyConfig implements Advised {
 	}
 
 
+	@Override
 	public final Advisor[] getAdvisors() {
 		return this.advisorArray;
 	}
 
+	@Override
 	public void addAdvisor(Advisor advisor) {
 		int pos = this.advisors.size();
 		addAdvisor(pos, advisor);
 	}
 
+	@Override
 	public void addAdvisor(int pos, Advisor advisor) throws AopConfigException {
 		if (advisor instanceof IntroductionAdvisor) {
 			validateIntroductionAdvisor((IntroductionAdvisor) advisor);
@@ -258,6 +267,7 @@ public class AdvisedSupport extends ProxyConfig implements Advised {
 		addAdvisorInternal(pos, advisor);
 	}
 
+	@Override
 	public boolean removeAdvisor(Advisor advisor) {
 		int index = indexOf(advisor);
 		if (index == -1) {
@@ -269,6 +279,7 @@ public class AdvisedSupport extends ProxyConfig implements Advised {
 		}
 	}
 
+	@Override
 	public void removeAdvisor(int index) throws AopConfigException {
 		if (isFrozen()) {
 			throw new AopConfigException("Cannot remove Advisor: Configuration is frozen.");
@@ -292,11 +303,13 @@ public class AdvisedSupport extends ProxyConfig implements Advised {
 		adviceChanged();
 	}
 
+	@Override
 	public int indexOf(Advisor advisor) {
 		Assert.notNull(advisor, "Advisor must not be null");
 		return this.advisors.indexOf(advisor);
 	}
 
+	@Override
 	public boolean replaceAdvisor(Advisor a, Advisor b) throws AopConfigException {
 		Assert.notNull(a, "Advisor a must not be null");
 		Assert.notNull(b, "Advisor b must not be null");
@@ -309,16 +322,6 @@ public class AdvisedSupport extends ProxyConfig implements Advised {
 		return true;
 	}
 
-	/**
-	 * Add all of the given advisors to this proxy configuration.
-	 * @param advisors the advisors to register
-	 * @deprecated as of Spring 3.0, in favor of {@link #addAdvisors}
-	 */
-	@Deprecated
-	public void addAllAdvisors(Advisor[] advisors) {
-		addAdvisors(Arrays.asList(advisors));
-	}
-
 	/**
 	 * Add all of the given advisors to this proxy configuration.
 	 * @param advisors the advisors to register
@@ -351,8 +354,8 @@ public class AdvisedSupport extends ProxyConfig implements Advised {
 	private void validateIntroductionAdvisor(IntroductionAdvisor advisor) {
 		advisor.validateInterfaces();
 		// If the advisor passed validation, we can make the change.
-		Class[] ifcs = advisor.getInterfaces();
-		for (Class ifc : ifcs) {
+		Class<?>[] ifcs = advisor.getInterfaces();
+		for (Class<?> ifc : ifcs) {
 			addInterface(ifc);
 		}
 	}
@@ -388,6 +391,7 @@ public class AdvisedSupport extends ProxyConfig implements Advised {
 	}
 
 
+	@Override
 	public void addAdvice(Advice advice) throws AopConfigException {
 		int pos = this.advisors.size();
 		addAdvice(pos, advice);
@@ -396,6 +400,7 @@ public class AdvisedSupport extends ProxyConfig implements Advised {
 	/**
 	 * Cannot add introductions this way unless the advice implements IntroductionInfo.
 	 */
+	@Override
 	public void addAdvice(int pos, Advice advice) throws AopConfigException {
 		Assert.notNull(advice, "Advice must not be null");
 		if (advice instanceof IntroductionInfo) {
@@ -412,6 +417,7 @@ public class AdvisedSupport extends ProxyConfig implements Advised {
 		}
 	}
 
+	@Override
 	public boolean removeAdvice(Advice advice) throws AopConfigException {
 		int index = indexOf(advice);
 		if (index == -1) {
@@ -423,6 +429,7 @@ public class AdvisedSupport extends ProxyConfig implements Advised {
 		}
 	}
 
+	@Override
 	public int indexOf(Advice advice) {
 		Assert.notNull(advice, "Advice must not be null");
 		for (int i = 0; i < this.advisors.size(); i++) {
@@ -455,7 +462,7 @@ public class AdvisedSupport extends ProxyConfig implements Advised {
 	 * @param adviceClass the advice class to check
 	 * @return the count of the interceptors of this class or subclasses
 	 */
-	public int countAdvicesOfType(Class adviceClass) {
+	public int countAdvicesOfType(Class<?> adviceClass) {
 		int count = 0;
 		if (adviceClass != null) {
 			for (Advisor advisor : this.advisors) {
@@ -475,7 +482,7 @@ public class AdvisedSupport extends ProxyConfig implements Advised {
 	 * @param targetClass the target class
 	 * @return List of MethodInterceptors (may also include InterceptorAndDynamicMethodMatchers)
 	 */
-	public List<Object> getInterceptorsAndDynamicInterceptionAdvice(Method method, Class targetClass) {
+	public List<Object> getInterceptorsAndDynamicInterceptionAdvice(Method method, Class<?> targetClass) {
 		MethodCacheKey cacheKey = new MethodCacheKey(method);
 		List<Object> cached = this.methodCache.get(cacheKey);
 		if (cached == null) {
@@ -513,7 +520,7 @@ public class AdvisedSupport extends ProxyConfig implements Advised {
 		copyFrom(other);
 		this.targetSource = targetSource;
 		this.advisorChainFactory = other.advisorChainFactory;
-		this.interfaces = new ArrayList<Class>(other.interfaces);
+		this.interfaces = new ArrayList<Class<?>>(other.interfaces);
 		for (Advisor advisor : advisors) {
 			if (advisor instanceof IntroductionAdvisor) {
 				validateIntroductionAdvisor((IntroductionAdvisor) advisor);
@@ -554,6 +561,7 @@ public class AdvisedSupport extends ProxyConfig implements Advised {
 	}
 
 
+	@Override
 	public String toProxyConfigString() {
 		return toString();
 	}
@@ -578,7 +586,7 @@ public class AdvisedSupport extends ProxyConfig implements Advised {
 	 * Simple wrapper class around a Method. Used as the key when
 	 * caching methods, for efficient equals and hashCode comparisons.
 	 */
-	private static class MethodCacheKey {
+	private static final class MethodCacheKey implements Comparable<MethodCacheKey> {
 
 		private final Method method;
 
@@ -591,17 +599,28 @@ public class AdvisedSupport extends ProxyConfig implements Advised {
 
 		@Override
 		public boolean equals(Object other) {
-			if (other == this) {
-				return true;
-			}
-			MethodCacheKey otherKey = (MethodCacheKey) other;
-			return (this.method == otherKey.method);
+			return (this == other || (other instanceof MethodCacheKey &&
+					this.method == ((MethodCacheKey) other).method));
 		}
 
 		@Override
 		public int hashCode() {
 			return this.hashCode;
 		}
+
+		@Override
+		public String toString() {
+			return this.method.toString();
+		}
+
+		@Override
+		public int compareTo(MethodCacheKey other) {
+			int result = this.method.getName().compareTo(other.method.getName());
+			if (result == 0) {
+				result = this.method.toString().compareTo(other.method.toString());
+			}
+			return result;
+		}
 	}
 
 }
