@@ -16,10 +16,13 @@
 
 package org.springframework.aop.aspectj.annotation;
 
+import java.io.Serializable;
+import java.util.Arrays;
+
+import org.apache.commons.logging.LogFactory;
 import org.aspectj.lang.ProceedingJoinPoint;
 import org.aspectj.lang.annotation.Around;
 import org.aspectj.lang.annotation.Aspect;
-import org.junit.Ignore;
 import org.junit.Test;
 import test.aop.PerThisAspect;
 
@@ -77,7 +80,18 @@ public class AspectProxyFactoryTests {
 	}
 
 	@Test
-	@Ignore  // InstantiationModelAwarePointcutAdvisorImpl not serializable yet
+	@SuppressWarnings("unchecked")
+	public void testSerializable() throws Exception {
+		AspectJProxyFactory proxyFactory = new AspectJProxyFactory(new TestBean());
+		proxyFactory.addAspect(LoggingAspectOnVarargs.class);
+		ITestBean proxy = proxyFactory.getProxy();
+		assertTrue(proxy.doWithVarargs(MyEnum.A, MyOtherEnum.C));
+		ITestBean tb = (ITestBean) SerializationTestUtils.serializeAndDeserialize(proxy);
+		assertTrue(tb.doWithVarargs(MyEnum.A, MyOtherEnum.C));
+	}
+
+	@Test
+	@SuppressWarnings("unchecked")
 	public void testWithInstance() throws Exception {
 		MultiplyReturnValue aspect = new MultiplyReturnValue();
 		int multiple = 3;
@@ -102,14 +116,36 @@ public class AspectProxyFactoryTests {
 		pf.addAspect(new PerThisAspect());
 	}
 
+	@Test  // SPR-13328
+	@SuppressWarnings("unchecked")
+	public void testProxiedVarargsWithEnumArray() throws Exception {
+		AspectJProxyFactory proxyFactory = new AspectJProxyFactory(new TestBean());
+		proxyFactory.addAspect(LoggingAspectOnVarargs.class);
+		ITestBean proxy = proxyFactory.getProxy();
+		assertTrue(proxy.doWithVarargs(MyEnum.A, MyOtherEnum.C));
+	}
+
+	@Test  // SPR-13328
+	@SuppressWarnings("unchecked")
+	public void testUnproxiedVarargsWithEnumArray() throws Exception {
+		AspectJProxyFactory proxyFactory = new AspectJProxyFactory(new TestBean());
+		proxyFactory.addAspect(LoggingAspectOnSetter.class);
+		ITestBean proxy = proxyFactory.getProxy();
+		assertTrue(proxy.doWithVarargs(MyEnum.A, MyOtherEnum.C));
+	}
+
 
 	public interface ITestBean {
 
 		int getAge();
+
+		@SuppressWarnings("unchecked")
+		<V extends MyInterface> boolean doWithVarargs(V... args);
 	}
 
 
-	public static class TestBean implements ITestBean {
+	@SuppressWarnings("serial")
+	public static class TestBean implements ITestBean, Serializable {
 
 		private int age;
 
@@ -121,16 +157,58 @@ public class AspectProxyFactoryTests {
 		public void setAge(int age) {
 			this.age = age;
 		}
+
+		@SuppressWarnings("unchecked")
+		@Override
+		public <V extends MyInterface> boolean doWithVarargs(V... args) {
+			return true;
+		}
 	}
 
+
+	public interface MyInterface {
+	}
+
+
+	public enum MyEnum implements MyInterface {
+
+		A, B;
+	}
+
+
+	public enum MyOtherEnum implements MyInterface {
+
+		C, D;
+	}
+
+
+	@Aspect
+	@SuppressWarnings("serial")
+	public static class LoggingAspectOnVarargs implements Serializable {
+
+		@Around("execution(* doWithVarargs(*))")
+		public Object doLog(ProceedingJoinPoint pjp) throws Throwable {
+			LogFactory.getLog(LoggingAspectOnVarargs.class).debug(Arrays.asList(pjp.getArgs()));
+			return pjp.proceed();
+		}
+	}
+
+
+	@Aspect
+	public static class LoggingAspectOnSetter {
+
+		@Around("execution(* setAge(*))")
+		public Object doLog(ProceedingJoinPoint pjp) throws Throwable {
+			LogFactory.getLog(LoggingAspectOnSetter.class).debug(Arrays.asList(pjp.getArgs()));
+			return pjp.proceed();
+		}
+	}
 }
 
 
-/**
- * @author Rod Johnson
- */
 @Aspect
-class MultiplyReturnValue {
+@SuppressWarnings("serial")
+class MultiplyReturnValue implements Serializable {
 
 	private int multiple = 2;
 
