@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2014 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -25,7 +25,6 @@ import java.math.BigDecimal;
 
 import org.junit.Test;
 
-import org.springframework.core.JdkVersion;
 import org.springframework.tests.sample.beans.TestBean;
 
 import static org.hamcrest.CoreMatchers.equalTo;
@@ -35,6 +34,8 @@ import static org.junit.Assert.*;
 
 /**
  * @author Chris Beams
+ * @author Juergen Hoeller
+ * @author Sam Brannen
  * @since 3.1
  */
 public class ExtendedBeanInfoTests {
@@ -136,7 +137,7 @@ public class ExtendedBeanInfoTests {
 
 		assertThat(hasReadMethodForProperty(bi, "foo"), is(true));
 		assertThat(hasWriteMethodForProperty(bi, "foo"), is(false));
-		assertThat(hasIndexedWriteMethodForProperty(bi, "foo"), is(trueUntilJdk17()));
+		assertThat(hasIndexedWriteMethodForProperty(bi, "foo"), is(false));
 
 		BeanInfo ebi = new ExtendedBeanInfo(bi);
 
@@ -482,7 +483,7 @@ public class ExtendedBeanInfoTests {
 
 		assertThat(hasIndexedReadMethodForProperty(bi, "foos"), is(true));
 		// interesting! standard Inspector picks up non-void return types on indexed write methods by default
-		assertThat(hasIndexedWriteMethodForProperty(bi, "foos"), is(trueUntilJdk17()));
+		assertThat(hasIndexedWriteMethodForProperty(bi, "foos"), is(false));
 
 		BeanInfo ebi = new ExtendedBeanInfo(Introspector.getBeanInfo(C.class));
 
@@ -507,13 +508,13 @@ public class ExtendedBeanInfoTests {
 		assertThat(hasIndexedReadMethodForProperty(bi, "foos"), is(true));
 		assertThat(hasWriteMethodForProperty(bi, "foos"), is(false));
 		// again as above, standard Inspector picks up non-void return types on indexed write methods by default
-		assertThat(hasIndexedWriteMethodForProperty(bi, "foos"), is(trueUntilJdk17()));
+		assertThat(hasIndexedWriteMethodForProperty(bi, "foos"), is(false));
 
 		BeanInfo ebi = new ExtendedBeanInfo(Introspector.getBeanInfo(C.class));
 
 		assertThat(hasIndexedReadMethodForProperty(bi, "foos"), is(true));
 		assertThat(hasWriteMethodForProperty(bi, "foos"), is(false));
-		assertThat(hasIndexedWriteMethodForProperty(bi, "foos"), is(trueUntilJdk17()));
+		assertThat(hasIndexedWriteMethodForProperty(bi, "foos"), is(false));
 
 		assertThat(hasIndexedReadMethodForProperty(ebi, "foos"), is(true));
 		assertThat(hasWriteMethodForProperty(ebi, "foos"), is(true));
@@ -717,19 +718,19 @@ public class ExtendedBeanInfoTests {
 		assertThat(hasReadMethodForProperty(bi, "dateFormat"), is(false));
 		assertThat(hasWriteMethodForProperty(bi, "dateFormat"), is(false));
 		assertThat(hasIndexedReadMethodForProperty(bi, "dateFormat"), is(false));
-		assertThat(hasIndexedWriteMethodForProperty(bi, "dateFormat"), is(trueUntilJdk17()));
+		assertThat(hasIndexedWriteMethodForProperty(bi, "dateFormat"), is(false));
 
 		BeanInfo ebi = new ExtendedBeanInfo(bi);
 
 		assertThat(hasReadMethodForProperty(bi, "dateFormat"), is(false));
 		assertThat(hasWriteMethodForProperty(bi, "dateFormat"), is(false));
 		assertThat(hasIndexedReadMethodForProperty(bi, "dateFormat"), is(false));
-		assertThat(hasIndexedWriteMethodForProperty(bi, "dateFormat"), is(trueUntilJdk17()));
+		assertThat(hasIndexedWriteMethodForProperty(bi, "dateFormat"), is(false));
 
 		assertThat(hasReadMethodForProperty(ebi, "dateFormat"), is(false));
 		assertThat(hasWriteMethodForProperty(ebi, "dateFormat"), is(true));
 		assertThat(hasIndexedReadMethodForProperty(ebi, "dateFormat"), is(false));
-		assertThat(hasIndexedWriteMethodForProperty(ebi, "dateFormat"), is(trueUntilJdk17()));
+		assertThat(hasIndexedWriteMethodForProperty(ebi, "dateFormat"), is(false));
 	}
 
 	@Test
@@ -834,32 +835,26 @@ public class ExtendedBeanInfoTests {
 	}
 
 	@Test
-	public void cornerSpr8937() throws IntrospectionException {
+	public void cornerSpr8937AndSpr12582() throws IntrospectionException {
 		@SuppressWarnings("unused") class A {
 			public void setAddress(String addr){ }
 			public void setAddress(int index, String addr) { }
 			public String getAddress(int index){ return null; }
 		}
 
-		// Baseline: ExtendedBeanInfo needs to behave exactly like the following...
-		boolean hasReadMethod;
-		boolean hasWriteMethod;
-		boolean hasIndexedReadMethod;
-		boolean hasIndexedWriteMethod;
-		{
-			BeanInfo bi = Introspector.getBeanInfo(A.class);
-			hasReadMethod = hasReadMethodForProperty(bi, "address");
-			hasWriteMethod = hasWriteMethodForProperty(bi, "address");
-			hasIndexedReadMethod = hasIndexedReadMethodForProperty(bi, "address");
-			hasIndexedWriteMethod = hasIndexedWriteMethodForProperty(bi, "address");
-		}
-		{
-			BeanInfo bi = new ExtendedBeanInfo(Introspector.getBeanInfo(A.class));
-			assertEquals(hasReadMethodForProperty(bi, "address"), hasReadMethod);
-			assertEquals(hasWriteMethodForProperty(bi, "address"), hasWriteMethod);
-			assertEquals(hasIndexedReadMethodForProperty(bi, "address"), hasIndexedReadMethod);
-			assertEquals(hasIndexedWriteMethodForProperty(bi, "address"), hasIndexedWriteMethod);
-		}
+		// Baseline:
+		BeanInfo bi = Introspector.getBeanInfo(A.class);
+		boolean hasReadMethod = hasReadMethodForProperty(bi, "address");
+		boolean hasWriteMethod = hasWriteMethodForProperty(bi, "address");
+		boolean hasIndexedReadMethod = hasIndexedReadMethodForProperty(bi, "address");
+		boolean hasIndexedWriteMethod = hasIndexedWriteMethodForProperty(bi, "address");
+
+		// ExtendedBeanInfo needs to behave exactly like BeanInfo...
+		BeanInfo ebi = new ExtendedBeanInfo(bi);
+		assertEquals(hasReadMethod, hasReadMethodForProperty(ebi, "address"));
+		assertEquals(hasWriteMethod, hasWriteMethodForProperty(ebi, "address"));
+		assertEquals(hasIndexedReadMethod, hasIndexedReadMethodForProperty(ebi, "address"));
+		assertEquals(hasIndexedWriteMethod, hasIndexedWriteMethodForProperty(ebi, "address"));
 	}
 
 	@Test
@@ -932,10 +927,6 @@ public class ExtendedBeanInfoTests {
 		return false;
 	}
 
-	private boolean trueUntilJdk17() {
-		return JdkVersion.getMajorJavaVersion() < JdkVersion.JAVA_17;
-	}
-
 
 	interface Spr9453<T> {
 
