@@ -81,19 +81,22 @@ public final class ServiceLocatorFactoryBeanTests {
 			TestServiceLocator factory = (TestServiceLocator) bf.getBean("factory");
 			factory.getTestService();
 			fail("Must fail on more than one matching type");
-		} catch (NoSuchBeanDefinitionException ex) { /* expected */ }
+		}
+		catch (NoSuchBeanDefinitionException ex) { /* expected */ }
 
 		try {
 			TestServiceLocator2 factory = (TestServiceLocator2) bf.getBean("factory2");
 			factory.getTestService(null);
 			fail("Must fail on more than one matching type");
-		} catch (NoSuchBeanDefinitionException ex) { /* expected */ }
+		}
+		catch (NoSuchBeanDefinitionException ex) { /* expected */ }
 
 		try {
 			TestService2Locator factory = (TestService2Locator) bf.getBean("factory3");
 			factory.getTestService();
 			fail("Must fail on no matching types");
-		} catch (NoSuchBeanDefinitionException ex) { /* expected */ }
+		}
+		catch (NoSuchBeanDefinitionException ex) { /* expected */ }
 	}
 
 	@Test
@@ -138,7 +141,8 @@ public final class ServiceLocatorFactoryBeanTests {
 			TestService2Locator factory3 = (TestService2Locator) bf.getBean("factory3");
 			factory3.getTestService();
 			fail("Must fail on no matching type");
-		} catch (CustomServiceLocatorException3 ex) { /* expected */ }
+		}
+		catch (CustomServiceLocatorException3 ex) { /* expected */ }
 	}
 
 	@Test
@@ -160,7 +164,8 @@ public final class ServiceLocatorFactoryBeanTests {
 		try {
 			factory.getTestService("bogusTestService");
 			fail("Illegal operation allowed");
-		} catch (NoSuchBeanDefinitionException ex) { /* expected */ }
+		}
+		catch (NoSuchBeanDefinitionException ex) { /* expected */ }
 	}
 
 	@Ignore @Test // worked when using an ApplicationContext (see commented), fails when using BeanFactory
@@ -275,7 +280,8 @@ public final class ServiceLocatorFactoryBeanTests {
 		try {
 			ServiceLocatorFactoryBean factory = new ServiceLocatorFactoryBean();
 			factory.setBeanFactory(beanFactory);
-		} catch (FatalBeanException ex) {
+		}
+		catch (FatalBeanException ex) {
 			// expected
 		}
 	}
