@@ -40,6 +40,7 @@ import org.springframework.beans.factory.BeanCreationException;
 import org.springframework.beans.factory.config.TypedStringValue;
 import org.springframework.beans.factory.xml.XmlBeanDefinitionReader;
 import org.springframework.beans.propertyeditors.CustomNumberEditor;
+import org.springframework.core.ResolvableType;
 import org.springframework.core.io.ClassPathResource;
 import org.springframework.core.io.UrlResource;
 import org.springframework.tests.Assume;
@@ -782,6 +783,15 @@ public class BeanFactoryGenericsTests {
 		NumberBean nb = bf.getBean(NumberBean.class);
 		assertSame(bf.getBean("doubleStore"), nb.getDoubleStore());
 		assertSame(bf.getBean("floatStore"), nb.getFloatStore());
+
+		String[] numberStoreNames = bf.getBeanNamesForType(ResolvableType.forClass(NumberStore.class));
+		String[] doubleStoreNames = bf.getBeanNamesForType(ResolvableType.forClassWithGenerics(NumberStore.class, Double.class));
+		String[] floatStoreNames = bf.getBeanNamesForType(ResolvableType.forClassWithGenerics(NumberStore.class, Float.class));
+		assertEquals(2, numberStoreNames.length);
+		assertEquals("doubleStore", numberStoreNames[0]);
+		assertEquals("floatStore", numberStoreNames[1]);
+		assertEquals(0, doubleStoreNames.length);
+		assertEquals(0, floatStoreNames.length);
 	}
 
 	@Test
@@ -797,6 +807,17 @@ public class BeanFactoryGenericsTests {
 		NumberBean nb = bf.getBean(NumberBean.class);
 		assertSame(bf.getBean("store1"), nb.getDoubleStore());
 		assertSame(bf.getBean("store2"), nb.getFloatStore());
+
+		String[] numberStoreNames = bf.getBeanNamesForType(ResolvableType.forClass(NumberStore.class));
+		String[] doubleStoreNames = bf.getBeanNamesForType(ResolvableType.forClassWithGenerics(NumberStore.class, Double.class));
+		String[] floatStoreNames = bf.getBeanNamesForType(ResolvableType.forClassWithGenerics(NumberStore.class, Float.class));
+		assertEquals(2, numberStoreNames.length);
+		assertEquals("store1", numberStoreNames[0]);
+		assertEquals("store2", numberStoreNames[1]);
+		assertEquals(1, doubleStoreNames.length);
+		assertEquals("store1", doubleStoreNames[0]);
+		assertEquals(1, floatStoreNames.length);
+		assertEquals("store2", floatStoreNames[0]);
 	}
 
 
