@@ -485,7 +485,8 @@ public class CustomEditorTests {
 			CustomNumberEditor editor = new CustomNumberEditor(Short.class, true);
 			editor.setAsText(String.valueOf(Short.MAX_VALUE + 1));
 			fail(Short.MAX_VALUE + 1 + " is greater than max value");
-		} catch (NumberFormatException ex) {
+		}
+		catch (NumberFormatException ex) {
 			// expected
 		}
 	}
