@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2013 the original author or authors.
+ * Copyright 2002-2018 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -67,6 +67,7 @@ public class DefaultContextLoadTimeWeaver implements LoadTimeWeaver, BeanClassLo
 		setBeanClassLoader(beanClassLoader);
 	}
 
+
 	@Override
 	public void setBeanClassLoader(ClassLoader classLoader) {
 		LoadTimeWeaver serverSpecificLoadTimeWeaver = createServerSpecificLoadTimeWeaver(classLoader);
@@ -84,8 +85,10 @@ public class DefaultContextLoadTimeWeaver implements LoadTimeWeaver, BeanClassLo
 		else {
 			try {
 				this.loadTimeWeaver = new ReflectiveLoadTimeWeaver(classLoader);
-				logger.info("Using a reflective load-time weaver for class loader: " +
-						this.loadTimeWeaver.getInstrumentableClassLoader().getClass().getName());
+				if (logger.isInfoEnabled()) {
+					logger.info("Using a reflective load-time weaver for class loader: " +
+							this.loadTimeWeaver.getInstrumentableClassLoader().getClass().getName());
+				}
 			}
 			catch (IllegalStateException ex) {
 				throw new IllegalStateException(ex.getMessage() + " Specify a custom LoadTimeWeaver or start your " +
@@ -106,24 +109,26 @@ public class DefaultContextLoadTimeWeaver implements LoadTimeWeaver, BeanClassLo
 	protected LoadTimeWeaver createServerSpecificLoadTimeWeaver(ClassLoader classLoader) {
 		String name = classLoader.getClass().getName();
 		try {
-			if (name.startsWith("weblogic")) {
-				return new WebLogicLoadTimeWeaver(classLoader);
+			if (name.startsWith("org.apache.catalina")) {
+				return new TomcatLoadTimeWeaver(classLoader);
 			}
 			else if (name.startsWith("org.glassfish")) {
 				return new GlassFishLoadTimeWeaver(classLoader);
 			}
-			else if (name.startsWith("org.apache.catalina")) {
-				return new TomcatLoadTimeWeaver(classLoader);
-			}
 			else if (name.startsWith("org.jboss")) {
 				return new JBossLoadTimeWeaver(classLoader);
 			}
 			else if (name.startsWith("com.ibm")) {
 				return new WebSphereLoadTimeWeaver(classLoader);
 			}
+			else if (name.startsWith("weblogic")) {
+				return new WebLogicLoadTimeWeaver(classLoader);
+			}
 		}
-		catch (IllegalStateException ex) {
-			logger.info("Could not obtain server-specific LoadTimeWeaver: " + ex.getMessage());
+		catch (Exception ex) {
+			if (logger.isInfoEnabled()) {
+				logger.info("Could not obtain server-specific LoadTimeWeaver: " + ex.getMessage());
+			}
 		}
 		return null;
 	}
@@ -131,8 +136,10 @@ public class DefaultContextLoadTimeWeaver implements LoadTimeWeaver, BeanClassLo
 	@Override
 	public void destroy() {
 		if (this.loadTimeWeaver instanceof InstrumentationLoadTimeWeaver) {
-			logger.info("Removing all registered transformers for class loader: " +
-					this.loadTimeWeaver.getInstrumentableClassLoader().getClass().getName());
+			if (logger.isInfoEnabled()) {
+				logger.info("Removing all registered transformers for class loader: " +
+						this.loadTimeWeaver.getInstrumentableClassLoader().getClass().getName());
+			}
 			((InstrumentationLoadTimeWeaver) this.loadTimeWeaver).removeTransformers();
 		}
 	}
