@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2016 the original author or authors.
+ * Copyright 2002-2017 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -37,7 +37,8 @@ import org.springframework.util.ClassUtils;
  */
 public class GlassFishLoadTimeWeaver implements LoadTimeWeaver {
 
-	private static final String INSTRUMENTABLE_LOADER_CLASS_NAME = "org.glassfish.api.deployment.InstrumentableClassLoader";
+	private static final String INSTRUMENTABLE_LOADER_CLASS_NAME =
+			"org.glassfish.api.deployment.InstrumentableClassLoader";
 
 
 	private final ClassLoader classLoader;
@@ -47,26 +48,30 @@ public class GlassFishLoadTimeWeaver implements LoadTimeWeaver {
 	private final Method copyMethod;
 
 
+	/**
+	 * Create a new instance of the {@link GlassFishLoadTimeWeaver} class using
+	 * the default {@link ClassLoader class loader}.
+	 * @see org.springframework.util.ClassUtils#getDefaultClassLoader()
+	 */
 	public GlassFishLoadTimeWeaver() {
 		this(ClassUtils.getDefaultClassLoader());
 	}
 
+	/**
+	 * Create a new instance of the {@link GlassFishLoadTimeWeaver} class using
+	 * the supplied {@link ClassLoader}.
+	 * @param classLoader the {@code ClassLoader} to delegate to for weaving
+	 */
 	public GlassFishLoadTimeWeaver(ClassLoader classLoader) {
 		Assert.notNull(classLoader, "ClassLoader must not be null");
 
 		Class<?> instrumentableLoaderClass;
 		try {
 			instrumentableLoaderClass = classLoader.loadClass(INSTRUMENTABLE_LOADER_CLASS_NAME);
-		}
-		catch (ClassNotFoundException ex) {
-			throw new IllegalStateException(
-					"Could not initialize GlassFishLoadTimeWeaver because GlassFish API classes are not available", ex);
-		}
-		try {
 			this.addTransformerMethod = instrumentableLoaderClass.getMethod("addTransformer", ClassFileTransformer.class);
 			this.copyMethod = instrumentableLoaderClass.getMethod("copy");
 		}
-		catch (Exception ex) {
+		catch (Throwable ex) {
 			throw new IllegalStateException(
 					"Could not initialize GlassFishLoadTimeWeaver because GlassFish API classes are not available", ex);
 		}
@@ -97,7 +102,7 @@ public class GlassFishLoadTimeWeaver implements LoadTimeWeaver {
 		catch (InvocationTargetException ex) {
 			throw new IllegalStateException("GlassFish addTransformer method threw exception", ex.getCause());
 		}
-		catch (Exception ex) {
+		catch (Throwable ex) {
 			throw new IllegalStateException("Could not invoke GlassFish addTransformer method", ex);
 		}
 	}
@@ -115,7 +120,7 @@ public class GlassFishLoadTimeWeaver implements LoadTimeWeaver {
 		catch (InvocationTargetException ex) {
 			throw new IllegalStateException("GlassFish copy method threw exception", ex.getCause());
 		}
-		catch (Exception ex) {
+		catch (Throwable ex) {
 			throw new IllegalStateException("Could not invoke GlassFish copy method", ex);
 		}
 	}
