@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2010 the original author or authors.
+ * Copyright 2002-2017 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -30,7 +30,7 @@ import org.springframework.stereotype.Component;
 @Component
 public @interface DevComponent {
 
-	public static final String PROFILE_NAME = "dev";
+	String PROFILE_NAME = "dev";
 
 	String value() default "";
 
