@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2012 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -13,8 +13,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
+
 package example.scannable_implicitbasepackage;
 
+import org.springframework.context.annotation.Bean;
 import org.springframework.context.annotation.ComponentScan;
 import org.springframework.context.annotation.Configuration;
 
@@ -24,4 +26,10 @@ import org.springframework.context.annotation.Configuration;
 @Configuration
 @ComponentScan
 public class ComponentScanAnnotatedConfigWithImplicitBasePackage {
+
+	@Bean  // override of scanned class
+	public ConfigurableComponent configurableComponent() {
+		return new ConfigurableComponent(true);
+	}
+
 }
