@@ -186,7 +186,9 @@ class PrecedenceTestAspect implements BeanNameAware, Ordered {
 		try {
 			ret = ((Integer)pjp.proceed()).intValue();
 		}
-		catch(Throwable t) { throw new RuntimeException(t); }
+		catch (Throwable t) {
+			throw new RuntimeException(t);
+		}
 		this.collaborator.aroundAdviceOne(this.name);
 		return ret;
 	}
@@ -197,7 +199,9 @@ class PrecedenceTestAspect implements BeanNameAware, Ordered {
 		try {
 			ret = ((Integer)pjp.proceed()).intValue();
 		}
-		catch(Throwable t) {throw new RuntimeException(t);}
+		catch (Throwable t) {
+			throw new RuntimeException(t);
+		}
 		this.collaborator.aroundAdviceTwo(this.name);
 		return ret;
 	}
