@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2012 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -22,7 +22,6 @@ import java.lang.annotation.RetentionPolicy;
 import org.aspectj.lang.annotation.Aspect;
 import org.aspectj.lang.annotation.Before;
 import org.junit.Test;
-
 import org.springframework.context.support.ClassPathXmlApplicationContext;
 
 import static org.junit.Assert.*;
@@ -32,13 +31,17 @@ import static org.junit.Assert.*;
  * @author Chris Beams
  */
 public final class ThisAndTargetSelectionOnlyPointcutsAtAspectJTests {
-	public TestInterface testBean;
-	public TestInterface testAnnotatedClassBean;
-	public TestInterface testAnnotatedMethodBean;
 
-	protected Counter counter;
+	private TestInterface testBean;
+
+	private TestInterface testAnnotatedClassBean;
+
+	private TestInterface testAnnotatedMethodBean;
+
+	private Counter counter;
 
 	@org.junit.Before
+	@SuppressWarnings("resource")
 	public void setUp() {
 		ClassPathXmlApplicationContext ctx =
 			new ClassPathXmlApplicationContext(getClass().getSimpleName() + ".xml", getClass());
@@ -50,56 +53,56 @@ public final class ThisAndTargetSelectionOnlyPointcutsAtAspectJTests {
 	}
 
 	@Test
-	public void testThisAsClassDoesNotMatch() {
+	public void thisAsClassDoesNotMatch() {
 		testBean.doIt();
 		assertEquals(0, counter.thisAsClassCounter);
 	}
 
 	@Test
-	public void testThisAsInterfaceMatch() {
+	public void thisAsInterfaceMatch() {
 		testBean.doIt();
 		assertEquals(1, counter.thisAsInterfaceCounter);
 	}
 
 	@Test
-	public void testTargetAsClassDoesMatch() {
+	public void targetAsClassDoesMatch() {
 		testBean.doIt();
 		assertEquals(1, counter.targetAsClassCounter);
 	}
 
 	@Test
-	public void testTargetAsInterfaceMatch() {
+	public void targetAsInterfaceMatch() {
 		testBean.doIt();
 		assertEquals(1, counter.targetAsInterfaceCounter);
 	}
 
 	@Test
-	public void testThisAsClassAndTargetAsClassCounterNotMatch() {
+	public void thisAsClassAndTargetAsClassCounterNotMatch() {
 		testBean.doIt();
 		assertEquals(0, counter.thisAsClassAndTargetAsClassCounter);
 	}
 
 	@Test
-	public void testThisAsInterfaceAndTargetAsInterfaceCounterMatch() {
+	public void thisAsInterfaceAndTargetAsInterfaceCounterMatch() {
 		testBean.doIt();
 		assertEquals(1, counter.thisAsInterfaceAndTargetAsInterfaceCounter);
 	}
 
 	@Test
-	public void testThisAsInterfaceAndTargetAsClassCounterMatch() {
+	public void thisAsInterfaceAndTargetAsClassCounterMatch() {
 		testBean.doIt();
 		assertEquals(1, counter.thisAsInterfaceAndTargetAsInterfaceCounter);
 	}
 
 
 	@Test
-	public void testAtTargetClassAnnotationMatch() {
+	public void atTargetClassAnnotationMatch() {
 		testAnnotatedClassBean.doIt();
 		assertEquals(1, counter.atTargetClassAnnotationCounter);
 	}
 
 	@Test
-	public void testAtAnnotationMethodAnnotationMatch() {
+	public void atAnnotationMethodAnnotationMatch() {
 		testAnnotatedMethodBean.doIt();
 		assertEquals(1, counter.atAnnotationMethodAnnotationCounter);
 	}
