@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2016 the original author or authors.
+ * Copyright 2002-2017 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -33,7 +33,7 @@ public class ClassWithComplexConstructor {
 
 	@Autowired
 	public ClassWithComplexConstructor(Dependency dependency) {
-		Assert.notNull(dependency);
+		Assert.notNull(dependency, "No Dependency bean injected");
 		this.dependency = dependency;
 	}
 
@@ -42,7 +42,8 @@ public class ClassWithComplexConstructor {
 	}
 
 	public void method() {
-		Assert.isTrue(this.selfReference != this && AopUtils.isCglibProxy(this.selfReference));
+		Assert.state(this.selfReference != this && AopUtils.isCglibProxy(this.selfReference),
+				"Self reference must be a CGLIB proxy");
 		this.dependency.method();
 	}
 
