@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2015 the original author or authors.
+ * Copyright 2002-2016 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -20,6 +20,7 @@ import java.io.Serializable;
 
 import org.aopalliance.intercept.MethodInterceptor;
 import org.aopalliance.intercept.MethodInvocation;
+
 import org.junit.Test;
 
 import org.springframework.aop.interceptor.ExposeInvocationInterceptor;
@@ -31,10 +32,10 @@ import org.springframework.tests.sample.beans.TestBean;
 import static org.junit.Assert.*;
 
 /**
- * @since 13.03.2003
  * @author Rod Johnson
  * @author Juergen Hoeller
  * @author Chris Beams
+ * @since 13.03.2003
  */
 @SuppressWarnings("serial")
 public class JdkDynamicProxyTests extends AbstractAopProxyTests implements Serializable {
@@ -53,42 +54,36 @@ public class JdkDynamicProxyTests extends AbstractAopProxyTests implements Seria
 	}
 
 
-	@Test
+	@Test(expected = IllegalArgumentException.class)
 	public void testNullConfig() {
-		try {
-			new JdkDynamicAopProxy(null);
-			fail("Shouldn't allow null interceptors");
-		}
-		catch (IllegalArgumentException ex) {
-			// Ok
-		}
+		new JdkDynamicAopProxy(null);
 	}
 
 	@Test
 	public void testProxyIsJustInterface() throws Throwable {
 		TestBean raw = new TestBean();
 		raw.setAge(32);
-		AdvisedSupport pc = new AdvisedSupport(new Class<?>[] {ITestBean.class});
+		AdvisedSupport pc = new AdvisedSupport(ITestBean.class);
 		pc.setTarget(raw);
 		JdkDynamicAopProxy aop = new JdkDynamicAopProxy(pc);
 
 		Object proxy = aop.getProxy();
 		assertTrue(proxy instanceof ITestBean);
-		assertTrue(!(proxy instanceof TestBean));
+		assertFalse(proxy instanceof TestBean);
 	}
 
 	@Test
 	public void testInterceptorIsInvokedWithNoTarget() throws Throwable {
 		// Test return value
-		final Integer age = 25;
+		final int age = 25;
 		MethodInterceptor mi = (invocation -> age);
 
-		AdvisedSupport pc = new AdvisedSupport(new Class<?>[] {ITestBean.class});
+		AdvisedSupport pc = new AdvisedSupport(ITestBean.class);
 		pc.addAdvice(mi);
 		AopProxy aop = createAopProxy(pc);
 
 		ITestBean tb = (ITestBean) aop.getProxy();
-		assertTrue("correct return value", tb.getAge() == age);
+		assertEquals("correct return value", age, tb.getAge());
 	}
 
 	@Test
@@ -96,13 +91,13 @@ public class JdkDynamicProxyTests extends AbstractAopProxyTests implements Seria
 		final ExposedInvocationTestBean expectedTarget = new ExposedInvocationTestBean() {
 			@Override
 			protected void assertions(MethodInvocation invocation) {
-				assertTrue(invocation.getThis() == this);
-				assertTrue("Invocation should be on ITestBean: " + invocation.getMethod(),
-						invocation.getMethod().getDeclaringClass() == ITestBean.class);
+				assertEquals(this, invocation.getThis());
+				assertEquals("Invocation should be on ITestBean: " + invocation.getMethod(),
+						ITestBean.class, invocation.getMethod().getDeclaringClass());
 			}
 		};
 
-		AdvisedSupport pc = new AdvisedSupport(new Class<?>[] {ITestBean.class, IOther.class});
+		AdvisedSupport pc = new AdvisedSupport(ITestBean.class, IOther.class);
 		pc.addAdvice(ExposeInvocationInterceptor.INSTANCE);
 		TrapTargetInterceptor tii = new TrapTargetInterceptor() {
 			@Override
@@ -118,15 +113,6 @@ public class JdkDynamicProxyTests extends AbstractAopProxyTests implements Seria
 
 		ITestBean tb = (ITestBean) aop.getProxy();
 		tb.getName();
-		// Not safe to trap invocation
-		//assertTrue(tii.invocation == target.invocation);
-
-		//assertTrue(target.invocation.getProxy() == tb);
-
-		//	((IOther) tb).absquatulate();
-		//MethodInvocation minv =  tii.invocation;
-		//assertTrue("invoked on iother, not " + minv.getMethod().getDeclaringClass(), minv.getMethod().getDeclaringClass() == IOther.class);
-		//assertTrue(target.invocation == tii.invocation);
 	}
 
 	@Test
@@ -139,18 +125,24 @@ public class JdkDynamicProxyTests extends AbstractAopProxyTests implements Seria
 		Foo proxy = (Foo) createProxy(as);
 		assertSame("Target should be returned when return types are incompatible", bean, proxy.getBarThis());
 		assertSame("Proxy should be returned when return types are compatible", proxy, proxy.getFooThis());
-
 	}
 
 	@Test
 	public void testEqualsAndHashCodeDefined() throws Exception {
-		AdvisedSupport as = new AdvisedSupport(new Class<?>[]{Named.class});
+		AdvisedSupport as = new AdvisedSupport(Named.class);
 		as.setTarget(new Person());
 		JdkDynamicAopProxy aopProxy = new JdkDynamicAopProxy(as);
 		Named proxy = (Named) aopProxy.getProxy();
 		Named named = new Person();
-		assertEquals("equals() returned false", proxy, named);
-		assertEquals("hashCode() not equal", proxy.hashCode(), named.hashCode());
+		assertEquals("equals()", proxy, named);
+		assertEquals("hashCode()", proxy.hashCode(), named.hashCode());
+	}
+
+	@Test  // SPR-13328
+	public void testVarargsWithEnumArray() throws Exception {
+		ProxyFactory proxyFactory = new ProxyFactory(new VarargTestBean());
+		VarargTestInterface proxy = (VarargTestInterface) proxyFactory.getProxy();
+		assertTrue(proxy.doWithVarargs(MyEnum.A, MyOtherEnum.C));
 	}
 
 
@@ -216,4 +208,36 @@ public class JdkDynamicProxyTests extends AbstractAopProxyTests implements Seria
 		}
 	}
 
+
+	public interface VarargTestInterface {
+
+		<V extends MyInterface> boolean doWithVarargs(V... args);
+	}
+
+
+	public static class VarargTestBean implements VarargTestInterface {
+
+		@SuppressWarnings("unchecked")
+		@Override
+		public <V extends MyInterface> boolean doWithVarargs(V... args) {
+			return true;
+		}
+	}
+
+
+	public interface MyInterface {
+	}
+
+
+	public enum MyEnum implements MyInterface {
+
+		A, B;
+	}
+
+
+	public enum MyOtherEnum implements MyInterface {
+
+		C, D;
+	}
+
 }
