@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2014 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -30,7 +30,7 @@ import static org.junit.Assert.*;
  * @author Chris Beams
  * @author Stephane Nicoll
  */
-public class AnnotationNamespaceDrivenTests extends AbstractAnnotationTests {
+public class AnnotationNamespaceDrivenTests extends AbstractCacheAnnotationTests {
 
 	@Override
 	protected ConfigurableApplicationContext getApplicationContext() {
@@ -40,8 +40,8 @@ public class AnnotationNamespaceDrivenTests extends AbstractAnnotationTests {
 
 	@Test
 	public void testKeyStrategy() {
-		CacheInterceptor ci = ctx.getBean("org.springframework.cache.interceptor.CacheInterceptor#0",
-				CacheInterceptor.class);
+		CacheInterceptor ci = ctx.getBean(
+				"org.springframework.cache.interceptor.CacheInterceptor#0", CacheInterceptor.class);
 		assertSame(ctx.getBean("keyGenerator"), ci.getKeyGenerator());
 	}
 
@@ -67,8 +67,9 @@ public class AnnotationNamespaceDrivenTests extends AbstractAnnotationTests {
 
 	@Test
 	public void testCacheErrorHandler() {
-		CacheInterceptor ci = ctx.getBean("org.springframework.cache.interceptor.CacheInterceptor#0",
-				CacheInterceptor.class);
+		CacheInterceptor ci = ctx.getBean(
+				"org.springframework.cache.interceptor.CacheInterceptor#0", CacheInterceptor.class);
 		assertSame(ctx.getBean("errorHandler", CacheErrorHandler.class), ci.getErrorHandler());
 	}
+
 }
