@@ -16,19 +16,22 @@
 
 package org.springframework.context.access;
 
-import junit.framework.TestCase;
+import org.junit.Test;
+
+import static org.junit.Assert.*;
 
 import org.springframework.beans.factory.access.BeanFactoryLocator;
 
 /**
  * @author Colin Sampaleanu
  */
-public class DefaultLocatorFactoryTests extends TestCase {
+public class DefaultLocatorFactoryTests {
 
 	/*
 	 * Class to test for BeanFactoryLocator getInstance()
 	 */
-	public void testGetInstance() {
+	@Test
+	public void getInstance() {
 		BeanFactoryLocator bf = DefaultLocatorFactory.getInstance();
 		BeanFactoryLocator bf2 = DefaultLocatorFactory.getInstance();
 		assertTrue(bf.equals(bf2));
@@ -37,7 +40,8 @@ public class DefaultLocatorFactoryTests extends TestCase {
 	/*
 	 * Class to test for BeanFactoryLocator getInstance(String)
 	 */
-	public void testGetInstanceString() {
+	@Test
+	public void getInstanceString() {
 		BeanFactoryLocator bf = DefaultLocatorFactory.getInstance("my-bean-refs.xml");
 		BeanFactoryLocator bf2 = DefaultLocatorFactory.getInstance("my-bean-refs.xml");
 		assertTrue(bf.equals(bf2));
