@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2014 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -44,7 +44,7 @@ public class ComponentScanAnnotationTests {
 
 @Configuration
 @ComponentScan(
-	basePackageClasses={TestBean.class},
+	basePackageClasses = TestBean.class,
 	nameGenerator = DefaultBeanNameGenerator.class,
 	scopedProxy = ScopedProxyMode.NO,
 	scopeResolver = AnnotationScopeMetadataResolver.class,
@@ -61,6 +61,6 @@ public class ComponentScanAnnotationTests {
 class MyConfig {
 }
 
-@ComponentScan(basePackageClasses=example.scannable.NamedComponent.class)
+@ComponentScan(basePackageClasses = example.scannable.NamedComponent.class)
 class SimpleConfig {
 }
