@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2014 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -145,9 +145,9 @@ public class ComponentScanParserTests {
 	}
 
 
-	@Target({ ElementType.TYPE, ElementType.FIELD })
+	@Target({ElementType.TYPE, ElementType.FIELD})
 	@Retention(RetentionPolicy.RUNTIME)
-	public static @interface CustomAnnotation {
+	public @interface CustomAnnotation {
 	}
 
 
