@@ -82,6 +82,15 @@ public class ConfigurationWithFactoryBeanAndAutowiringTests {
 		ctx.refresh();
 	}
 
+	@Test
+	public void withFactoryBeanCallingBean() {
+		AnnotationConfigApplicationContext ctx = new AnnotationConfigApplicationContext();
+		ctx.register(AppConfig.class);
+		ctx.register(FactoryBeanCallingConfig.class);
+		ctx.refresh();
+		assertEquals("true", ctx.getBean("myString"));
+	}
+
 
 	static class DummyBean {
 	}
@@ -237,4 +246,23 @@ public class ConfigurationWithFactoryBeanAndAutowiringTests {
 		}
 	}
 
+
+	@Configuration
+	static class FactoryBeanCallingConfig {
+
+		@Autowired
+		private DummyBean dummyBean;
+
+		@Bean
+		public MyFactoryBean factoryBean() {
+			Assert.notNull(dummyBean, "DummyBean was not injected.");
+			return new MyFactoryBean();
+		}
+
+		@Bean
+		public String myString() {
+			return factoryBean().getString();
+		}
+	}
+
 }
