@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2011 the original author or authors.
+ * Copyright 2002-2013 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,10 +17,12 @@
 package org.springframework.context.annotation.role;
 
 import org.springframework.beans.factory.config.BeanDefinition;
+import org.springframework.context.annotation.Description;
 import org.springframework.context.annotation.Role;
 import org.springframework.stereotype.Component;
 
 @Component("componentWithRole")
 @Role(BeanDefinition.ROLE_INFRASTRUCTURE)
+@Description("A Component with a role")
 public class ComponentWithRole {
 }
\ No newline at end of file
