@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2013 the original author or authors.
+ * Copyright 2002-2016 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -279,26 +279,25 @@ public class SimpleRemoteStatelessSessionProxyFactoryBeanTests extends SimpleRem
 	}
 
 
-	protected static interface MyHome extends EJBHome {
+	protected interface MyHome extends EJBHome {
 
 		MyBusinessMethods create() throws CreateException, RemoteException;
 	}
 
 
-	protected static interface MyBusinessMethods  {
+	protected interface MyBusinessMethods  {
 
 		int getValue() throws RemoteException;
 	}
 
 
-	protected static interface MyLocalBusinessMethods  {
+	protected interface MyLocalBusinessMethods  {
 
 		int getValue();
 	}
 
 
-	protected static interface MyEjb extends EJBObject, MyBusinessMethods {
-
+	protected interface MyEjb extends EJBObject, MyBusinessMethods {
 	}
 
 }
