@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2012 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -43,10 +43,11 @@ import static org.junit.Assert.*;
  */
 public class DateFormatterTests {
 
+	private static final TimeZone UTC = TimeZone.getTimeZone("UTC");
+
 	@Rule
 	public ExpectedException thown = ExpectedException.none();
 
-	private static final TimeZone UTC = TimeZone.getTimeZone("UTC");
 
 	@Test
 	public void shouldPrintAndParseDefault() throws Exception {
@@ -148,7 +149,7 @@ public class DateFormatterTests {
 
 	@Test
 	public void shouldSupportJodaStylePatterns() throws Exception {
-		String[] chars = { "S", "M", "L", "F", "-" };
+		String[] chars = { "S", "M", "-" };
 		for (String d : chars) {
 			for (String t : chars) {
 				String style = d + t;
@@ -156,7 +157,8 @@ public class DateFormatterTests {
 					Date date = getDate(2009, Calendar.JUNE, 10, 14, 23, 0, 0);
 					if (t.equals("-")) {
 						date = getDate(2009, Calendar.JUNE, 10);
-					} else if (d.equals("-")) {
+					}
+					else if (d.equals("-")) {
 						date = getDate(1970, Calendar.JANUARY, 1, 14, 23, 0, 0);
 					}
 					testJodaStylePatterns(style, Locale.US, date);
@@ -165,13 +167,11 @@ public class DateFormatterTests {
 		}
 	}
 
-	private void testJodaStylePatterns(String style, Locale locale, Date date)
-			throws Exception {
+	private void testJodaStylePatterns(String style, Locale locale, Date date) throws Exception {
 		DateFormatter formatter = new DateFormatter();
 		formatter.setTimeZone(UTC);
 		formatter.setStylePattern(style);
-		DateTimeFormatter jodaFormatter = DateTimeFormat.forStyle(style).withLocale(
-				locale).withZone(DateTimeZone.UTC);
+		DateTimeFormatter jodaFormatter = DateTimeFormat.forStyle(style).withLocale(locale).withZone(DateTimeZone.UTC);
 		String jodaPrinted = jodaFormatter.print(date.getTime());
 		assertThat("Unable to print style pattern " + style,
 				formatter.print(date, locale), is(equalTo(jodaPrinted)));
@@ -180,7 +180,7 @@ public class DateFormatterTests {
 	}
 
 	@Test
-	public void shouldThrowOnUnsupportStylePattern() throws Exception {
+	public void shouldThrowOnUnsupportedStylePattern() throws Exception {
 		DateFormatter formatter = new DateFormatter();
 		formatter.setStylePattern("OO");
 		thown.expect(IllegalStateException.class);
@@ -210,12 +210,12 @@ public class DateFormatterTests {
 		assertThat("uses style", formatter.print(date, Locale.US), is("6/1/09"));
 	}
 
+
 	private Date getDate(int year, int month, int dayOfMonth) {
 		return getDate(year, month, dayOfMonth, 0, 0, 0, 0);
 	}
 
-	private Date getDate(int year, int month, int dayOfMonth, int hour, int minute,
-			int second, int millisecond) {
+	private Date getDate(int year, int month, int dayOfMonth, int hour, int minute, int second, int millisecond) {
 		Calendar cal = Calendar.getInstance(Locale.US);
 		cal.setTimeZone(UTC);
 		cal.clear();
