@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2013 the original author or authors.
+ * Copyright 2002-2016 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -46,10 +46,11 @@ import static org.junit.Assert.*;
  */
 public class DateFormattingTests {
 
-	private FormattingConversionService conversionService = new FormattingConversionService();
+	private final FormattingConversionService conversionService = new FormattingConversionService();
 
 	private DataBinder binder;
 
+
 	@Before
 	public void setUp() {
 		DateFormatterRegistrar registrar = new DateFormatterRegistrar();
@@ -73,21 +74,32 @@ public class DateFormattingTests {
 		LocaleContextHolder.setLocale(null);
 	}
 
+
 	@Test
-	public void testBindDate() {
+	public void testBindLong() {
 		MutablePropertyValues propertyValues = new MutablePropertyValues();
-		propertyValues.add("date", "10/31/09 12:00 PM");
+		propertyValues.add("millis", "1256961600");
 		binder.bind(propertyValues);
 		assertEquals(0, binder.getBindingResult().getErrorCount());
-		assertEquals("10/31/09 12:00 PM", binder.getBindingResult().getFieldValue("date"));
+		assertEquals("1256961600", binder.getBindingResult().getFieldValue("millis"));
 	}
 
 	@Test
-	public void testBindDateArray() {
+	public void testBindLongAnnotated() {
 		MutablePropertyValues propertyValues = new MutablePropertyValues();
-		propertyValues.add("date", new String[] {"10/31/09 12:00 PM"});
+		propertyValues.add("millisAnnotated", "10/31/09");
 		binder.bind(propertyValues);
 		assertEquals(0, binder.getBindingResult().getErrorCount());
+		assertEquals("10/31/09", binder.getBindingResult().getFieldValue("millisAnnotated"));
+	}
+
+	@Test
+	public void testBindCalendarAnnotated() {
+		MutablePropertyValues propertyValues = new MutablePropertyValues();
+		propertyValues.add("calendarAnnotated", "10/31/09");
+		binder.bind(propertyValues);
+		assertEquals(0, binder.getBindingResult().getErrorCount());
+		assertEquals("10/31/09", binder.getBindingResult().getFieldValue("calendarAnnotated"));
 	}
 
 	@Test
@@ -99,6 +111,14 @@ public class DateFormattingTests {
 		assertEquals("10/31/09", binder.getBindingResult().getFieldValue("dateAnnotated"));
 	}
 
+	@Test
+	public void testBindDateArray() {
+		MutablePropertyValues propertyValues = new MutablePropertyValues();
+		propertyValues.add("dateAnnotated", new String[]{"10/31/09 12:00 PM"});
+		binder.bind(propertyValues);
+		assertEquals(0, binder.getBindingResult().getErrorCount());
+	}
+
 	@Test
 	public void testBindDateAnnotatedWithError() {
 		MutablePropertyValues propertyValues = new MutablePropertyValues();
@@ -120,39 +140,20 @@ public class DateFormattingTests {
 	}
 
 	@Test
-	public void testBindCalendar() {
+	public void testBindDateAnnotatedPattern() {
 		MutablePropertyValues propertyValues = new MutablePropertyValues();
-		propertyValues.add("calendar", "10/31/09 12:00 PM");
+		propertyValues.add("dateAnnotatedPattern", "10/31/09 1:05");
 		binder.bind(propertyValues);
 		assertEquals(0, binder.getBindingResult().getErrorCount());
-		assertEquals("10/31/09 12:00 PM", binder.getBindingResult().getFieldValue("calendar"));
+		assertEquals("10/31/09 1:05", binder.getBindingResult().getFieldValue("dateAnnotatedPattern"));
 	}
 
 	@Test
-	public void testBindCalendarAnnotated() {
+	public void testBindDateTimeOverflow() {
 		MutablePropertyValues propertyValues = new MutablePropertyValues();
-		propertyValues.add("calendarAnnotated", "10/31/09");
+		propertyValues.add("dateAnnotatedPattern", "02/29/09 12:00 PM");
 		binder.bind(propertyValues);
-		assertEquals(0, binder.getBindingResult().getErrorCount());
-		assertEquals("10/31/09", binder.getBindingResult().getFieldValue("calendarAnnotated"));
-	}
-
-	@Test
-	public void testBindLong() {
-		MutablePropertyValues propertyValues = new MutablePropertyValues();
-		propertyValues.add("millis", "1256961600");
-		binder.bind(propertyValues);
-		assertEquals(0, binder.getBindingResult().getErrorCount());
-		assertEquals("1256961600", binder.getBindingResult().getFieldValue("millis"));
-	}
-
-	@Test
-	public void testBindLongAnnotated() {
-		MutablePropertyValues propertyValues = new MutablePropertyValues();
-		propertyValues.add("millisAnnotated", "10/31/09");
-		binder.bind(propertyValues);
-		assertEquals(0, binder.getBindingResult().getErrorCount());
-		assertEquals("10/31/09", binder.getBindingResult().getFieldValue("millisAnnotated"));
+		assertEquals(1, binder.getBindingResult().getErrorCount());
 	}
 
 	@Test
@@ -237,23 +238,17 @@ public class DateFormattingTests {
 	@SuppressWarnings("unused")
 	private static class SimpleDateBean {
 
-		@DateTimeFormat
-		private Date date;
-
-		@DateTimeFormat(style="S-")
-		private Date dateAnnotated;
-
-		@DateTimeFormat
-		private Calendar calendar;
-
-		@DateTimeFormat(style="S-")
-		private Calendar calendarAnnotated;
-
 		private Long millis;
 
 		private Long millisAnnotated;
 
-		@DateTimeFormat(pattern="M/d/yy h:mm a")
+		@DateTimeFormat(style="S-")
+		private Calendar calendarAnnotated;
+
+		@DateTimeFormat(style="S-")
+		private Date dateAnnotated;
+
+		@DateTimeFormat(pattern="M/d/yy h:mm")
 		private Date dateAnnotatedPattern;
 
 		@DateTimeFormat(iso=ISO.DATE)
@@ -267,38 +262,6 @@ public class DateFormattingTests {
 
 		private final List<SimpleDateBean> children = new ArrayList<SimpleDateBean>();
 
-		public Date getDate() {
-			return date;
-		}
-
-		public void setDate(Date date) {
-			this.date = date;
-		}
-
-		public Date getDateAnnotated() {
-			return dateAnnotated;
-		}
-
-		public void setDateAnnotated(Date dateAnnotated) {
-			this.dateAnnotated = dateAnnotated;
-		}
-
-		public Calendar getCalendar() {
-			return calendar;
-		}
-
-		public void setCalendar(Calendar calendar) {
-			this.calendar = calendar;
-		}
-
-		public Calendar getCalendarAnnotated() {
-			return calendarAnnotated;
-		}
-
-		public void setCalendarAnnotated(Calendar calendarAnnotated) {
-			this.calendarAnnotated = calendarAnnotated;
-		}
-
 		public Long getMillis() {
 			return millis;
 		}
@@ -316,6 +279,30 @@ public class DateFormattingTests {
 			this.millisAnnotated = millisAnnotated;
 		}
 
+		public Calendar getCalendarAnnotated() {
+			return calendarAnnotated;
+		}
+
+		public void setCalendarAnnotated(Calendar calendarAnnotated) {
+			this.calendarAnnotated = calendarAnnotated;
+		}
+
+		public Date getDateAnnotated() {
+			return dateAnnotated;
+		}
+
+		public void setDateAnnotated(Date dateAnnotated) {
+			this.dateAnnotated = dateAnnotated;
+		}
+
+		public Date getDateAnnotatedPattern() {
+			return dateAnnotatedPattern;
+		}
+
+		public void setDateAnnotatedPattern(Date dateAnnotatedPattern) {
+			this.dateAnnotatedPattern = dateAnnotatedPattern;
+		}
+
 		public Date getIsoDate() {
 			return isoDate;
 		}
