@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2012 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -41,10 +41,11 @@ import static org.junit.Assert.*;
  */
 public class NumberFormattingTests {
 
-	private FormattingConversionService conversionService = new FormattingConversionService();
+	private final FormattingConversionService conversionService = new FormattingConversionService();
 
 	private DataBinder binder;
 
+
 	@Before
 	public void setUp() {
 		DefaultConversionService.addDefaultConverters(conversionService);
@@ -53,12 +54,13 @@ public class NumberFormattingTests {
 			public String resolveStringValue(String strVal) {
 				if ("${pattern}".equals(strVal)) {
 					return "#,##.00";
-				} else {
+				}
+				else {
 					return strVal;
 				}
 			}
 		});
-		conversionService.addFormatterForFieldType(Number.class, new NumberFormatter());
+		conversionService.addFormatterForFieldType(Number.class, new NumberStyleFormatter());
 		conversionService.addFormatterForFieldAnnotation(new NumberFormatAnnotationFormatterFactory());
 		LocaleContextHolder.setLocale(Locale.US);
 		binder = new DataBinder(new TestBean());
@@ -70,6 +72,7 @@ public class NumberFormattingTests {
 		LocaleContextHolder.setLocale(null);
 	}
 
+
 	@Test
 	public void testDefaultNumberFormatting() {
 		MutablePropertyValues propertyValues = new MutablePropertyValues();
@@ -172,6 +175,7 @@ public class NumberFormattingTests {
 		assertEquals("1,25.00,2,35.00", binder.getBindingResult().getFieldValue("patternList2"));
 	}
 
+
 	@SuppressWarnings("unused")
 	private static class TestBean {
 
@@ -261,7 +265,6 @@ public class NumberFormattingTests {
 		public void setPatternList2(List<BigDecimal> patternList2) {
 			this.patternList2 = patternList2;
 		}
-
 	}
 
 }
