@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2014 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -27,6 +27,7 @@ import static org.junit.Assert.*;
 
 /**
  * @author Mark Fisher
+ * @author Stephane Nicoll
  */
 public class AnnotationDrivenBeanDefinitionParserTests {
 
@@ -64,4 +65,11 @@ public class AnnotationDrivenBeanDefinitionParserTests {
 		assertSame(scheduler, new DirectFieldAccessor(postProcessor).getPropertyValue("scheduler"));
 	}
 
+	@Test
+	public void asyncPostProcessorExceptionHandlerReference() {
+		Object exceptionHandler = context.getBean("testExceptionHandler");
+		Object postProcessor = context.getBean(TaskManagementConfigUtils.ASYNC_ANNOTATION_PROCESSOR_BEAN_NAME);
+		assertSame(exceptionHandler, new DirectFieldAccessor(postProcessor).getPropertyValue("exceptionHandler"));
+	}
+
 }
