@@ -41,15 +41,19 @@ public class LazyScheduledTasksBeanDefinitionParserTests {
 		while (!task.executed) {
 			try {
 				Thread.sleep(10);
-			} catch (Exception e) { /* Do Nothing */ }
+			}
+			catch (Exception ex) { /* Do Nothing */ }
 		}
 	}
 
+
 	static class Task {
+
 		volatile boolean executed = false;
 
 		public void doWork() {
 			executed = true;
 		}
 	}
+
 }
