@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2013 the original author or authors.
+ * Copyright 2002-2016 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -22,7 +22,6 @@ import java.util.Map;
 
 import groovy.lang.DelegatingMetaClass;
 import groovy.lang.GroovyObject;
-import org.junit.Ignore;
 import org.junit.Test;
 
 import org.springframework.aop.support.AopUtils;
@@ -90,6 +89,35 @@ public class GroovyScriptFactoryTests {
 		assertTrue(ctx.getBeansOfType(Messenger.class).values().contains(messenger));
 	}
 
+	@Test
+	public void testStaticScriptUsingJsr223() throws Exception {
+		ApplicationContext ctx = new ClassPathXmlApplicationContext("groovyContextWithJsr223.xml", getClass());
+
+		assertTrue(Arrays.asList(ctx.getBeanNamesForType(Calculator.class)).contains("calculator"));
+		assertTrue(Arrays.asList(ctx.getBeanNamesForType(Messenger.class)).contains("messenger"));
+
+		Calculator calc = (Calculator) ctx.getBean("calculator");
+		Messenger messenger = (Messenger) ctx.getBean("messenger");
+
+		assertFalse("Shouldn't get proxy when refresh is disabled", AopUtils.isAopProxy(calc));
+		assertFalse("Shouldn't get proxy when refresh is disabled", AopUtils.isAopProxy(messenger));
+
+		assertFalse("Scripted object should not be instance of Refreshable", calc instanceof Refreshable);
+		assertFalse("Scripted object should not be instance of Refreshable", messenger instanceof Refreshable);
+
+		assertEquals(calc, calc);
+		assertEquals(messenger, messenger);
+		assertTrue(!messenger.equals(calc));
+		assertTrue(messenger.hashCode() != calc.hashCode());
+		assertTrue(!messenger.toString().equals(calc.toString()));
+
+		String desiredMessage = "Hello World!";
+		assertEquals("Message is incorrect", desiredMessage, messenger.getMessage());
+
+		assertTrue(ctx.getBeansOfType(Calculator.class).values().contains(calc));
+		assertTrue(ctx.getBeansOfType(Messenger.class).values().contains(messenger));
+	}
+
 	@Test
 	public void testStaticPrototypeScript() throws Exception {
 		ApplicationContext ctx = new ClassPathXmlApplicationContext("groovyContext.xml", getClass());
@@ -109,6 +137,25 @@ public class GroovyScriptFactoryTests {
 		assertEquals("Byebye World!", messenger2.getMessage());
 	}
 
+	@Test
+	public void testStaticPrototypeScriptUsingJsr223() throws Exception {
+		ApplicationContext ctx = new ClassPathXmlApplicationContext("groovyContextWithJsr223.xml", getClass());
+		ConfigurableMessenger messenger = (ConfigurableMessenger) ctx.getBean("messengerPrototype");
+		ConfigurableMessenger messenger2 = (ConfigurableMessenger) ctx.getBean("messengerPrototype");
+
+		assertFalse("Shouldn't get proxy when refresh is disabled", AopUtils.isAopProxy(messenger));
+		assertFalse("Scripted object should not be instance of Refreshable", messenger instanceof Refreshable);
+
+		assertNotSame(messenger, messenger2);
+		assertSame(messenger.getClass(), messenger2.getClass());
+		assertEquals("Hello World!", messenger.getMessage());
+		assertEquals("Hello World!", messenger2.getMessage());
+		messenger.setMessage("Bye World!");
+		messenger2.setMessage("Byebye World!");
+		assertEquals("Bye World!", messenger.getMessage());
+		assertEquals("Byebye World!", messenger2.getMessage());
+	}
+
 	@Test
 	public void testStaticScriptWithInstance() throws Exception {
 		ApplicationContext ctx = new ClassPathXmlApplicationContext("groovyContext.xml", getClass());
@@ -123,6 +170,20 @@ public class GroovyScriptFactoryTests {
 		assertTrue(ctx.getBeansOfType(Messenger.class).values().contains(messenger));
 	}
 
+	@Test
+	public void testStaticScriptWithInstanceUsingJsr223() throws Exception {
+		ApplicationContext ctx = new ClassPathXmlApplicationContext("groovyContextWithJsr223.xml", getClass());
+		assertTrue(Arrays.asList(ctx.getBeanNamesForType(Messenger.class)).contains("messengerInstance"));
+		Messenger messenger = (Messenger) ctx.getBean("messengerInstance");
+
+		assertFalse("Shouldn't get proxy when refresh is disabled", AopUtils.isAopProxy(messenger));
+		assertFalse("Scripted object should not be instance of Refreshable", messenger instanceof Refreshable);
+
+		String desiredMessage = "Hello World!";
+		assertEquals("Message is incorrect", desiredMessage, messenger.getMessage());
+		assertTrue(ctx.getBeansOfType(Messenger.class).values().contains(messenger));
+	}
+
 	@Test
 	public void testStaticScriptWithInlineDefinedInstance() throws Exception {
 		ApplicationContext ctx = new ClassPathXmlApplicationContext("groovyContext.xml", getClass());
@@ -137,6 +198,20 @@ public class GroovyScriptFactoryTests {
 		assertTrue(ctx.getBeansOfType(Messenger.class).values().contains(messenger));
 	}
 
+	@Test
+	public void testStaticScriptWithInlineDefinedInstanceUsingJsr223() throws Exception {
+		ApplicationContext ctx = new ClassPathXmlApplicationContext("groovyContextWithJsr223.xml", getClass());
+		assertTrue(Arrays.asList(ctx.getBeanNamesForType(Messenger.class)).contains("messengerInstanceInline"));
+		Messenger messenger = (Messenger) ctx.getBean("messengerInstanceInline");
+
+		assertFalse("Shouldn't get proxy when refresh is disabled", AopUtils.isAopProxy(messenger));
+		assertFalse("Scripted object should not be instance of Refreshable", messenger instanceof Refreshable);
+
+		String desiredMessage = "Hello World!";
+		assertEquals("Message is incorrect", desiredMessage, messenger.getMessage());
+		assertTrue(ctx.getBeansOfType(Messenger.class).values().contains(messenger));
+	}
+
 	@Test
 	public void testNonStaticScript() throws Exception {
 		ApplicationContext ctx = new ClassPathXmlApplicationContext("groovyRefreshableContext.xml", getClass());
@@ -193,7 +268,7 @@ public class GroovyScriptFactoryTests {
 	@Test
 	public void testScriptedClassThatDoesNotHaveANoArgCtor() throws Exception {
 		ScriptSource script = mock(ScriptSource.class);
-		final String badScript = "class Foo { public Foo(String foo) {}}";
+		String badScript = "class Foo { public Foo(String foo) {}}";
 		given(script.getScriptAsString()).willReturn(badScript);
 		given(script.suggestedClassName()).willReturn("someName");
 		GroovyScriptFactory factory = new GroovyScriptFactory(ScriptFactoryPostProcessor.INLINE_SCRIPT_PREFIX
@@ -210,11 +285,10 @@ public class GroovyScriptFactoryTests {
 	@Test
 	public void testScriptedClassThatHasNoPublicNoArgCtor() throws Exception {
 		ScriptSource script = mock(ScriptSource.class);
-		final String badScript = "class Foo { protected Foo() {}}";
+		String badScript = "class Foo { protected Foo() {} \n String toString() { 'X' }}";
 		given(script.getScriptAsString()).willReturn(badScript);
 		given(script.suggestedClassName()).willReturn("someName");
-		GroovyScriptFactory factory = new GroovyScriptFactory(ScriptFactoryPostProcessor.INLINE_SCRIPT_PREFIX
-				+ badScript);
+		GroovyScriptFactory factory = new GroovyScriptFactory(ScriptFactoryPostProcessor.INLINE_SCRIPT_PREFIX + badScript);
 		try {
 			factory.getScriptedObject(script);
 			fail("Must have thrown a ScriptCompilationException (no oublic no-arg ctor in scripted class).");
@@ -311,8 +385,6 @@ public class GroovyScriptFactoryTests {
 		}
 	}
 
-	@Ignore
-	// see http://build.springframework.org/browse/SPR-TRUNKQUICK-908
 	@Test
 	public void testResourceScriptFromTag() throws Exception {
 		ClassPathXmlApplicationContext ctx = new ClassPathXmlApplicationContext("groovy-with-xsd.xml", getClass());
@@ -372,8 +444,7 @@ public class GroovyScriptFactoryTests {
 		assertTrue(ctx.getBeansOfType(Messenger.class).values().contains(messenger));
 	}
 
-	@Test
-	// Test for SPR-6268
+	@Test  // SPR-6268
 	public void testRefreshableFromTagProxyTargetClass() throws Exception {
 		ApplicationContext ctx = new ClassPathXmlApplicationContext("groovy-with-xsd-proxy-target-class.xml",
 				getClass());
@@ -391,11 +462,10 @@ public class GroovyScriptFactoryTests {
 		assertNotNull(AnnotationUtils.findAnnotation(messenger.getClass(), Component.class));
 	}
 
-	@Test
-	// Test for SPR-6268
+	@Test  // SPR-6268
 	public void testProxyTargetClassNotAllowedIfNotGroovy() throws Exception {
 		try {
-			new ClassPathXmlApplicationContext("jruby-with-xsd-proxy-target-class.xml", getClass());
+			new ClassPathXmlApplicationContext("groovy-with-xsd-proxy-target-class.xml", getClass());
 		}
 		catch (BeanCreationException ex) {
 			assertTrue(ex.getMessage().contains("Cannot use proxyTargetClass=true"));
@@ -407,6 +477,51 @@ public class GroovyScriptFactoryTests {
 		ApplicationContext ctx = new ClassPathXmlApplicationContext("groovy-with-xsd.xml", getClass());
 		Map<?, Messenger> beans = ctx.getBeansOfType(Messenger.class);
 		assertEquals(4, beans.size());
+		assertTrue(ctx.getBean(MyBytecodeProcessor.class).processed.contains(
+				"org.springframework.scripting.groovy.GroovyMessenger2"));
+	}
+
+	@Test
+	public void testJsr223FromTag() throws Exception {
+		ApplicationContext ctx = new ClassPathXmlApplicationContext("groovy-with-xsd-jsr223.xml", getClass());
+		assertTrue(Arrays.asList(ctx.getBeanNamesForType(Messenger.class)).contains("messenger"));
+		Messenger messenger = (Messenger) ctx.getBean("messenger");
+		assertFalse(AopUtils.isAopProxy(messenger));
+		assertEquals("Hello World!", messenger.getMessage());
+	}
+
+	@Test
+	public void testJsr223FromTagWithInterface() throws Exception {
+		ApplicationContext ctx = new ClassPathXmlApplicationContext("groovy-with-xsd-jsr223.xml", getClass());
+		assertTrue(Arrays.asList(ctx.getBeanNamesForType(Messenger.class)).contains("messengerWithInterface"));
+		Messenger messenger = (Messenger) ctx.getBean("messengerWithInterface");
+		assertFalse(AopUtils.isAopProxy(messenger));
+	}
+
+	@Test
+	public void testRefreshableJsr223FromTag() throws Exception {
+		ApplicationContext ctx = new ClassPathXmlApplicationContext("groovy-with-xsd-jsr223.xml", getClass());
+		assertTrue(Arrays.asList(ctx.getBeanNamesForType(Messenger.class)).contains("refreshableMessenger"));
+		Messenger messenger = (Messenger) ctx.getBean("refreshableMessenger");
+		assertTrue(AopUtils.isAopProxy(messenger));
+		assertTrue(messenger instanceof Refreshable);
+		assertEquals("Hello World!", messenger.getMessage());
+	}
+
+	@Test
+	public void testInlineJsr223FromTag() throws Exception {
+		ApplicationContext ctx = new ClassPathXmlApplicationContext("groovy-with-xsd-jsr223.xml", getClass());
+		assertTrue(Arrays.asList(ctx.getBeanNamesForType(Messenger.class)).contains("inlineMessenger"));
+		Messenger messenger = (Messenger) ctx.getBean("inlineMessenger");
+		assertFalse(AopUtils.isAopProxy(messenger));
+	}
+
+	@Test
+	public void testInlineJsr223FromTagWithInterface() throws Exception {
+		ApplicationContext ctx = new ClassPathXmlApplicationContext("groovy-with-xsd-jsr223.xml", getClass());
+		assertTrue(Arrays.asList(ctx.getBeanNamesForType(Messenger.class)).contains("inlineMessengerWithInterface"));
+		Messenger messenger = (Messenger) ctx.getBean("inlineMessengerWithInterface");
+		assertFalse(AopUtils.isAopProxy(messenger));
 	}
 
 	/**
@@ -448,7 +563,7 @@ public class GroovyScriptFactoryTests {
 		testMetaClass("org/springframework/scripting/groovy/calculators-with-xsd.xml");
 	}
 
-	private void testMetaClass(final String xmlFile) {
+	private void testMetaClass(String xmlFile) {
 		// expect the exception we threw in the custom metaclass to show it got invoked
 		try {
 			ApplicationContext ctx = new ClassPathXmlApplicationContext(xmlFile);
