@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2012 the original author or authors.
+ * Copyright 2002-2016 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -20,6 +20,13 @@ public class Employee extends TestBean {
 
 	private String co;
 
+	public Employee() {
+	}
+
+	public Employee(String name) {
+		super(name);
+	}
+
 	public String getCompany() {
 		return co;
 	}
