@@ -24,6 +24,7 @@ import org.springframework.util.StringUtils;
  * {@link PropertySource} that reads keys and values from a {@code Map} object.
  *
  * @author Chris Beams
+ * @author Juergen Hoeller
  * @since 3.1
  * @see PropertiesPropertySource
  */
@@ -39,6 +40,11 @@ public class MapPropertySource extends EnumerablePropertySource<Map<String, Obje
 		return this.source.get(name);
 	}
 
+	@Override
+	public boolean containsProperty(String name) {
+		return this.source.containsKey(name);
+	}
+
 	@Override
 	public String[] getPropertyNames() {
 		return StringUtils.toStringArray(this.source.keySet());
