@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2012 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -20,22 +20,52 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.ObjectInputStream;
 
+import org.springframework.core.ConfigurableObjectInputStream;
 import org.springframework.core.NestedIOException;
 
 /**
- * Deserializer that reads an input stream using Java Serialization.
+ * A default {@link Deserializer} implementation that reads an input stream
+ * using Java serialization.
  *
  * @author Gary Russell
  * @author Mark Fisher
+ * @author Juergen Hoeller
  * @since 3.0.5
+ * @see ObjectInputStream
  */
 public class DefaultDeserializer implements Deserializer<Object> {
 
+	private final ClassLoader classLoader;
+
+
 	/**
-	 * Reads the input stream and deserializes into an object.
+	 * Create a {@code DefaultDeserializer} with default {@link ObjectInputStream}
+	 * configuration, using the "latest user-defined ClassLoader".
 	 */
+	public DefaultDeserializer() {
+		this.classLoader = null;
+	}
+
+	/**
+	 * Create a {@code DefaultDeserializer} for using an {@link ObjectInputStream}
+	 * with the given {@code ClassLoader}.
+	 * @since 4.2.1
+	 * @see ConfigurableObjectInputStream#ConfigurableObjectInputStream(InputStream, ClassLoader)
+	 */
+	public DefaultDeserializer(ClassLoader classLoader) {
+		this.classLoader = classLoader;
+	}
+
+
+	/**
+	 * Read from the supplied {@code InputStream} and deserialize the contents
+	 * into an object.
+	 * @see ObjectInputStream#readObject()
+	 */
+	@Override
+	@SuppressWarnings("resource")
 	public Object deserialize(InputStream inputStream) throws IOException {
-		ObjectInputStream objectInputStream = new ObjectInputStream(inputStream);
+		ObjectInputStream objectInputStream = new ConfigurableObjectInputStream(inputStream, this.classLoader);
 		try {
 			return objectInputStream.readObject();
 		}
