@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2016 the original author or authors.
+ * Copyright 2002-2017 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -92,20 +92,22 @@ final class AnnotationAttributesReadingVisitor extends RecursiveAnnotationAttrib
 	}
 
 	private void recursivelyCollectMetaAnnotations(Set<Annotation> visited, Annotation annotation) {
-		if (!AnnotationUtils.isInJavaLangAnnotationPackage(annotation) && visited.add(annotation)) {
+		Class<? extends Annotation> annotationType = annotation.annotationType();
+		String annotationName = annotationType.getName();
+		if (!AnnotationUtils.isInJavaLangAnnotationPackage(annotationName) && visited.add(annotation)) {
 			try {
 				// Only do attribute scanning for public annotations; we'd run into
 				// IllegalAccessExceptions otherwise, and we don't want to mess with
 				// accessibility in a SecurityManager environment.
-				if (Modifier.isPublic(annotation.annotationType().getModifiers())) {
-					String annotationName = annotation.annotationType().getName();
-					this.attributesMap.add(annotationName, AnnotationUtils.getAnnotationAttributes(annotation, false, true));
+				if (Modifier.isPublic(annotationType.getModifiers())) {
+					this.attributesMap.add(annotationName,
+							AnnotationUtils.getAnnotationAttributes(annotation, false, true));
 				}
-				for (Annotation metaMetaAnnotation : annotation.annotationType().getAnnotations()) {
+				for (Annotation metaMetaAnnotation : annotationType.getAnnotations()) {
 					recursivelyCollectMetaAnnotations(visited, metaMetaAnnotation);
 				}
 			}
-			catch (Exception ex) {
+			catch (Throwable ex) {
 				if (logger.isDebugEnabled()) {
 					logger.debug("Failed to introspect meta-annotations on [" + annotation + "]: " + ex);
 				}
