@@ -35,7 +35,8 @@ public class ClassMetadataReadingVisitorMemberClassTests
 			MetadataReader reader =
 				new SimpleMetadataReaderFactory().getMetadataReader(clazz.getName());
 			return reader.getAnnotationMetadata();
-		} catch (IOException ex) {
+		}
+		catch (IOException ex) {
 			throw new IllegalStateException(ex);
 		}
 	}
