@@ -21,6 +21,7 @@ import java.io.ByteArrayOutputStream;
 import java.io.InputStream;
 import java.io.OutputStream;
 import java.nio.charset.Charset;
+import java.util.Arrays;
 import java.util.Random;
 import java.util.UUID;
 
@@ -93,6 +94,15 @@ public class StreamUtilsTests {
 		verify(out, never()).close();
 	}
 
+	@Test
+	public void copyRange() throws Exception {
+		ByteArrayOutputStream out = spy(new ByteArrayOutputStream());
+		StreamUtils.copyRange(new ByteArrayInputStream(bytes), out, 0, 100);
+		byte[] range = Arrays.copyOfRange(bytes, 0, 101);
+		assertThat(out.toByteArray(), equalTo(range));
+		verify(out, never()).close();
+	}
+
 	@Test
 	public void nonClosingInputStream() throws Exception {
 		InputStream source = mock(InputStream.class);
