@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2014 the original author or authors.
+ * Copyright 2002-2016 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -27,8 +27,7 @@ import javax.xml.transform.Result;
 public class StaxEventHandlerTests extends AbstractStaxHandlerTestCase {
 
 	@Override
-	protected AbstractStaxHandler createStaxHandler(Result result)
-			throws XMLStreamException {
+	protected AbstractStaxHandler createStaxHandler(Result result) throws XMLStreamException {
 		XMLOutputFactory outputFactory = XMLOutputFactory.newFactory();
 		XMLEventWriter eventWriter = outputFactory.createXMLEventWriter(result);
 		return new StaxEventHandler(eventWriter);
