@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2012 the original author or authors.
+ * Copyright 2002-2016 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -13,9 +13,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
+
 package org.springframework.expression.spel.ast;
 
+import org.springframework.asm.MethodVisitor;
 import org.springframework.expression.TypedValue;
+import org.springframework.expression.spel.CodeFlow;
 
 /**
  * Expression language AST node that represents an integer literal.
@@ -27,14 +30,38 @@ public class IntLiteral extends Literal {
 
 	private final TypedValue value;
 
-	IntLiteral(String payload, int pos, int value) {
+
+	public IntLiteral(String payload, int pos, int value) {
 		super(payload, pos);
 		this.value = new TypedValue(value);
+		this.exitTypeDescriptor = "I";
 	}
 
+
 	@Override
 	public TypedValue getLiteralValue() {
 		return this.value;
 	}
 
+	@Override
+	public boolean isCompilable() {
+		return true;
+	}
+	
+	@Override
+	public void generateCode(MethodVisitor mv, CodeFlow cf) {
+		int intValue = (Integer) this.value.getValue();
+		if (intValue == -1) {
+			// Not sure we can get here because -1 is OpMinus
+			mv.visitInsn(ICONST_M1);
+		}
+		else if (intValue >= 0 && intValue < 6) {
+			mv.visitInsn(ICONST_0 + intValue);
+		}
+		else {
+			mv.visitLdcInsn(intValue);
+		}
+		cf.pushDescriptor(this.exitTypeDescriptor);
+	}
+
 }
