@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2014 the original author or authors.
+ * Copyright 2002-2017 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -20,6 +20,7 @@ import java.lang.reflect.InvocationHandler;
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
 import java.lang.reflect.Proxy;
+import java.sql.BatchUpdateException;
 import java.sql.CallableStatement;
 import java.sql.Connection;
 import java.sql.PreparedStatement;
@@ -49,6 +50,7 @@ import org.springframework.jdbc.support.nativejdbc.NativeJdbcExtractor;
 import org.springframework.jdbc.support.rowset.SqlRowSet;
 import org.springframework.util.Assert;
 import org.springframework.util.LinkedCaseInsensitiveMap;
+import org.springframework.util.StringUtils;
 
 /**
  * <b>This is the central class in the JDBC core package.</b>
@@ -79,6 +81,8 @@ import org.springframework.util.LinkedCaseInsensitiveMap;
  * <p>All SQL operations performed by this class are logged at debug level,
  * using "org.springframework.jdbc.core.JdbcTemplate" as log category.
  *
+ * <p><b>NOTE: An instance of this class is thread-safe once configured.</b>
+ *
  * @author Rod Johnson
  * @author Juergen Hoeller
  * @author Thomas Risberg
@@ -107,26 +111,26 @@ public class JdbcTemplate extends JdbcAccessor implements JdbcOperations {
 	private boolean ignoreWarnings = true;
 
 	/**
-	 * If this variable is set to a non-zero value, it will be used for setting the
+	 * If this variable is set to a non-negative value, it will be used for setting the
 	 * fetchSize property on statements used for query processing.
 	 */
-	private int fetchSize = 0;
+	private int fetchSize = -1;
 
 	/**
-	 * If this variable is set to a non-zero value, it will be used for setting the
+	 * If this variable is set to a non-negative value, it will be used for setting the
 	 * maxRows property on statements used for query processing.
 	 */
-	private int maxRows = 0;
+	private int maxRows = -1;
 
 	/**
-	 * If this variable is set to a non-zero value, it will be used for setting the
+	 * If this variable is set to a non-negative value, it will be used for setting the
 	 * queryTimeout property on statements used for query processing.
 	 */
-	private int queryTimeout = 0;
+	private int queryTimeout = -1;
 
 	/**
-	 * If this variable is set to true then all results checking will be bypassed for any
-	 * callable statement processing.  This can be used to avoid a bug in some older Oracle
+	 * If this variable is set to true, then all results checking will be bypassed for any
+	 * callable statement processing. This can be used to avoid a bug in some older Oracle
 	 * JDBC drivers like 10.1.0.2.
 	 */
 	private boolean skipResultsProcessing = false;
@@ -141,8 +145,7 @@ public class JdbcTemplate extends JdbcAccessor implements JdbcOperations {
 
 	/**
 	 * If this variable is set to true then execution of a CallableStatement will return
-	 * the results in a Map that uses case insensitive names for the parameters if
-	 * Commons Collections is available on the classpath.
+	 * the results in a Map that uses case insensitive names for the parameters.
 	 */
 	private boolean resultsMapCaseInsensitive = false;
 
@@ -216,11 +219,14 @@ public class JdbcTemplate extends JdbcAccessor implements JdbcOperations {
 	}
 
 	/**
-	 * Set the fetch size for this JdbcTemplate. This is important for processing
-	 * large result sets: Setting this higher than the default value will increase
-	 * processing speed at the cost of memory consumption; setting this lower can
-	 * avoid transferring row data that will never be read by the application.
-	 * <p>Default is 0, indicating to use the JDBC driver's default.
+	 * Set the fetch size for this JdbcTemplate. This is important for processing large
+	 * result sets: Setting this higher than the default value will increase processing
+	 * speed at the cost of memory consumption; setting this lower can avoid transferring
+	 * row data that will never be read by the application.
+	 * <p>Default is -1, indicating to use the JDBC driver's default configuration
+	 * (i.e. to not pass a specific fetch size setting on to the driver).
+	 * <p>Note: As of 4.3, negative values other than -1 will get passed on to the
+	 * driver, since e.g. MySQL supports special behavior for {@code Integer.MIN_VALUE}.
 	 * @see java.sql.Statement#setFetchSize
 	 */
 	public void setFetchSize(int fetchSize) {
@@ -235,12 +241,15 @@ public class JdbcTemplate extends JdbcAccessor implements JdbcOperations {
 	}
 
 	/**
-	 * Set the maximum number of rows for this JdbcTemplate. This is important
-	 * for processing subsets of large result sets, avoiding to read and hold
-	 * the entire result set in the database or in the JDBC driver if we're
-	 * never interested in the entire result in the first place (for example,
-	 * when performing searches that might return a large number of matches).
-	 * <p>Default is 0, indicating to use the JDBC driver's default.
+	 * Set the maximum number of rows for this JdbcTemplate. This is important for
+	 * processing subsets of large result sets, avoiding to read and hold the entire
+	 * result set in the database or in the JDBC driver if we're never interested in
+	 * the entire result in the first place (for example, when performing searches
+	 * that might return a large number of matches).
+	 * <p>Default is -1, indicating to use the JDBC driver's default configuration
+	 * (i.e. to not pass a specific max rows setting on to the driver).
+	 * <p>Note: As of 4.3, negative values other than -1 will get passed on to the
+	 * driver, in sync with {@link #setFetchSize}'s support for special MySQL values.
 	 * @see java.sql.Statement#setMaxRows
 	 */
 	public void setMaxRows(int maxRows) {
@@ -256,7 +265,8 @@ public class JdbcTemplate extends JdbcAccessor implements JdbcOperations {
 
 	/**
 	 * Set the query timeout for statements that this JdbcTemplate executes.
-	 * <p>Default is 0, indicating to use the JDBC driver's default.
+	 * <p>Default is -1, indicating to use the JDBC driver's default
+	 * (i.e. to not pass a specific query timeout setting on the driver).
 	 * <p>Note: Any timeout specified here will be overridden by the remaining
 	 * transaction timeout when executing within a transaction that has a
 	 * timeout specified at the transaction level.
@@ -325,6 +335,7 @@ public class JdbcTemplate extends JdbcAccessor implements JdbcOperations {
 	// Methods dealing with a plain java.sql.Connection
 	//-------------------------------------------------------------------------
 
+	@Override
 	public <T> T execute(ConnectionCallback<T> action) throws DataAccessException {
 		Assert.notNull(action, "Callback object must not be null");
 
@@ -376,6 +387,7 @@ public class JdbcTemplate extends JdbcAccessor implements JdbcOperations {
 	// Methods dealing with static SQL (java.sql.Statement)
 	//-------------------------------------------------------------------------
 
+	@Override
 	public <T> T execute(StatementCallback<T> action) throws DataAccessException {
 		Assert.notNull(action, "Callback object must not be null");
 
@@ -412,29 +424,37 @@ public class JdbcTemplate extends JdbcAccessor implements JdbcOperations {
 		}
 	}
 
+	@Override
 	public void execute(final String sql) throws DataAccessException {
 		if (logger.isDebugEnabled()) {
 			logger.debug("Executing SQL statement [" + sql + "]");
 		}
+
 		class ExecuteStatementCallback implements StatementCallback<Object>, SqlProvider {
+			@Override
 			public Object doInStatement(Statement stmt) throws SQLException {
 				stmt.execute(sql);
 				return null;
 			}
+			@Override
 			public String getSql() {
 				return sql;
 			}
 		}
+
 		execute(new ExecuteStatementCallback());
 	}
 
+	@Override
 	public <T> T query(final String sql, final ResultSetExtractor<T> rse) throws DataAccessException {
 		Assert.notNull(sql, "SQL must not be null");
 		Assert.notNull(rse, "ResultSetExtractor must not be null");
 		if (logger.isDebugEnabled()) {
 			logger.debug("Executing SQL query [" + sql + "]");
 		}
+
 		class QueryStatementCallback implements StatementCallback<T>, SqlProvider {
+			@Override
 			public T doInStatement(Statement stmt) throws SQLException {
 				ResultSet rs = null;
 				try {
@@ -449,64 +469,65 @@ public class JdbcTemplate extends JdbcAccessor implements JdbcOperations {
 					JdbcUtils.closeResultSet(rs);
 				}
 			}
+			@Override
 			public String getSql() {
 				return sql;
 			}
 		}
+
 		return execute(new QueryStatementCallback());
 	}
 
+	@Override
 	public void query(String sql, RowCallbackHandler rch) throws DataAccessException {
 		query(sql, new RowCallbackHandlerResultSetExtractor(rch));
 	}
 
+	@Override
 	public <T> List<T> query(String sql, RowMapper<T> rowMapper) throws DataAccessException {
 		return query(sql, new RowMapperResultSetExtractor<T>(rowMapper));
 	}
 
+	@Override
 	public Map<String, Object> queryForMap(String sql) throws DataAccessException {
 		return queryForObject(sql, getColumnMapRowMapper());
 	}
 
+	@Override
 	public <T> T queryForObject(String sql, RowMapper<T> rowMapper) throws DataAccessException {
 		List<T> results = query(sql, rowMapper);
 		return DataAccessUtils.requiredSingleResult(results);
 	}
 
+	@Override
 	public <T> T queryForObject(String sql, Class<T> requiredType) throws DataAccessException {
 		return queryForObject(sql, getSingleColumnRowMapper(requiredType));
 	}
 
-	@Deprecated
-	public long queryForLong(String sql) throws DataAccessException {
-		Number number = queryForObject(sql, Long.class);
-		return (number != null ? number.longValue() : 0);
-	}
-
-	@Deprecated
-	public int queryForInt(String sql) throws DataAccessException {
-		Number number = queryForObject(sql, Integer.class);
-		return (number != null ? number.intValue() : 0);
-	}
-
+	@Override
 	public <T> List<T> queryForList(String sql, Class<T> elementType) throws DataAccessException {
 		return query(sql, getSingleColumnRowMapper(elementType));
 	}
 
+	@Override
 	public List<Map<String, Object>> queryForList(String sql) throws DataAccessException {
 		return query(sql, getColumnMapRowMapper());
 	}
 
+	@Override
 	public SqlRowSet queryForRowSet(String sql) throws DataAccessException {
 		return query(sql, new SqlRowSetResultSetExtractor());
 	}
 
+	@Override
 	public int update(final String sql) throws DataAccessException {
 		Assert.notNull(sql, "SQL must not be null");
 		if (logger.isDebugEnabled()) {
 			logger.debug("Executing SQL update [" + sql + "]");
 		}
+
 		class UpdateStatementCallback implements StatementCallback<Integer>, SqlProvider {
+			@Override
 			public Integer doInStatement(Statement stmt) throws SQLException {
 				int rows = stmt.executeUpdate(sql);
 				if (logger.isDebugEnabled()) {
@@ -514,28 +535,49 @@ public class JdbcTemplate extends JdbcAccessor implements JdbcOperations {
 				}
 				return rows;
 			}
+			@Override
 			public String getSql() {
 				return sql;
 			}
 		}
+
 		return execute(new UpdateStatementCallback());
 	}
 
-	public int[] batchUpdate(final String[] sql) throws DataAccessException {
+	@Override
+	public int[] batchUpdate(final String... sql) throws DataAccessException {
 		Assert.notEmpty(sql, "SQL array must not be empty");
 		if (logger.isDebugEnabled()) {
 			logger.debug("Executing SQL batch update of " + sql.length + " statements");
 		}
+
 		class BatchUpdateStatementCallback implements StatementCallback<int[]>, SqlProvider {
+
 			private String currSql;
+
+			@Override
 			public int[] doInStatement(Statement stmt) throws SQLException, DataAccessException {
 				int[] rowsAffected = new int[sql.length];
 				if (JdbcUtils.supportsBatchUpdates(stmt.getConnection())) {
 					for (String sqlStmt : sql) {
-						this.currSql = sqlStmt;
+						this.currSql = appendSql(this.currSql, sqlStmt);
 						stmt.addBatch(sqlStmt);
 					}
-					rowsAffected = stmt.executeBatch();
+					try {
+						rowsAffected = stmt.executeBatch();
+					}
+					catch (BatchUpdateException ex) {
+						String batchExceptionSql = null;
+						for (int i = 0; i < ex.getUpdateCounts().length; i++) {
+							if (ex.getUpdateCounts()[i] == Statement.EXECUTE_FAILED) {
+								batchExceptionSql = appendSql(batchExceptionSql, sql[i]);
+							}
+						}
+						if (StringUtils.hasLength(batchExceptionSql)) {
+							this.currSql = batchExceptionSql;
+						}
+						throw ex;
+					}
 				}
 				else {
 					for (int i = 0; i < sql.length; i++) {
@@ -550,10 +592,17 @@ public class JdbcTemplate extends JdbcAccessor implements JdbcOperations {
 				}
 				return rowsAffected;
 			}
+
+			private String appendSql(String sql, String statement) {
+				return (StringUtils.isEmpty(sql) ? statement : sql + "; " + statement);
+			}
+
+			@Override
 			public String getSql() {
 				return this.currSql;
 			}
 		}
+
 		return execute(new BatchUpdateStatementCallback());
 	}
 
@@ -562,6 +611,7 @@ public class JdbcTemplate extends JdbcAccessor implements JdbcOperations {
 	// Methods dealing with prepared statements
 	//-------------------------------------------------------------------------
 
+	@Override
 	public <T> T execute(PreparedStatementCreator psc, PreparedStatementCallback<T> action)
 			throws DataAccessException {
 
@@ -613,6 +663,7 @@ public class JdbcTemplate extends JdbcAccessor implements JdbcOperations {
 		}
 	}
 
+	@Override
 	public <T> T execute(String sql, PreparedStatementCallback<T> action) throws DataAccessException {
 		return execute(new SimplePreparedStatementCreator(sql), action);
 	}
@@ -637,6 +688,7 @@ public class JdbcTemplate extends JdbcAccessor implements JdbcOperations {
 		logger.debug("Executing prepared SQL query");
 
 		return execute(psc, new PreparedStatementCallback<T>() {
+			@Override
 			public T doInPreparedStatement(PreparedStatement ps) throws SQLException {
 				ResultSet rs = null;
 				try {
@@ -660,66 +712,82 @@ public class JdbcTemplate extends JdbcAccessor implements JdbcOperations {
 		});
 	}
 
+	@Override
 	public <T> T query(PreparedStatementCreator psc, ResultSetExtractor<T> rse) throws DataAccessException {
 		return query(psc, null, rse);
 	}
 
+	@Override
 	public <T> T query(String sql, PreparedStatementSetter pss, ResultSetExtractor<T> rse) throws DataAccessException {
 		return query(new SimplePreparedStatementCreator(sql), pss, rse);
 	}
 
+	@Override
 	public <T> T query(String sql, Object[] args, int[] argTypes, ResultSetExtractor<T> rse) throws DataAccessException {
 		return query(sql, newArgTypePreparedStatementSetter(args, argTypes), rse);
 	}
 
+	@Override
 	public <T> T query(String sql, Object[] args, ResultSetExtractor<T> rse) throws DataAccessException {
 		return query(sql, newArgPreparedStatementSetter(args), rse);
 	}
 
+	@Override
 	public <T> T query(String sql, ResultSetExtractor<T> rse, Object... args) throws DataAccessException {
 		return query(sql, newArgPreparedStatementSetter(args), rse);
 	}
 
+	@Override
 	public void query(PreparedStatementCreator psc, RowCallbackHandler rch) throws DataAccessException {
 		query(psc, new RowCallbackHandlerResultSetExtractor(rch));
 	}
 
+	@Override
 	public void query(String sql, PreparedStatementSetter pss, RowCallbackHandler rch) throws DataAccessException {
 		query(sql, pss, new RowCallbackHandlerResultSetExtractor(rch));
 	}
 
+	@Override
 	public void query(String sql, Object[] args, int[] argTypes, RowCallbackHandler rch) throws DataAccessException {
 		query(sql, newArgTypePreparedStatementSetter(args, argTypes), rch);
 	}
 
+	@Override
 	public void query(String sql, Object[] args, RowCallbackHandler rch) throws DataAccessException {
 		query(sql, newArgPreparedStatementSetter(args), rch);
 	}
 
+	@Override
 	public void query(String sql, RowCallbackHandler rch, Object... args) throws DataAccessException {
 		query(sql, newArgPreparedStatementSetter(args), rch);
 	}
 
+	@Override
 	public <T> List<T> query(PreparedStatementCreator psc, RowMapper<T> rowMapper) throws DataAccessException {
 		return query(psc, new RowMapperResultSetExtractor<T>(rowMapper));
 	}
 
+	@Override
 	public <T> List<T> query(String sql, PreparedStatementSetter pss, RowMapper<T> rowMapper) throws DataAccessException {
 		return query(sql, pss, new RowMapperResultSetExtractor<T>(rowMapper));
 	}
 
+	@Override
 	public <T> List<T> query(String sql, Object[] args, int[] argTypes, RowMapper<T> rowMapper) throws DataAccessException {
 		return query(sql, args, argTypes, new RowMapperResultSetExtractor<T>(rowMapper));
 	}
 
+	@Override
 	public <T> List<T> query(String sql, Object[] args, RowMapper<T> rowMapper) throws DataAccessException {
 		return query(sql, args, new RowMapperResultSetExtractor<T>(rowMapper));
 	}
 
+	@Override
 	public <T> List<T> query(String sql, RowMapper<T> rowMapper, Object... args) throws DataAccessException {
 		return query(sql, args, new RowMapperResultSetExtractor<T>(rowMapper));
 	}
 
+	@Override
 	public <T> T queryForObject(String sql, Object[] args, int[] argTypes, RowMapper<T> rowMapper)
 			throws DataAccessException {
 
@@ -727,86 +795,76 @@ public class JdbcTemplate extends JdbcAccessor implements JdbcOperations {
 		return DataAccessUtils.requiredSingleResult(results);
 	}
 
+	@Override
 	public <T> T queryForObject(String sql, Object[] args, RowMapper<T> rowMapper) throws DataAccessException {
 		List<T> results = query(sql, args, new RowMapperResultSetExtractor<T>(rowMapper, 1));
 		return DataAccessUtils.requiredSingleResult(results);
 	}
 
+	@Override
 	public <T> T queryForObject(String sql, RowMapper<T> rowMapper, Object... args) throws DataAccessException {
 		List<T> results = query(sql, args, new RowMapperResultSetExtractor<T>(rowMapper, 1));
 		return DataAccessUtils.requiredSingleResult(results);
 	}
 
+	@Override
 	public <T> T queryForObject(String sql, Object[] args, int[] argTypes, Class<T> requiredType)
 			throws DataAccessException {
 
 		return queryForObject(sql, args, argTypes, getSingleColumnRowMapper(requiredType));
 	}
 
+	@Override
 	public <T> T queryForObject(String sql, Object[] args, Class<T> requiredType) throws DataAccessException {
 		return queryForObject(sql, args, getSingleColumnRowMapper(requiredType));
 	}
 
+	@Override
 	public <T> T queryForObject(String sql, Class<T> requiredType, Object... args) throws DataAccessException {
 		return queryForObject(sql, args, getSingleColumnRowMapper(requiredType));
 	}
 
+	@Override
 	public Map<String, Object> queryForMap(String sql, Object[] args, int[] argTypes) throws DataAccessException {
 		return queryForObject(sql, args, argTypes, getColumnMapRowMapper());
 	}
 
+	@Override
 	public Map<String, Object> queryForMap(String sql, Object... args) throws DataAccessException {
 		return queryForObject(sql, args, getColumnMapRowMapper());
 	}
 
-	@Deprecated
-	public long queryForLong(String sql, Object[] args, int[] argTypes) throws DataAccessException {
-		Number number = queryForObject(sql, args, argTypes, Long.class);
-		return (number != null ? number.longValue() : 0);
-	}
-
-	@Deprecated
-	public long queryForLong(String sql, Object... args) throws DataAccessException {
-		Number number = queryForObject(sql, args, Long.class);
-		return (number != null ? number.longValue() : 0);
-	}
-
-	@Deprecated
-	public int queryForInt(String sql, Object[] args, int[] argTypes) throws DataAccessException {
-		Number number = queryForObject(sql, args, argTypes, Integer.class);
-		return (number != null ? number.intValue() : 0);
-	}
-
-	@Deprecated
-	public int queryForInt(String sql, Object... args) throws DataAccessException {
-		Number number = queryForObject(sql, args, Integer.class);
-		return (number != null ? number.intValue() : 0);
-	}
-
+	@Override
 	public <T> List<T> queryForList(String sql, Object[] args, int[] argTypes, Class<T> elementType) throws DataAccessException {
 		return query(sql, args, argTypes, getSingleColumnRowMapper(elementType));
 	}
 
+	@Override
 	public <T> List<T> queryForList(String sql, Object[] args, Class<T> elementType) throws DataAccessException {
 		return query(sql, args, getSingleColumnRowMapper(elementType));
 	}
 
+	@Override
 	public <T> List<T> queryForList(String sql, Class<T> elementType, Object... args) throws DataAccessException {
 		return query(sql, args, getSingleColumnRowMapper(elementType));
 	}
 
+	@Override
 	public List<Map<String, Object>> queryForList(String sql, Object[] args, int[] argTypes) throws DataAccessException {
 		return query(sql, args, argTypes, getColumnMapRowMapper());
 	}
 
+	@Override
 	public List<Map<String, Object>> queryForList(String sql, Object... args) throws DataAccessException {
 		return query(sql, args, getColumnMapRowMapper());
 	}
 
+	@Override
 	public SqlRowSet queryForRowSet(String sql, Object[] args, int[] argTypes) throws DataAccessException {
 		return query(sql, args, argTypes, new SqlRowSetResultSetExtractor());
 	}
 
+	@Override
 	public SqlRowSet queryForRowSet(String sql, Object... args) throws DataAccessException {
 		return query(sql, args, new SqlRowSetResultSetExtractor());
 	}
@@ -816,6 +874,7 @@ public class JdbcTemplate extends JdbcAccessor implements JdbcOperations {
 
 		logger.debug("Executing prepared SQL update");
 		return execute(psc, new PreparedStatementCallback<Integer>() {
+			@Override
 			public Integer doInPreparedStatement(PreparedStatement ps) throws SQLException {
 				try {
 					if (pss != null) {
@@ -836,10 +895,12 @@ public class JdbcTemplate extends JdbcAccessor implements JdbcOperations {
 		});
 	}
 
+	@Override
 	public int update(PreparedStatementCreator psc) throws DataAccessException {
 		return update(psc, (PreparedStatementSetter) null);
 	}
 
+	@Override
 	public int update(final PreparedStatementCreator psc, final KeyHolder generatedKeyHolder)
 			throws DataAccessException {
 
@@ -847,6 +908,7 @@ public class JdbcTemplate extends JdbcAccessor implements JdbcOperations {
 		logger.debug("Executing SQL update and returning generated keys");
 
 		return execute(psc, new PreparedStatementCallback<Integer>() {
+			@Override
 			public Integer doInPreparedStatement(PreparedStatement ps) throws SQLException {
 				int rows = ps.executeUpdate();
 				List<Map<String, Object>> generatedKeys = generatedKeyHolder.getKeyList();
@@ -870,24 +932,29 @@ public class JdbcTemplate extends JdbcAccessor implements JdbcOperations {
 		});
 	}
 
+	@Override
 	public int update(String sql, PreparedStatementSetter pss) throws DataAccessException {
 		return update(new SimplePreparedStatementCreator(sql), pss);
 	}
 
+	@Override
 	public int update(String sql, Object[] args, int[] argTypes) throws DataAccessException {
 		return update(sql, newArgTypePreparedStatementSetter(args, argTypes));
 	}
 
+	@Override
 	public int update(String sql, Object... args) throws DataAccessException {
 		return update(sql, newArgPreparedStatementSetter(args));
 	}
 
+	@Override
 	public int[] batchUpdate(String sql, final BatchPreparedStatementSetter pss) throws DataAccessException {
 		if (logger.isDebugEnabled()) {
 			logger.debug("Executing SQL batch update [" + sql + "]");
 		}
 
 		return execute(sql, new PreparedStatementCallback<int[]>() {
+			@Override
 			public int[] doInPreparedStatement(PreparedStatement ps) throws SQLException {
 				try {
 					int batchSize = pss.getBatchSize();
@@ -929,14 +996,17 @@ public class JdbcTemplate extends JdbcAccessor implements JdbcOperations {
 		});
 	}
 
+	@Override
 	public int[] batchUpdate(String sql, List<Object[]> batchArgs) throws DataAccessException {
 		return batchUpdate(sql, batchArgs, new int[0]);
 	}
 
+	@Override
 	public int[] batchUpdate(String sql, List<Object[]> batchArgs, int[] argTypes) throws DataAccessException {
 		return BatchUpdateUtils.executeBatchUpdate(sql, batchArgs, argTypes, this);
 	}
 
+	@Override
 	public <T> int[][] batchUpdate(String sql, final Collection<T> batchArgs, final int batchSize,
 			final ParameterizedPreparedStatementSetter<T> pss) throws DataAccessException {
 
@@ -944,6 +1014,7 @@ public class JdbcTemplate extends JdbcAccessor implements JdbcOperations {
 			logger.debug("Executing SQL batch update [" + sql + "] with a batch size of " + batchSize);
 		}
 		return execute(sql, new PreparedStatementCallback<int[][]>() {
+			@Override
 			public int[][] doInPreparedStatement(PreparedStatement ps) throws SQLException {
 				List<int[]> rowsAffected = new ArrayList<int[]>();
 				try {
@@ -977,7 +1048,8 @@ public class JdbcTemplate extends JdbcAccessor implements JdbcOperations {
 						result[i] = rowsAffected.get(i);
 					}
 					return result;
-				} finally {
+				}
+				finally {
 					if (pss instanceof ParameterDisposer) {
 						((ParameterDisposer) pss).cleanupParameters();
 					}
@@ -990,6 +1062,7 @@ public class JdbcTemplate extends JdbcAccessor implements JdbcOperations {
 	// Methods dealing with callable statements
 	//-------------------------------------------------------------------------
 
+	@Override
 	public <T> T execute(CallableStatementCreator csc, CallableStatementCallback<T> action)
 			throws DataAccessException {
 
@@ -1040,10 +1113,12 @@ public class JdbcTemplate extends JdbcAccessor implements JdbcOperations {
 		}
 	}
 
+	@Override
 	public <T> T execute(String callString, CallableStatementCallback<T> action) throws DataAccessException {
 		return execute(new SimpleCallableStatementCreator(callString), action);
 	}
 
+	@Override
 	public Map<String, Object> call(CallableStatementCreator csc, List<SqlParameter> declaredParameters)
 			throws DataAccessException {
 
@@ -1064,6 +1139,7 @@ public class JdbcTemplate extends JdbcAccessor implements JdbcOperations {
 			}
 		}
 		return execute(csc, new CallableStatementCallback<Map<String, Object>>() {
+			@Override
 			public Map<String, Object> doInCallableStatement(CallableStatement cs) throws SQLException {
 				boolean retVal = cs.execute();
 				int updateCount = cs.getUpdateCount();
@@ -1107,7 +1183,7 @@ public class JdbcTemplate extends JdbcAccessor implements JdbcOperations {
 					else {
 						if (!this.skipUndeclaredResults) {
 							String rsName = RETURN_RESULT_SET_PREFIX + (rsIndex + 1);
-							SqlReturnResultSet undeclaredRsParam = new SqlReturnResultSet(rsName, new ColumnMapRowMapper());
+							SqlReturnResultSet undeclaredRsParam = new SqlReturnResultSet(rsName, getColumnMapRowMapper());
 							if (logger.isDebugEnabled()) {
 								logger.debug("Added default SqlReturnResultSet parameter named '" + rsName + "'");
 							}
@@ -1172,7 +1248,7 @@ public class JdbcTemplate extends JdbcAccessor implements JdbcOperations {
 						}
 						else {
 							String rsName = outParam.getName();
-							SqlReturnResultSet rsParam = new SqlReturnResultSet(rsName, new ColumnMapRowMapper());
+							SqlReturnResultSet rsParam = new SqlReturnResultSet(rsName, getColumnMapRowMapper());
 							returnedResults.putAll(processResultSet((ResultSet) out, rsParam));
 							if (logger.isDebugEnabled()) {
 								logger.debug("Added default SqlReturnResultSet parameter named '" + rsName + "'");
@@ -1197,11 +1273,14 @@ public class JdbcTemplate extends JdbcAccessor implements JdbcOperations {
 	 * @param param the corresponding stored procedure parameter
 	 * @return Map that contains returned results
 	 */
-	@SuppressWarnings({ "unchecked", "rawtypes" })
-	protected Map<String, Object> processResultSet(ResultSet rs, ResultSetSupportingSqlParameter param) throws SQLException {
+	@SuppressWarnings({"unchecked", "rawtypes"})
+	protected Map<String, Object> processResultSet(ResultSet rs, ResultSetSupportingSqlParameter param)
+			throws SQLException {
+
 		if (rs == null) {
 			return Collections.emptyMap();
 		}
+
 		Map<String, Object> returnedResults = new HashMap<String, Object>();
 		try {
 			ResultSet rsToUse = rs;
@@ -1254,11 +1333,13 @@ public class JdbcTemplate extends JdbcAccessor implements JdbcOperations {
 	}
 
 	/**
-	 * Create a Map instance to be used as results map.
-	 * <p>If "isResultsMapCaseInsensitive" has been set to true,
-	 * a linked case-insensitive Map will be created.
+	 * Create a Map instance to be used as the results map.
+	 * <p>If {@link #resultsMapCaseInsensitive} has been set to true,
+	 * a {@link LinkedCaseInsensitiveMap} will be created; otherwise, a
+	 * {@link LinkedHashMap} will be created.
 	 * @return the results Map instance
 	 * @see #setResultsMapCaseInsensitive
+	 * @see #isResultsMapCaseInsensitive
 	 */
 	protected Map<String, Object> createResultsMap() {
 		if (isResultsMapCaseInsensitive()) {
@@ -1281,11 +1362,11 @@ public class JdbcTemplate extends JdbcAccessor implements JdbcOperations {
 	 */
 	protected void applyStatementSettings(Statement stmt) throws SQLException {
 		int fetchSize = getFetchSize();
-		if (fetchSize > 0) {
+		if (fetchSize != -1) {
 			stmt.setFetchSize(fetchSize);
 		}
 		int maxRows = getMaxRows();
-		if (maxRows > 0) {
+		if (maxRows != -1) {
 			stmt.setMaxRows(maxRows);
 		}
 		DataSourceUtils.applyTimeout(stmt, getDataSource(), getQueryTimeout());
@@ -1378,6 +1459,7 @@ public class JdbcTemplate extends JdbcAccessor implements JdbcOperations {
 			this.target = target;
 		}
 
+		@Override
 		@SuppressWarnings("rawtypes")
 		public Object invoke(Object proxy, Method method, Object[] args) throws Throwable {
 			// Invocation on ConnectionProxy interface coming in...
@@ -1391,12 +1473,12 @@ public class JdbcTemplate extends JdbcAccessor implements JdbcOperations {
 				return System.identityHashCode(proxy);
 			}
 			else if (method.getName().equals("unwrap")) {
-				if (((Class) args[0]).isInstance(proxy)) {
+				if (((Class<?>) args[0]).isInstance(proxy)) {
 					return proxy;
 				}
 			}
 			else if (method.getName().equals("isWrapperFor")) {
-				if (((Class) args[0]).isInstance(proxy)) {
+				if (((Class<?>) args[0]).isInstance(proxy)) {
 					return true;
 				}
 			}
@@ -1443,10 +1525,12 @@ public class JdbcTemplate extends JdbcAccessor implements JdbcOperations {
 			this.sql = sql;
 		}
 
+		@Override
 		public PreparedStatement createPreparedStatement(Connection con) throws SQLException {
 			return con.prepareStatement(this.sql);
 		}
 
+		@Override
 		public String getSql() {
 			return this.sql;
 		}
@@ -1465,10 +1549,12 @@ public class JdbcTemplate extends JdbcAccessor implements JdbcOperations {
 			this.callString = callString;
 		}
 
+		@Override
 		public CallableStatement createCallableStatement(Connection con) throws SQLException {
 			return con.prepareCall(this.callString);
 		}
 
+		@Override
 		public String getSql() {
 			return this.callString;
 		}
@@ -1488,6 +1574,7 @@ public class JdbcTemplate extends JdbcAccessor implements JdbcOperations {
 			this.rch = rch;
 		}
 
+		@Override
 		public Object extractData(ResultSet rs) throws SQLException {
 			while (rs.next()) {
 				this.rch.processRow(rs);
