@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2014 the original author or authors.
+ * Copyright 2002-2017 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -320,19 +320,13 @@ public class NamedParameterJdbcTemplate implements NamedParameterJdbcOperations
 
 	@Override
 	public int[] batchUpdate(String sql, Map<String, ?>[] batchValues) {
-		SqlParameterSource[] batchArgs = new SqlParameterSource[batchValues.length];
-		int i = 0;
-		for (Map<String, ?> values : batchValues) {
-			batchArgs[i] = new MapSqlParameterSource(values);
-			i++;
-		}
-		return batchUpdate(sql, batchArgs);
+		return batchUpdate(sql, SqlParameterSourceUtils.createBatch(batchValues));
 	}
 
 	@Override
 	public int[] batchUpdate(String sql, SqlParameterSource[] batchArgs) {
-		ParsedSql parsedSql = getParsedSql(sql);
-		return NamedParameterBatchUpdateUtils.executeBatchUpdateWithNamedParameters(parsedSql, batchArgs, getJdbcOperations());
+		return NamedParameterBatchUpdateUtils.executeBatchUpdateWithNamedParameters(
+				getParsedSql(sql), batchArgs, getJdbcOperations());
 	}
 
 	/**
