@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2014 the original author or authors.
+ * Copyright 2002-2016 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -80,7 +80,7 @@ public abstract class AbstractJdbcInsert {
 	 * Has this operation been compiled? Compilation means at least checking
 	 * that a DataSource or JdbcTemplate has been provided.
 	 */
-	private boolean compiled = false;
+	private volatile boolean compiled = false;
 
 	/** The generated string used for insert statement */
 	private String insertString;
@@ -296,7 +296,7 @@ public abstract class AbstractJdbcInsert {
 
 	/**
 	 * Is this operation "compiled"?
-	 * @return whether this operation is compiled, and ready to use.
+	 * @return whether this operation is compiled and ready to use
 	 */
 	public boolean isCompiled() {
 		return this.compiled;
@@ -335,7 +335,7 @@ public abstract class AbstractJdbcInsert {
 	 * @param args Map with parameter names and values to be used in insert
 	 * @return the number of rows affected
 	 */
-	protected int doExecute(Map<String, Object> args) {
+	protected int doExecute(Map<String, ?> args) {
 		checkCompiled();
 		List<Object> values = matchInParameterValuesWithInsertColumns(args);
 		return executeInsertInternal(values);
@@ -355,7 +355,7 @@ public abstract class AbstractJdbcInsert {
 	/**
 	 * Delegate method to execute the insert.
 	 */
-	private int executeInsertInternal(List<Object> values) {
+	private int executeInsertInternal(List<?> values) {
 		if (logger.isDebugEnabled()) {
 			logger.debug("The following parameters are used for insert " + getInsertString() + " with: " + values);
 		}
@@ -368,7 +368,7 @@ public abstract class AbstractJdbcInsert {
 	 * @param args Map with parameter names and values to be used in insert
 	 * @return the key generated by the insert
 	 */
-	protected Number doExecuteAndReturnKey(Map<String, Object> args) {
+	protected Number doExecuteAndReturnKey(Map<String, ?> args) {
 		checkCompiled();
 		List<Object> values = matchInParameterValuesWithInsertColumns(args);
 		return executeInsertAndReturnKeyInternal(values);
@@ -392,7 +392,7 @@ public abstract class AbstractJdbcInsert {
 	 * @param args Map with parameter names and values to be used in insert
 	 * @return the KeyHolder containing keys generated by the insert
 	 */
-	protected KeyHolder doExecuteAndReturnKeyHolder(Map<String, Object> args) {
+	protected KeyHolder doExecuteAndReturnKeyHolder(Map<String, ?> args) {
 		checkCompiled();
 		List<Object> values = matchInParameterValuesWithInsertColumns(args);
 		return executeInsertAndReturnKeyHolderInternal(values);
@@ -413,7 +413,7 @@ public abstract class AbstractJdbcInsert {
 	/**
 	 * Delegate method to execute the insert, generating a single key.
 	 */
-	private Number executeInsertAndReturnKeyInternal(final List<Object> values) {
+	private Number executeInsertAndReturnKeyInternal(final List<?> values) {
 		KeyHolder kh = executeInsertAndReturnKeyHolderInternal(values);
 		if (kh != null && kh.getKey() != null) {
 			return kh.getKey();
@@ -427,7 +427,7 @@ public abstract class AbstractJdbcInsert {
 	/**
 	 * Delegate method to execute the insert, generating any number of keys.
 	 */
-	private KeyHolder executeInsertAndReturnKeyHolderInternal(final List<Object> values) {
+	private KeyHolder executeInsertAndReturnKeyHolderInternal(final List<?> values) {
 		if (logger.isDebugEnabled()) {
 			logger.debug("The following parameters are used for call " + getInsertString() + " with: " + values);
 		}
@@ -435,6 +435,7 @@ public abstract class AbstractJdbcInsert {
 		if (this.tableMetaDataContext.isGetGeneratedKeysSupported()) {
 			getJdbcTemplate().update(
 					new PreparedStatementCreator() {
+						@Override
 						public PreparedStatement createPreparedStatement(Connection con) throws SQLException {
 							PreparedStatement ps = prepareStatementForGeneratedKeys(con);
 							setParameterValues(ps, values, getInsertTypes());
@@ -472,6 +473,7 @@ public abstract class AbstractJdbcInsert {
 			}
 			else {
 				getJdbcTemplate().execute(new ConnectionCallback<Object>() {
+					@Override
 					public Object doInConnection(Connection con) throws SQLException, DataAccessException {
 						// Do the insert
 						PreparedStatement ps = null;
@@ -540,14 +542,12 @@ public abstract class AbstractJdbcInsert {
 	 * @param batch array of Maps with parameter names and values to be used in batch insert
 	 * @return array of number of rows affected
 	 */
-	@SuppressWarnings({"unchecked", "rawtypes"})
-	protected int[] doExecuteBatch(Map<String, Object>[] batch) {
+	@SuppressWarnings("unchecked")
+	protected int[] doExecuteBatch(Map<String, ?>... batch) {
 		checkCompiled();
-		List[] batchValues = new ArrayList[batch.length];
-		int i = 0;
-		for (Map<String, Object> args : batch) {
-			List<Object> values = matchInParameterValuesWithInsertColumns(args);
-			batchValues[i++] = values;
+		List<List<Object>> batchValues = new ArrayList<List<Object>>(batch.length);
+		for (Map<String, ?> args : batch) {
+			batchValues.add(matchInParameterValuesWithInsertColumns(args));
 		}
 		return executeBatchInternal(batchValues);
 	}
@@ -557,14 +557,11 @@ public abstract class AbstractJdbcInsert {
 	 * @param batch array of SqlParameterSource with parameter names and values to be used in insert
 	 * @return array of number of rows affected
 	 */
-	@SuppressWarnings({"unchecked", "rawtypes"})
-	protected int[] doExecuteBatch(SqlParameterSource[] batch) {
+	protected int[] doExecuteBatch(SqlParameterSource... batch) {
 		checkCompiled();
-		List[] batchValues = new ArrayList[batch.length];
-		int i = 0;
+		List<List<Object>> batchValues = new ArrayList<List<Object>>(batch.length);
 		for (SqlParameterSource parameterSource : batch) {
-			List<Object> values = matchInParameterValuesWithInsertColumns(parameterSource);
-			batchValues[i++] = values;
+			batchValues.add(matchInParameterValuesWithInsertColumns(parameterSource));
 		}
 		return executeBatchInternal(batchValues);
 	}
@@ -572,18 +569,19 @@ public abstract class AbstractJdbcInsert {
 	/**
 	 * Delegate method to execute the batch insert.
 	 */
-	private int[] executeBatchInternal(final List<Object>[] batchValues) {
+	private int[] executeBatchInternal(final List<List<Object>> batchValues) {
 		if (logger.isDebugEnabled()) {
-			logger.debug("Executing statement " + getInsertString() + " with batch of size: " + batchValues.length);
+			logger.debug("Executing statement " + getInsertString() + " with batch of size: " + batchValues.size());
 		}
 		return getJdbcTemplate().batchUpdate(getInsertString(),
 				new BatchPreparedStatementSetter() {
+					@Override
 					public void setValues(PreparedStatement ps, int i) throws SQLException {
-						List<Object> values = batchValues[i];
-						setParameterValues(ps, values, getInsertTypes());
+						setParameterValues(ps, batchValues.get(i), getInsertTypes());
 					}
+					@Override
 					public int getBatchSize() {
-						return batchValues.length;
+						return batchValues.size();
 					}
 				});
 	}
@@ -593,7 +591,7 @@ public abstract class AbstractJdbcInsert {
 	 * @param preparedStatement the PreparedStatement
 	 * @param values the values to be set
 	 */
-	private void setParameterValues(PreparedStatement preparedStatement, List<Object> values, int[] columnTypes)
+	private void setParameterValues(PreparedStatement preparedStatement, List<?> values, int... columnTypes)
 			throws SQLException {
 
 		int colIndex = 0;
@@ -624,7 +622,7 @@ public abstract class AbstractJdbcInsert {
 	 * @param args the parameter values provided in a Map
 	 * @return Map with parameter names and values
 	 */
-	protected List<Object> matchInParameterValuesWithInsertColumns(Map<String, Object> args) {
+	protected List<Object> matchInParameterValuesWithInsertColumns(Map<String, ?> args) {
 		return this.tableMetaDataContext.matchInParameterValuesWithInsertColumns(args);
 	}
 
