@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2014 the original author or authors.
+ * Copyright 2002-2016 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,6 +16,8 @@
 
 package org.springframework.jdbc.config;
 
+import java.util.function.Predicate;
+
 import javax.sql.DataSource;
 
 import org.junit.Rule;
@@ -31,6 +33,7 @@ import org.springframework.context.support.ClassPathXmlApplicationContext;
 import org.springframework.core.io.ClassPathResource;
 import org.springframework.jdbc.BadSqlGrammarException;
 import org.springframework.jdbc.core.JdbcTemplate;
+import org.springframework.jdbc.datasource.AbstractDriverBasedDataSource;
 import org.springframework.jdbc.datasource.embedded.EmbeddedDatabaseFactoryBean;
 import org.springframework.jdbc.datasource.init.DataSourceInitializer;
 import org.springframework.tests.Assume;
@@ -38,12 +41,14 @@ import org.springframework.tests.TestGroup;
 
 import static org.hamcrest.CoreMatchers.*;
 import static org.junit.Assert.*;
+import static org.springframework.jdbc.datasource.embedded.EmbeddedDatabaseFactory.*;
 
 /**
  * @author Dave Syer
  * @author Juergen Hoeller
  * @author Chris Beams
  * @author Sam Brannen
+ * @author Stephane Nicoll
  */
 public class JdbcNamespaceIntegrationTests {
 
@@ -69,6 +74,31 @@ public class JdbcNamespaceIntegrationTests {
 		assertCorrectSetup("jdbc-config-pattern.xml", "dataSource");
 	}
 
+	@Test
+	public void createWithAnonymousDataSourceAndDefaultDatabaseName() throws Exception {
+		assertCorrectSetupForSingleDataSource("jdbc-config-db-name-default-and-anonymous-datasource.xml",
+			(url) -> url.endsWith(DEFAULT_DATABASE_NAME));
+	}
+
+	@Test
+	public void createWithImplicitDatabaseName() throws Exception {
+		assertCorrectSetupForSingleDataSource("jdbc-config-db-name-implicit.xml", (url) -> url.endsWith("dataSource"));
+	}
+
+	@Test
+	public void createWithExplicitDatabaseName() throws Exception {
+		assertCorrectSetupForSingleDataSource("jdbc-config-db-name-explicit.xml", (url) -> url.endsWith("customDbName"));
+	}
+
+	@Test
+	public void createWithGeneratedDatabaseName() throws Exception {
+		Predicate<String> urlPredicate = (url) -> url.startsWith("jdbc:hsqldb:mem:");
+		urlPredicate.and((url) -> !url.endsWith("dataSource"));
+		urlPredicate.and((url) -> !url.endsWith("shouldBeOverriddenByGeneratedName"));
+
+		assertCorrectSetupForSingleDataSource("jdbc-config-db-name-generated.xml", urlPredicate);
+	}
+
 	@Test
 	public void createWithEndings() throws Exception {
 		assertCorrectSetupAndCloseContext("jdbc-initialize-endings-config.xml", 2, "dataSource");
@@ -136,6 +166,16 @@ public class JdbcNamespaceIntegrationTests {
 		assertBeanPropertyValueOf("databaseName", "secondDataSource", factory);
 	}
 
+	@Test
+	public void initializeWithCustomSeparator() throws Exception {
+		assertCorrectSetupAndCloseContext("jdbc-initialize-custom-separator.xml", 2, "dataSource");
+	}
+
+	@Test
+	public void embeddedWithCustomSeparator() throws Exception {
+		assertCorrectSetupAndCloseContext("jdbc-config-custom-separator.xml", 2, "dataSource");
+	}
+
 	private ClassPathXmlApplicationContext context(String file) {
 		return new ClassPathXmlApplicationContext(file, getClass());
 	}
@@ -160,8 +200,10 @@ public class JdbcNamespaceIntegrationTests {
 		try {
 			for (String dataSourceName : dataSources) {
 				DataSource dataSource = context.getBean(dataSourceName, DataSource.class);
-				JdbcTemplate template = new JdbcTemplate(dataSource);
-				assertNumRowsInTestTable(template, count);
+				assertNumRowsInTestTable(new JdbcTemplate(dataSource), count);
+				assertTrue(dataSource instanceof AbstractDriverBasedDataSource);
+				AbstractDriverBasedDataSource adbDataSource = (AbstractDriverBasedDataSource) dataSource;
+				assertThat(adbDataSource.getUrl(), containsString(dataSourceName));
 			}
 		}
 		finally {
@@ -169,4 +211,18 @@ public class JdbcNamespaceIntegrationTests {
 		}
 	}
 
+	private void assertCorrectSetupForSingleDataSource(String file, Predicate<String> urlPredicate) {
+		ConfigurableApplicationContext context = context(file);
+		try {
+			DataSource dataSource = context.getBean(DataSource.class);
+			assertNumRowsInTestTable(new JdbcTemplate(dataSource), 1);
+			assertTrue(dataSource instanceof AbstractDriverBasedDataSource);
+			AbstractDriverBasedDataSource adbDataSource = (AbstractDriverBasedDataSource) dataSource;
+			assertTrue(urlPredicate.test(adbDataSource.getUrl()));
+		}
+		finally {
+			context.close();
+		}
+	}
+
 }
