@@ -24,6 +24,7 @@ import java.sql.SQLException;
 import java.sql.Types;
 import javax.sql.DataSource;
 
+import org.junit.Assert;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
@@ -41,19 +42,24 @@ import static org.mockito.BDDMockito.*;
 import static org.springframework.tests.Matchers.*;
 
 /**
- * Mock object based tests for SimpleJdbcCall.
+ * Tests for {@link SimpleJdbcCall}.
  *
  * @author Thomas Risberg
+ * @author Kiril Nugmanov
  */
 public class SimpleJdbcCallTests {
 
+	private Connection connection;
+
+	private DatabaseMetaData databaseMetaData;
+
+	private DataSource dataSource;
+
+	private CallableStatement callableStatement;
+
 	@Rule
 	public ExpectedException thrown = ExpectedException.none();
 
-	private Connection connection;
-	private DatabaseMetaData databaseMetaData;
-	private DataSource dataSource;
-	private CallableStatement callableStatement;
 
 	@Before
 	public void setUp() throws Exception {
@@ -65,6 +71,7 @@ public class SimpleJdbcCallTests {
 		given(dataSource.getConnection()).willReturn(connection);
 	}
 
+
 	@Test
 	public void testNoSuchStoredProcedure() throws Exception {
 		final String NO_SUCH_PROC = "x";
@@ -202,6 +209,35 @@ public class SimpleJdbcCallTests {
 
 	}
 
+	@Test
+	public void testCorrectFunctionStatement() throws Exception {
+		initializeAddInvoiceWithMetaData(true);
+		SimpleJdbcCall adder = new SimpleJdbcCall(dataSource).withFunctionName("add_invoice");
+		adder.compile();
+		verifyStatement(adder, "{? = call ADD_INVOICE(?, ?)}");
+	}
+
+	@Test
+	public void testCorrectFunctionStatementNamed() throws Exception {
+		initializeAddInvoiceWithMetaData(true);
+		SimpleJdbcCall adder = new SimpleJdbcCall(dataSource).withNamedBinding().withFunctionName("add_invoice");
+		adder.compile();
+		verifyStatement(adder, "{? = call ADD_INVOICE(AMOUNT => ?, CUSTID => ?)}");
+	}
+
+	@Test
+	public void testCorrectProcedureStatementNamed() throws Exception {
+		initializeAddInvoiceWithMetaData(false);
+		SimpleJdbcCall adder = new SimpleJdbcCall(dataSource).withNamedBinding().withProcedureName("add_invoice");
+		adder.compile();
+		verifyStatement(adder, "{call ADD_INVOICE(AMOUNT => ?, CUSTID => ?, NEWID => ?)}");
+	}
+
+
+	private void verifyStatement(SimpleJdbcCall adder, String expected) {
+		Assert.assertEquals("Incorrect call statement", expected, adder.getCallString());
+	}
+
 	private void initializeAddInvoiceWithoutMetaData(boolean isFunction) throws SQLException {
 		given(databaseMetaData.getDatabaseProductName()).willReturn("MyDB");
 		given(databaseMetaData.getUserName()).willReturn("me");
