@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2013 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -43,11 +43,14 @@ import static org.mockito.BDDMockito.*;
 public class TableMetaDataContextTests  {
 
 	private Connection connection;
+
 	private DataSource dataSource;
+
 	private DatabaseMetaData databaseMetaData;
 
 	private TableMetaDataContext context = new TableMetaDataContext();
 
+
 	@Before
 	public void setUp() throws Exception {
 		connection = mock(Connection.class);
@@ -57,9 +60,6 @@ public class TableMetaDataContextTests  {
 		given(dataSource.getConnection()).willReturn(connection);
 	}
 
-	public void verifyClosed() throws Exception {
-		verify(connection).close();
-	}
 
 	@Test
 	public void testMatchInParametersAndSqlTypeInfoWrapping() throws Exception {
@@ -153,4 +153,5 @@ public class TableMetaDataContextTests  {
 		verify(metaDataResultSet).close();
 		verify(columnsResultSet).close();
 	}
+
 }
