@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2013 the original author or authors.
+ * Copyright 2002-2014 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,7 +17,7 @@
 package org.springframework.jms.listener;
 
 import java.util.HashSet;
-
+import java.util.Set;
 import javax.jms.Connection;
 import javax.jms.ConnectionFactory;
 import javax.jms.ExceptionListener;
@@ -29,6 +29,7 @@ import javax.jms.Session;
 
 import org.junit.Before;
 import org.junit.Test;
+
 import org.springframework.context.support.GenericApplicationContext;
 import org.springframework.core.task.TaskExecutor;
 import org.springframework.jms.StubQueue;
@@ -169,11 +170,11 @@ public class SimpleMessageListenerContainerTests extends AbstractMessageListener
 		final ConnectionFactory connectionFactory = mock(ConnectionFactory.class);
 		given(connectionFactory.createConnection()).willReturn(connection);
 
-		final HashSet failure = new HashSet();
+		final Set<String> failure = new HashSet<String>(1);
 
 		this.container.setConnectionFactory(connectionFactory);
 		this.container.setDestinationName(DESTINATION_NAME);
-		this.container.setMessageListener(new SessionAwareMessageListener() {
+		this.container.setMessageListener(new SessionAwareMessageListener<Message>() {
 			@Override
 			public void onMessage(Message message, Session sess) {
 				try {
@@ -269,7 +270,7 @@ public class SimpleMessageListenerContainerTests extends AbstractMessageListener
 
 		this.container.setConnectionFactory(connectionFactory);
 		this.container.setDestinationName(DESTINATION_NAME);
-		this.container.setMessageListener(new SessionAwareMessageListener() {
+		this.container.setMessageListener(new SessionAwareMessageListener<Message>() {
 			@Override
 			public void onMessage(Message message, Session session) throws JMSException {
 				throw theException;
@@ -319,7 +320,7 @@ public class SimpleMessageListenerContainerTests extends AbstractMessageListener
 
 		this.container.setConnectionFactory(connectionFactory);
 		this.container.setDestinationName(DESTINATION_NAME);
-		this.container.setMessageListener(new SessionAwareMessageListener() {
+		this.container.setMessageListener(new SessionAwareMessageListener<Message>() {
 			@Override
 			public void onMessage(Message message, Session session) throws JMSException {
 				throw theException;
