@@ -307,7 +307,8 @@ public class MessageListenerAdapterTests {
 		try {
 			adapter.onMessage(sentTextMessage, session);
 			fail("expected CouldNotSendReplyException with InvalidDestinationException");
-		} catch(ReplyFailureException ex) {
+		}
+		catch (ReplyFailureException ex) {
 			assertEquals(InvalidDestinationException.class, ex.getCause().getClass());
 		}
 
@@ -345,7 +346,8 @@ public class MessageListenerAdapterTests {
 		try {
 			adapter.onMessage(sentTextMessage, session);
 			fail("expected CouldNotSendReplyException with JMSException");
-		} catch(ReplyFailureException ex) {
+		}
+		catch (ReplyFailureException ex) {
 			assertEquals(JMSException.class, ex.getCause().getClass());
 		}
 
@@ -371,7 +373,8 @@ public class MessageListenerAdapterTests {
 		try {
 			adapter.onMessage(message, session);
 			fail("expected ListenerExecutionFailedException");
-		} catch(ListenerExecutionFailedException ex) { /* expected */ }
+		}
+		catch (ListenerExecutionFailedException ex) { /* expected */ }
 	}
 
 	@Test
@@ -425,7 +428,8 @@ public class MessageListenerAdapterTests {
 		try {
 			adapter.onMessage(sentTextMessage, session);
 			fail("expected CouldNotSendReplyException with MessageConversionException");
-		} catch(ReplyFailureException ex) {
+		}
+		catch (ReplyFailureException ex) {
 			assertEquals(MessageConversionException.class, ex.getCause().getClass());
 		}
 	}
