@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2016 the original author or authors.
+ * Copyright 2002-2017 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -136,8 +136,8 @@ public class DefaultSubscriptionRegistry extends AbstractSubscriptionRegistry {
 
 
 	@Override
-	protected void addSubscriptionInternal(String sessionId, String subsId, String destination,
-			Message<?> message) {
+	protected void addSubscriptionInternal(
+			String sessionId, String subsId, String destination, Message<?> message) {
 
 		Expression expression = null;
 		MessageHeaders headers = message.getHeaders();
@@ -292,8 +292,12 @@ public class DefaultSubscriptionRegistry extends AbstractSubscriptionRegistry {
 					String cachedDestination = entry.getKey();
 					if (getPathMatcher().match(destination, cachedDestination)) {
 						LinkedMultiValueMap<String, String> subs = entry.getValue();
-						subs.add(sessionId, subsId);
-						this.accessCache.put(cachedDestination, subs.deepCopy());
+						// Subscription id's may also be populated via getSubscriptions()
+						List<String> subsForSession = subs.get(sessionId);
+						if (subsForSession == null || !subsForSession.contains(subsId)) {
+							subs.add(sessionId, subsId);
+							this.accessCache.put(cachedDestination, subs.deepCopy());
+						}
 					}
 				}
 			}
@@ -410,7 +414,7 @@ public class DefaultSubscriptionRegistry extends AbstractSubscriptionRegistry {
 				new ConcurrentHashMap<String, Set<Subscription>>(4);
 
 		public SessionSubscriptionInfo(String sessionId) {
-			Assert.notNull(sessionId, "sessionId must not be null");
+			Assert.notNull(sessionId, "'sessionId' must not be null");
 			this.sessionId = sessionId;
 		}
 
@@ -427,8 +431,8 @@ public class DefaultSubscriptionRegistry extends AbstractSubscriptionRegistry {
 		}
 
 		public Subscription getSubscription(String subscriptionId) {
-			for (String destination : this.destinationLookup.keySet()) {
-				Set<Subscription> subs = this.destinationLookup.get(destination);
+			for (Map.Entry<String, Set<DefaultSubscriptionRegistry.Subscription>> destinationEntry : this.destinationLookup.entrySet()) {
+				Set<Subscription> subs = destinationEntry.getValue();
 				if (subs != null) {
 					for (Subscription sub : subs) {
 						if (sub.getId().equalsIgnoreCase(subscriptionId)) {
@@ -455,17 +459,17 @@ public class DefaultSubscriptionRegistry extends AbstractSubscriptionRegistry {
 		}
 
 		public String removeSubscription(String subscriptionId) {
-			for (String destination : this.destinationLookup.keySet()) {
-				Set<Subscription> subs = this.destinationLookup.get(destination);
+			for (Map.Entry<String, Set<DefaultSubscriptionRegistry.Subscription>> destinationEntry : this.destinationLookup.entrySet()) {
+				Set<Subscription> subs = destinationEntry.getValue();
 				if (subs != null) {
 					for (Subscription sub : subs) {
 						if (sub.getId().equals(subscriptionId) && subs.remove(sub)) {
 							synchronized (this.destinationLookup) {
 								if (subs.isEmpty()) {
-									this.destinationLookup.remove(destination);
+									this.destinationLookup.remove(destinationEntry.getKey());
 								}
 							}
-							return destination;
+							return destinationEntry.getKey();
 						}
 					}
 				}
@@ -480,13 +484,14 @@ public class DefaultSubscriptionRegistry extends AbstractSubscriptionRegistry {
 	}
 
 
-	private static class Subscription {
+	private static final class Subscription {
 
 		private final String id;
 
 		private final Expression selectorExpression;
 
 		public Subscription(String id, Expression selector) {
+			Assert.notNull(id, "Subscription id must not be null");
 			this.id = id;
 			this.selectorExpression = selector;
 		}
@@ -499,6 +504,16 @@ public class DefaultSubscriptionRegistry extends AbstractSubscriptionRegistry {
 			return this.selectorExpression;
 		}
 
+		@Override
+		public boolean equals(Object other) {
+			return (this == other || (other instanceof Subscription && this.id.equals(((Subscription) other).id)));
+		}
+
+		@Override
+		public int hashCode() {
+			return this.id.hashCode();
+		}
+
 		@Override
 		public String toString() {
 			return "subscription(id=" + this.id + ")";
