@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2012 the original author or authors.
+ * Copyright 2002-2013 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -18,12 +18,14 @@ package org.springframework.orm.hibernate4;
 
 import org.hibernate.StaleObjectStateException;
 import org.hibernate.StaleStateException;
+import org.hibernate.dialect.lock.OptimisticEntityLockException;
 
 import org.springframework.orm.ObjectOptimisticLockingFailureException;
 
 /**
  * Hibernate-specific subclass of ObjectOptimisticLockingFailureException.
- * Converts Hibernate's StaleObjectStateException and StaleStateException.
+ * Converts Hibernate's StaleObjectStateException, StaleStateException
+ * and OptimisticEntityLockException.
  *
  * @author Juergen Hoeller
  * @since 3.1
@@ -40,4 +42,8 @@ public class HibernateOptimisticLockingFailureException extends ObjectOptimistic
 		super(ex.getMessage(), ex);
 	}
 
+	public HibernateOptimisticLockingFailureException(OptimisticEntityLockException ex) {
+		super(ex.getMessage(), ex);
+	}
+
 }
