@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2012 the original author or authors.
+ * Copyright 2002-2017 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -149,7 +149,7 @@ public class ObjectOptimisticLockingFailureException extends OptimisticLockingFa
 	 * Return the identifier of the object for which the locking failed.
 	 */
 	public Object getIdentifier() {
-		return identifier;
+		return this.identifier;
 	}
 
 }
