@@ -62,7 +62,9 @@ import org.springframework.dao.DataAccessException;
  * @see org.springframework.transaction.jta.JtaTransactionManager
  * @see org.springframework.orm.hibernate3.support.OpenSessionInViewFilter
  * @see org.springframework.orm.hibernate3.support.OpenSessionInViewInterceptor
+ * @deprecated as of Spring 4.3, in favor of Hibernate 4.x/5.x
  */
+@Deprecated
 public interface HibernateOperations {
 
 	/**
@@ -97,7 +99,7 @@ public interface HibernateOperations {
 	 * call with a generic List type declared
 	 */
 	@Deprecated
-	List executeFind(HibernateCallback<?> action) throws DataAccessException;
+	List<?> executeFind(HibernateCallback<?> action) throws DataAccessException;
 
 
 	//-------------------------------------------------------------------------
@@ -432,19 +434,6 @@ public interface HibernateOperations {
 	 */
 	void saveOrUpdate(String entityName, Object entity) throws DataAccessException;
 
-	/**
-	 * Save or update all given persistent instances,
-	 * according to its id (matching the configured "unsaved-value"?).
-	 * Associates the instances with the current Hibernate {@code Session}.
-	 * @param entities the persistent instances to save or update
-	 * (to be associated with the Hibernate {@code Session})
-	 * @throws DataAccessException in case of Hibernate errors
-	 * @deprecated as of Spring 2.5, in favor of individual
-	 * {@code saveOrUpdate} or {@code merge} usage
-	 */
-	@Deprecated
-	void saveOrUpdateAll(Collection entities) throws DataAccessException;
-
 	/**
 	 * Persist the state of the given detached instance according to the
 	 * given replication mode, reusing the current identifier value.
@@ -579,7 +568,7 @@ public interface HibernateOperations {
 	 * @throws org.springframework.dao.DataAccessException in case of Hibernate errors
 	 * @see org.hibernate.Session#delete(Object)
 	 */
-	void deleteAll(Collection entities) throws DataAccessException;
+	void deleteAll(Collection<?> entities) throws DataAccessException;
 
 	/**
 	 * Flush all pending saves, updates and deletes to the database.
@@ -612,7 +601,7 @@ public interface HibernateOperations {
 	 * @throws org.springframework.dao.DataAccessException in case of Hibernate errors
 	 * @see org.hibernate.Session#createQuery
 	 */
-	List find(String queryString) throws DataAccessException;
+	List<?> find(String queryString) throws DataAccessException;
 
 	/**
 	 * Execute an HQL query, binding one value to a "?" parameter in the
@@ -623,7 +612,7 @@ public interface HibernateOperations {
 	 * @throws org.springframework.dao.DataAccessException in case of Hibernate errors
 	 * @see org.hibernate.Session#createQuery
 	 */
-	List find(String queryString, Object value) throws DataAccessException;
+	List<?> find(String queryString, Object value) throws DataAccessException;
 
 	/**
 	 * Execute an HQL query, binding a number of values to "?" parameters
@@ -634,7 +623,7 @@ public interface HibernateOperations {
 	 * @throws org.springframework.dao.DataAccessException in case of Hibernate errors
 	 * @see org.hibernate.Session#createQuery
 	 */
-	List find(String queryString, Object... values) throws DataAccessException;
+	List<?> find(String queryString, Object... values) throws DataAccessException;
 
 	/**
 	 * Execute an HQL query, binding one value to a ":" named parameter
@@ -646,8 +635,7 @@ public interface HibernateOperations {
 	 * @throws org.springframework.dao.DataAccessException in case of Hibernate errors
 	 * @see org.hibernate.Session#getNamedQuery(String)
 	 */
-	List findByNamedParam(String queryString, String paramName, Object value)
-			throws DataAccessException;
+	List<?> findByNamedParam(String queryString, String paramName, Object value) throws DataAccessException;
 
 	/**
 	 * Execute an HQL query, binding a number of values to ":" named
@@ -659,8 +647,7 @@ public interface HibernateOperations {
 	 * @throws org.springframework.dao.DataAccessException in case of Hibernate errors
 	 * @see org.hibernate.Session#getNamedQuery(String)
 	 */
-	List findByNamedParam(String queryString, String[] paramNames, Object[] values)
-			throws DataAccessException;
+	List<?> findByNamedParam(String queryString, String[] paramNames, Object[] values) throws DataAccessException;
 
 	/**
 	 * Execute an HQL query, binding the properties of the given bean to
@@ -672,7 +659,7 @@ public interface HibernateOperations {
 	 * @see org.hibernate.Query#setProperties
 	 * @see org.hibernate.Session#createQuery
 	 */
-	List findByValueBean(String queryString, Object valueBean) throws DataAccessException;
+	List<?> findByValueBean(String queryString, Object valueBean) throws DataAccessException;
 
 
 	//-------------------------------------------------------------------------
@@ -687,7 +674,7 @@ public interface HibernateOperations {
 	 * @throws org.springframework.dao.DataAccessException in case of Hibernate errors
 	 * @see org.hibernate.Session#getNamedQuery(String)
 	 */
-	List findByNamedQuery(String queryName) throws DataAccessException;
+	List<?> findByNamedQuery(String queryName) throws DataAccessException;
 
 	/**
 	 * Execute a named query, binding one value to a "?" parameter in
@@ -699,7 +686,7 @@ public interface HibernateOperations {
 	 * @throws org.springframework.dao.DataAccessException in case of Hibernate errors
 	 * @see org.hibernate.Session#getNamedQuery(String)
 	 */
-	List findByNamedQuery(String queryName, Object value) throws DataAccessException;
+	List<?> findByNamedQuery(String queryName, Object value) throws DataAccessException;
 
 	/**
 	 * Execute a named query binding a number of values to "?" parameters
@@ -711,7 +698,7 @@ public interface HibernateOperations {
 	 * @throws org.springframework.dao.DataAccessException in case of Hibernate errors
 	 * @see org.hibernate.Session#getNamedQuery(String)
 	 */
-	List findByNamedQuery(String queryName, Object... values) throws DataAccessException;
+	List<?> findByNamedQuery(String queryName, Object... values) throws DataAccessException;
 
 	/**
 	 * Execute a named query, binding one value to a ":" named parameter
@@ -724,7 +711,7 @@ public interface HibernateOperations {
 	 * @throws org.springframework.dao.DataAccessException in case of Hibernate errors
 	 * @see org.hibernate.Session#getNamedQuery(String)
 	 */
-	List findByNamedQueryAndNamedParam(String queryName, String paramName, Object value)
+	List<?> findByNamedQueryAndNamedParam(String queryName, String paramName, Object value)
 			throws DataAccessException;
 
 	/**
@@ -738,7 +725,7 @@ public interface HibernateOperations {
 	 * @throws org.springframework.dao.DataAccessException in case of Hibernate errors
 	 * @see org.hibernate.Session#getNamedQuery(String)
 	 */
-	List findByNamedQueryAndNamedParam(String queryName, String[] paramNames, Object[] values)
+	List<?> findByNamedQueryAndNamedParam(String queryName, String[] paramNames, Object[] values)
 			throws DataAccessException;
 
 	/**
@@ -752,8 +739,7 @@ public interface HibernateOperations {
 	 * @see org.hibernate.Query#setProperties
 	 * @see org.hibernate.Session#getNamedQuery(String)
 	 */
-	List findByNamedQueryAndValueBean(String queryName, Object valueBean)
-			throws DataAccessException;
+	List<?> findByNamedQueryAndValueBean(String queryName, Object valueBean) throws DataAccessException;
 
 
 	//-------------------------------------------------------------------------
@@ -769,7 +755,7 @@ public interface HibernateOperations {
 	 * @throws org.springframework.dao.DataAccessException in case of Hibernate errors
 	 * @see org.hibernate.criterion.DetachedCriteria#getExecutableCriteria(org.hibernate.Session)
 	 */
-	List findByCriteria(DetachedCriteria criteria) throws DataAccessException;
+	List<?> findByCriteria(DetachedCriteria criteria) throws DataAccessException;
 
 	/**
 	 * Execute a query based on the given Hibernate criteria object.
@@ -786,7 +772,7 @@ public interface HibernateOperations {
 	 * @see org.hibernate.Criteria#setFirstResult(int)
 	 * @see org.hibernate.Criteria#setMaxResults(int)
 	 */
-	List findByCriteria(DetachedCriteria criteria, int firstResult, int maxResults) throws DataAccessException;
+	List<?> findByCriteria(DetachedCriteria criteria, int firstResult, int maxResults) throws DataAccessException;
 
 	/**
 	 * Execute a query based on the given example entity object.
@@ -796,7 +782,7 @@ public interface HibernateOperations {
 	 * @throws org.springframework.dao.DataAccessException in case of Hibernate errors
 	 * @see org.hibernate.criterion.Example#create(Object)
 	 */
-	List findByExample(Object exampleEntity) throws DataAccessException;
+	<T> List<T> findByExample(T exampleEntity) throws DataAccessException;
 
 	/**
 	 * Execute a query based on the given example entity object.
@@ -807,7 +793,7 @@ public interface HibernateOperations {
 	 * @throws org.springframework.dao.DataAccessException in case of Hibernate errors
 	 * @see org.hibernate.criterion.Example#create(Object)
 	 */
-	List findByExample(String entityName, Object exampleEntity) throws DataAccessException;
+	<T> List<T> findByExample(String entityName, T exampleEntity) throws DataAccessException;
 
 	/**
 	 * Execute a query based on a given example entity object.
@@ -823,7 +809,7 @@ public interface HibernateOperations {
 	 * @see org.hibernate.Criteria#setFirstResult(int)
 	 * @see org.hibernate.Criteria#setMaxResults(int)
 	 */
-	List findByExample(Object exampleEntity, int firstResult, int maxResults) throws DataAccessException;
+	<T> List<T> findByExample(T exampleEntity, int firstResult, int maxResults) throws DataAccessException;
 
 	/**
 	 * Execute a query based on a given example entity object.
@@ -840,7 +826,7 @@ public interface HibernateOperations {
 	 * @see org.hibernate.Criteria#setFirstResult(int)
 	 * @see org.hibernate.Criteria#setMaxResults(int)
 	 */
-	List findByExample(String entityName, Object exampleEntity, int firstResult, int maxResults)
+	<T> List<T> findByExample(String entityName, T exampleEntity, int firstResult, int maxResults)
 			throws DataAccessException;
 
 
@@ -858,7 +844,7 @@ public interface HibernateOperations {
 	 * @see org.hibernate.Session#createQuery
 	 * @see org.hibernate.Query#iterate
 	 */
-	Iterator iterate(String queryString) throws DataAccessException;
+	Iterator<?> iterate(String queryString) throws DataAccessException;
 
 	/**
 	 * Execute a query for persistent instances, binding one value
@@ -872,7 +858,7 @@ public interface HibernateOperations {
 	 * @see org.hibernate.Session#createQuery
 	 * @see org.hibernate.Query#iterate
 	 */
-	Iterator iterate(String queryString, Object value) throws DataAccessException;
+	Iterator<?> iterate(String queryString, Object value) throws DataAccessException;
 
 	/**
 	 * Execute a query for persistent instances, binding a number of
@@ -886,7 +872,7 @@ public interface HibernateOperations {
 	 * @see org.hibernate.Session#createQuery
 	 * @see org.hibernate.Query#iterate
 	 */
-	Iterator iterate(String queryString, Object... values) throws DataAccessException;
+	Iterator<?> iterate(String queryString, Object... values) throws DataAccessException;
 
 	/**
 	 * Immediately close an {@link Iterator} created by any of the various
@@ -896,7 +882,7 @@ public interface HibernateOperations {
 	 * @throws DataAccessException if the {@code Iterator} could not be closed
 	 * @see org.hibernate.Hibernate#close
 	 */
-	void closeIterator(Iterator it) throws DataAccessException;
+	void closeIterator(Iterator<?> it) throws DataAccessException;
 
 	/**
 	 * Update/delete all objects according to the given query.
