@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2014 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -30,19 +30,19 @@ import org.springframework.orm.jpa.AbstractContainerEntityManagerFactoryIntegrat
 public class HibernateMultiEntityManagerFactoryIntegrationTests extends
 		AbstractContainerEntityManagerFactoryIntegrationTests {
 
-	private EntityManagerFactory entityManagerFactory2;
-
-
-	public HibernateMultiEntityManagerFactoryIntegrationTests() {
+	{
 		setAutowireMode(AUTOWIRE_BY_NAME);
 	}
 
+	private EntityManagerFactory entityManagerFactory2;
+
+
 	public void setEntityManagerFactory2(EntityManagerFactory entityManagerFactory2) {
 		this.entityManagerFactory2 = entityManagerFactory2;
 	}
 
 	@Override
-	protected String[] getConfigLocations() {
+	protected String[] getConfigPaths() {
 		return new String[] {
 			"/org/springframework/orm/jpa/hibernate/hibernate-manager-multi.xml",
 			"/org/springframework/orm/jpa/memdb.xml",
