@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2014 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -40,7 +40,7 @@ import org.springframework.transaction.support.TransactionTemplate;
 public class OpenJpaEntityManagerFactoryIntegrationTests extends AbstractContainerEntityManagerFactoryIntegrationTests {
 
 	@Override
-	protected String[] getConfigLocations() {
+	protected String[] getConfigPaths() {
 		return OPENJPA_CONFIG_LOCATIONS;
 	}
 
@@ -59,6 +59,7 @@ public class OpenJpaEntityManagerFactoryIntegrationTests extends AbstractContain
 		assertNotNull(openJPAEntityManager.getDelegate());
 	}
 
+	@SuppressWarnings("unchecked")
 	public void testSavepoint() {
 		TransactionTemplate tt = new TransactionTemplate(transactionManager);
 		tt.setPropagationBehavior(TransactionTemplate.PROPAGATION_NESTED);
