@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2014 the original author or authors.
+ * Copyright 2002-2017 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -72,8 +72,8 @@ import org.springframework.util.xml.StaxUtils;
  * can only be used to unmarshal XML that represents that specific class. If you want to unmarshal
  * multiple classes, you have to provide a mapping file using {@code setMappingLocations}.
  *
- * <p>Due to limitations of Castor's API, it is required to set the encoding used for
- * writing to output streams. It defaults to {@code UTF-8}.
+ * <p>Due to limitations of Castor's API, it is required to set the encoding used for writing
+ * to output streams. It defaults to {@code UTF-8}.
  *
  * @author Arjen Poutsma
  * @author Jakub Narloch
@@ -84,7 +84,9 @@ import org.springframework.util.xml.StaxUtils;
  * @see #setTargetPackages(String[])
  * @see #setMappingLocation(Resource)
  * @see #setMappingLocations(Resource[])
+ * @deprecated as of Spring Framework 4.3.13, due to the lack of activity on the Castor project
  */
+@Deprecated
 public class CastorMarshaller extends AbstractMarshaller implements InitializingBean, BeanClassLoaderAware {
 
 	/**
