@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2013 the original author or authors.
+ * Copyright 2002-2016 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -91,7 +91,10 @@ public class ProfileValueUtilsTests {
 		assertClassIsEnabled(EnabledAnnotatedMultiValue.class);
 		assertClassIsEnabled(MetaEnabledClass.class);
 		assertClassIsEnabled(MetaEnabledWithCustomProfileValueSourceClass.class);
+		assertClassIsEnabled(EnabledWithCustomProfileValueSourceOnTestInterface.class);
+
 		assertClassIsDisabled(DisabledAnnotatedSingleValue.class);
+		assertClassIsDisabled(DisabledAnnotatedSingleValueOnTestInterface.class);
 		assertClassIsDisabled(DisabledAnnotatedMultiValue.class);
 		assertClassIsDisabled(MetaDisabledClass.class);
 		assertClassIsDisabled(MetaDisabledWithCustomProfileValueSourceClass.class);
@@ -105,6 +108,7 @@ public class ProfileValueUtilsTests {
 		assertMethodIsEnabled(ENABLED_ANNOTATED_METHOD, EnabledAnnotatedSingleValue.class);
 		assertMethodIsDisabled(DISABLED_ANNOTATED_METHOD, EnabledAnnotatedSingleValue.class);
 
+
 		assertMethodIsEnabled(NON_ANNOTATED_METHOD, MetaEnabledAnnotatedSingleValue.class);
 		assertMethodIsEnabled(ENABLED_ANNOTATED_METHOD, MetaEnabledAnnotatedSingleValue.class);
 		assertMethodIsDisabled(DISABLED_ANNOTATED_METHOD, MetaEnabledAnnotatedSingleValue.class);
@@ -117,6 +121,8 @@ public class ProfileValueUtilsTests {
 		assertMethodIsDisabled(ENABLED_ANNOTATED_METHOD, DisabledAnnotatedSingleValue.class);
 		assertMethodIsDisabled(DISABLED_ANNOTATED_METHOD, DisabledAnnotatedSingleValue.class);
 
+		assertMethodIsDisabled(NON_ANNOTATED_METHOD, DisabledAnnotatedSingleValueOnTestInterface.class);
+
 		assertMethodIsDisabled(NON_ANNOTATED_METHOD, MetaDisabledAnnotatedSingleValue.class);
 		assertMethodIsDisabled(ENABLED_ANNOTATED_METHOD, MetaDisabledAnnotatedSingleValue.class);
 		assertMethodIsDisabled(DISABLED_ANNOTATED_METHOD, MetaDisabledAnnotatedSingleValue.class);
@@ -176,6 +182,17 @@ public class ProfileValueUtilsTests {
 		}
 	}
 
+	@IfProfileValue(name = NAME, value = VALUE + "X")
+	private interface IfProfileValueTestInterface {
+	}
+
+	@SuppressWarnings("unused")
+	private static class DisabledAnnotatedSingleValueOnTestInterface implements IfProfileValueTestInterface {
+
+		public void nonAnnotatedMethod() {
+		}
+	}
+
 	@SuppressWarnings("unused")
 	@IfProfileValue(name = NAME, values = { "foo", VALUE, "bar" })
 	private static class EnabledAnnotatedMultiValue {
@@ -302,4 +319,13 @@ public class ProfileValueUtilsTests {
 	private static class MetaDisabledWithCustomProfileValueSourceClass {
 	}
 
+	@ProfileValueSourceConfiguration(HardCodedProfileValueSource.class)
+	private interface CustomProfileValueSourceTestInterface {
+	}
+
+	@IfProfileValue(name = NAME, value = "42")
+	private static class EnabledWithCustomProfileValueSourceOnTestInterface
+			implements CustomProfileValueSourceTestInterface {
+	}
+
 }
