@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2014 the original author or authors.
+ * Copyright 2002-2016 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,6 +16,7 @@
 
 package org.springframework.test.context;
 
+import java.util.Collections;
 import java.util.HashSet;
 import java.util.Set;
 
@@ -28,14 +29,17 @@ import org.springframework.test.context.support.AnnotationConfigContextLoader;
 import org.springframework.test.context.support.GenericXmlContextLoader;
 
 import static org.junit.Assert.*;
+import static org.mockito.Mockito.*;
 
 /**
  * Unit tests for {@link MergedContextConfiguration}.
  *
  * <p>These tests primarily exist to ensure that {@code MergedContextConfiguration}
- * can safely be used as the cache key for {@link ContextCache}.
+ * can safely be used as the cache key for
+ * {@link org.springframework.test.context.cache.ContextCache ContextCache}.
  *
  * @author Sam Brannen
+ * @author Phillip Webb
  * @since 3.1
  */
 public class MergedContextConfigurationTests {
@@ -140,7 +144,7 @@ public class MergedContextConfigurationTests {
 				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, activeProfiles1, loader);
 		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(),
 				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, activeProfiles2, loader);
-		assertEquals(mergedConfig1.hashCode(), mergedConfig2.hashCode());
+		assertNotEquals(mergedConfig1.hashCode(), mergedConfig2.hashCode());
 	}
 
 	@Test
@@ -336,7 +340,7 @@ public class MergedContextConfigurationTests {
 				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, activeProfiles1, loader);
 		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(),
 				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, activeProfiles2, loader);
-		assertEquals(mergedConfig1, mergedConfig2);
+		assertNotEquals(mergedConfig1, mergedConfig2);
 	}
 
 	@Test
@@ -399,6 +403,35 @@ public class MergedContextConfigurationTests {
 		assertNotEquals(mergedConfig2, mergedConfig1);
 	}
 
+	/**
+	 * @since 4.3
+	 */
+	@Test
+	public void equalsWithSameContextCustomizers() {
+		Set<ContextCustomizer> customizers = Collections.singleton(mock(ContextCustomizer.class));
+		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
+			EMPTY_CLASS_ARRAY, null, EMPTY_STRING_ARRAY, null, null, customizers, loader, null, null);
+		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
+			EMPTY_CLASS_ARRAY, null, EMPTY_STRING_ARRAY, null, null, customizers, loader, null, null);
+		assertEquals(mergedConfig1, mergedConfig2);
+	}
+
+	/**
+	 * @since 4.3
+	 */
+	@Test
+	public void equalsWithDifferentContextCustomizers() {
+		Set<ContextCustomizer> customizers1 = Collections.singleton(mock(ContextCustomizer.class));
+		Set<ContextCustomizer> customizers2 = Collections.singleton(mock(ContextCustomizer.class));
+
+		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
+			EMPTY_CLASS_ARRAY, null, EMPTY_STRING_ARRAY, null, null, customizers1, loader, null, null);
+		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
+			EMPTY_CLASS_ARRAY, null, EMPTY_STRING_ARRAY, null, null, customizers2, loader, null, null);
+		assertNotEquals(mergedConfig1, mergedConfig2);
+		assertNotEquals(mergedConfig2, mergedConfig1);
+	}
+
 	/**
 	 * @since 3.2.2
 	 */
