@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2013 the original author or authors.
+ * Copyright 2002-2016 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -40,7 +40,7 @@ import static org.junit.Assert.*;
 public class SingleTestClassWithTwoLevelContextHierarchyTests {
 
 	@Configuration
-	static class ParentConfig {
+	public static class ParentConfig {
 
 		@Bean
 		public String foo() {
@@ -54,7 +54,7 @@ public class SingleTestClassWithTwoLevelContextHierarchyTests {
 	}
 
 	@Configuration
-	static class ChildConfig {
+	public static class ChildConfig {
 
 		@Bean
 		public String bar() {
