@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2013 the original author or authors.
+ * Copyright 2002-2016 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -21,19 +21,15 @@ import java.util.ArrayList;
 import org.junit.Ignore;
 import org.junit.Test;
 import org.junit.runner.RunWith;
-import org.junit.runner.notification.RunNotifier;
 import org.junit.runners.JUnit4;
 
 import org.springframework.test.context.TestExecutionListeners;
 
-import static org.junit.Assert.*;
+import static org.springframework.test.context.junit4.JUnitTestingUtils.*;
 
 /**
- * Verifies proper handling of the following in conjunction with the
- * {@link SpringJUnit4ClassRunner}:
- * <ul>
- * <li>JUnit's {@link Test#expected() &#064;Test(expected=...)}</li>
- * </ul>
+ * Verifies proper handling of JUnit's {@link Test#expected() &#064;Test(expected=...)}
+ * support in conjunction with the {@link SpringRunner}.
  *
  * @author Sam Brannen
  * @since 3.0
@@ -43,23 +39,11 @@ public class ExpectedExceptionSpringRunnerTests {
 
 	@Test
 	public void expectedExceptions() throws Exception {
-		Class<ExpectedExceptionSpringRunnerTestCase> testClass = ExpectedExceptionSpringRunnerTestCase.class;
-		TrackingRunListener listener = new TrackingRunListener();
-		RunNotifier notifier = new RunNotifier();
-		notifier.addListener(listener);
-
-		new SpringJUnit4ClassRunner(testClass).run(notifier);
-		assertEquals("Verifying number of failures for test class [" + testClass + "].", 0,
-			listener.getTestFailureCount());
-		assertEquals("Verifying number of tests started for test class [" + testClass + "].", 1,
-			listener.getTestStartedCount());
-		assertEquals("Verifying number of tests finished for test class [" + testClass + "].", 1,
-			listener.getTestFinishedCount());
+		runTestsAndAssertCounters(SpringRunner.class, ExpectedExceptionSpringRunnerTestCase.class, 1, 0, 1, 0, 0);
 	}
 
 
 	@Ignore("TestCase classes are run manually by the enclosing test class")
-	@RunWith(SpringJUnit4ClassRunner.class)
 	@TestExecutionListeners({})
 	public static final class ExpectedExceptionSpringRunnerTestCase {
 
@@ -68,7 +52,6 @@ public class ExpectedExceptionSpringRunnerTests {
 		public void verifyJUnitExpectedException() {
 			new ArrayList<Object>().get(1);
 		}
-
 	}
 
 }
