@@ -16,12 +16,12 @@
 
 package org.springframework.test.context.junit4.profile.annotation;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
-
 import org.junit.Test;
+
 import org.springframework.test.context.ActiveProfiles;
 
+import static org.junit.Assert.*;
+
 /**
  * @author Sam Brannen
  * @since 3.1
