@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2011 the original author or authors.
+ * Copyright 2002-2013 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -31,7 +31,8 @@ import org.junit.runners.Suite.SuiteClasses;
 // Note: the following 'multi-line' layout is for enhanced code readability.
 @SuiteClasses({//
 DefaultProfileXmlConfigTests.class,//
-	DevProfileXmlConfigTests.class //
+	DevProfileXmlConfigTests.class,//
+	DevProfileResolverXmlConfigTests.class //
 })
 public class ProfileXmlConfigTestSuite {
 }
