@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2013 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -68,7 +68,7 @@ public class TransactionalAnnotatedConfigClassWithAtConfigurationTests extends
 		@Bean
 		public DataSource dataSource() {
 			return new EmbeddedDatabaseBuilder()//
-			.addScript("classpath:/org/springframework/test/context/junit4/spr9051/schema.sql")//
+			.addScript("classpath:/org/springframework/test/jdbc/schema.sql")//
 			// Ensure that this in-memory database is only used by this class:
 			.setName(getClass().getName())//
 			.build();
