@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2014 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -25,10 +25,10 @@ import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.junit.runners.Parameterized;
 import org.junit.runners.Parameterized.Parameters;
-
 import org.springframework.core.annotation.AnnotationUtils;
 import org.springframework.test.context.ContextConfiguration;
 import org.springframework.test.context.ContextLoader;
+import org.springframework.util.ClassUtils;
 import org.springframework.util.ObjectUtils;
 
 import static org.junit.Assert.*;
@@ -55,12 +55,7 @@ public class GenericXmlContextLoaderResourceLocationsTests {
 	protected final String[] expectedLocations;
 
 
-	public GenericXmlContextLoaderResourceLocationsTests(final Class<?> testClass, final String[] expectedLocations) {
-		this.testClass = testClass;
-		this.expectedLocations = expectedLocations;
-	}
-
-	@Parameters
+	@Parameters(name = "{0}")
 	public static Collection<Object[]> contextConfigurationLocationsData() {
 		@ContextConfiguration
 		class ClasspathNonExistentDefaultLocationsTestCase {
@@ -93,25 +88,25 @@ public class GenericXmlContextLoaderResourceLocationsTests {
 
 		return Arrays.asList(new Object[][] {
 
-			{ ClasspathNonExistentDefaultLocationsTestCase.class, new String[] {} },
+			{ ClasspathNonExistentDefaultLocationsTestCase.class.getSimpleName(), new String[] {} },
 
 			{
-				ClasspathExistentDefaultLocationsTestCase.class,
+				ClasspathExistentDefaultLocationsTestCase.class.getSimpleName(),
 				new String[] { "classpath:org/springframework/test/context/support/GenericXmlContextLoaderResourceLocationsTests$1ClasspathExistentDefaultLocationsTestCase-context.xml" } },
 
 			{
-				ImplicitClasspathLocationsTestCase.class,
+				ImplicitClasspathLocationsTestCase.class.getSimpleName(),
 				new String[] { "classpath:/org/springframework/test/context/support/context1.xml",
 					"classpath:/org/springframework/test/context/support/context2.xml" } },
 
-			{ ExplicitClasspathLocationsTestCase.class, new String[] { "classpath:context.xml" } },
+			{ ExplicitClasspathLocationsTestCase.class.getSimpleName(), new String[] { "classpath:context.xml" } },
 
-			{ ExplicitFileLocationsTestCase.class, new String[] { "file:/testing/directory/context.xml" } },
+			{ ExplicitFileLocationsTestCase.class.getSimpleName(), new String[] { "file:/testing/directory/context.xml" } },
 
-			{ ExplicitUrlLocationsTestCase.class, new String[] { "http://example.com/context.xml" } },
+			{ ExplicitUrlLocationsTestCase.class.getSimpleName(), new String[] { "http://example.com/context.xml" } },
 
 			{
-				ExplicitMixedPathTypesLocationsTestCase.class,
+				ExplicitMixedPathTypesLocationsTestCase.class.getSimpleName(),
 				new String[] { "classpath:/org/springframework/test/context/support/context1.xml",
 					"classpath:context2.xml", "classpath:/context3.xml", "file:/testing/directory/context.xml",
 					"http://example.com/context.xml" } }
@@ -119,6 +114,11 @@ public class GenericXmlContextLoaderResourceLocationsTests {
 		});
 	}
 
+	public GenericXmlContextLoaderResourceLocationsTests(final String testClassName, final String[] expectedLocations) throws Exception {
+		this.testClass = ClassUtils.forName(getClass().getName() + "$1" + testClassName, getClass().getClassLoader());
+		this.expectedLocations = expectedLocations;
+	}
+
 	@Test
 	public void assertContextConfigurationLocations() throws Exception {
 
