@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2014 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,8 +16,8 @@
 
 package org.springframework.test.context.transaction.ejb;
 
+import org.springframework.test.annotation.Commit;
 import org.springframework.test.context.ContextConfiguration;
-import org.springframework.test.context.transaction.TransactionConfiguration;
 import org.springframework.test.context.transaction.TransactionalTestExecutionListener;
 import org.springframework.test.context.transaction.ejb.dao.RequiresNewEjbTxTestEntityDao;
 
@@ -31,7 +31,7 @@ import org.springframework.test.context.transaction.ejb.dao.RequiresNewEjbTxTest
  * @since 4.0.1
  */
 @ContextConfiguration("requires-new-tx-config.xml")
-@TransactionConfiguration(defaultRollback = false)
+@Commit
 public class CommitForRequiresNewEjbTxDaoTests extends AbstractEjbTxDaoTests {
 
 	/* test methods in superclass */
