@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2012 the original author or authors.
+ * Copyright 2002-2014 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,13 +16,15 @@
 
 package org.springframework.test.context.web;
 
-import static org.junit.Assert.*;
-
 import org.junit.Test;
+
+import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.context.annotation.Bean;
 import org.springframework.context.annotation.Configuration;
 import org.springframework.test.context.ContextConfiguration;
 
+import static org.junit.Assert.*;
+
 /**
  * @author Sam Brannen
  * @since 3.2
@@ -37,12 +39,25 @@ public class BasicAnnotationConfigWacTests extends AbstractBasicWacTests {
 		public String foo() {
 			return "enigma";
 		}
+
+		@Bean
+		public ServletContextAwareBean servletContextAwareBean() {
+			return new ServletContextAwareBean();
+		}
 	}
 
+	@Autowired
+	protected ServletContextAwareBean servletContextAwareBean;
 
 	@Test
 	public void fooEnigmaAutowired() {
 		assertEquals("enigma", foo);
 	}
 
+	@Test
+	public void servletContextAwareBeanProcessed() {
+		assertNotNull(servletContextAwareBean);
+		assertNotNull(servletContextAwareBean.servletContext);
+	}
+
 }
