@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2013 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -35,7 +35,7 @@ public class TransactionManagerConfiguration {
 	}
 
 	@Bean
-	@Qualifier("noSynch")
+	@NoSynch
 	public PlatformTransactionManager transactionManager2() {
 		CallCountingTransactionManager tm = new CallCountingTransactionManager();
 		tm.setTransactionSynchronization(CallCountingTransactionManager.SYNCHRONIZATION_NEVER);
