@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2016 the original author or authors.
+ * Copyright 2002-2017 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -64,13 +64,15 @@ public class SimpleClientHttpRequestFactory implements ClientHttpRequestFactory,
 	}
 
 	/**
-	 * Indicates whether this request factory should buffer the {@linkplain ClientHttpRequest#getBody() request body}
-	 * internally.
-	 * <p>Default is {@code true}. When sending large amounts of data via POST or PUT, it is recommended
-	 * to change this property to {@code false}, so as not to run out of memory. This will result in a
-	 * {@link ClientHttpRequest} that either streams directly to the underlying {@link HttpURLConnection}
-	 * (if the {@link org.springframework.http.HttpHeaders#getContentLength() Content-Length} is known in advance),
-	 * or that will use "Chunked transfer encoding" (if the {@code Content-Length} is not known in advance).
+	 * Indicate whether this request factory should buffer the
+	 * {@linkplain ClientHttpRequest#getBody() request body} internally.
+	 * <p>Default is {@code true}. When sending large amounts of data via POST or PUT,
+	 * it is recommended to change this property to {@code false}, so as not to run
+	 * out of memory. This will result in a {@link ClientHttpRequest} that either
+	 * streams directly to the underlying {@link HttpURLConnection} (if the
+	 * {@link org.springframework.http.HttpHeaders#getContentLength() Content-Length}
+	 * is known in advance), or that will use "Chunked transfer encoding"
+	 * (if the {@code Content-Length} is not known in advance).
 	 * @see #setChunkSize(int)
 	 * @see HttpURLConnection#setFixedLengthStreamingMode(int)
 	 */
@@ -79,9 +81,11 @@ public class SimpleClientHttpRequestFactory implements ClientHttpRequestFactory,
 	}
 
 	/**
-	 * Sets the number of bytes to write in each chunk when not buffering request bodies locally.
-	 * <p>Note that this parameter is only used when {@link #setBufferRequestBody(boolean) bufferRequestBody} is set
-	 * to {@code false}, and the {@link org.springframework.http.HttpHeaders#getContentLength() Content-Length}
+	 * Set the number of bytes to write in each chunk when not buffering request
+	 * bodies locally.
+	 * <p>Note that this parameter is only used when
+	 * {@link #setBufferRequestBody(boolean) bufferRequestBody} is set to {@code false},
+	 * and the {@link org.springframework.http.HttpHeaders#getContentLength() Content-Length}
 	 * is not known in advance.
 	 * @see #setBufferRequestBody(boolean)
 	 */
@@ -177,7 +181,9 @@ public class SimpleClientHttpRequestFactory implements ClientHttpRequestFactory,
 	 */
 	protected HttpURLConnection openConnection(URL url, Proxy proxy) throws IOException {
 		URLConnection urlConnection = (proxy != null ? url.openConnection(proxy) : url.openConnection());
-		Assert.isInstanceOf(HttpURLConnection.class, urlConnection);
+		if (!HttpURLConnection.class.isInstance(urlConnection)) {
+			throw new IllegalStateException("HttpURLConnection required for [" + url + "] but got: " + urlConnection);
+		}
 		return (HttpURLConnection) urlConnection;
 	}
 
