@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2016 the original author or authors.
+ * Copyright 2002-2018 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -39,6 +39,7 @@ import org.springframework.util.StringUtils;
  * Extension of {@link UriComponents} for hierarchical URIs.
  *
  * @author Arjen Poutsma
+ * @author Juergen Hoeller
  * @author Rossen Stoyanchev
  * @author Phillip Webb
  * @since 3.1.3
@@ -49,6 +50,9 @@ final class HierarchicalUriComponents extends UriComponents {
 
 	private static final char PATH_DELIMITER = '/';
 
+	private static final String PATH_DELIMITER_STRING = "/";
+
+
 	private final String userInfo;
 
 	private final String host;
@@ -82,17 +86,18 @@ final class HierarchicalUriComponents extends UriComponents {
 		this.userInfo = userInfo;
 		this.host = host;
 		this.port = port;
-		this.path = path != null ? path : NULL_PATH_COMPONENT;
+		this.path = (path != null ? path : NULL_PATH_COMPONENT);
 		this.queryParams = CollectionUtils.unmodifiableMultiValueMap(
 				queryParams != null ? queryParams : new LinkedMultiValueMap<String, String>(0));
 		this.encoded = encoded;
+
 		if (verify) {
 			verify();
 		}
 	}
 
 
-	// component getters
+	// Component getters
 
 	@Override
 	public String getSchemeSpecificPart() {
@@ -166,7 +171,7 @@ final class HierarchicalUriComponents extends UriComponents {
 	}
 
 	/**
-	 * Returns the map of query parameters. Empty if no query has been set.
+	 * Return the map of query parameters. Empty if no query has been set.
 	 */
 	@Override
 	public MultiValueMap<String, String> getQueryParams() {
@@ -174,12 +179,12 @@ final class HierarchicalUriComponents extends UriComponents {
 	}
 
 
-	// encoding
+	// Encoding
 
 	/**
 	 * Encode all URI components using their specific encoding rules and return
 	 * the result as a new {@code UriComponents} instance.
-	 * @param encoding the encoding of the values contained in this map
+	 * @param encoding the encoding of the values
 	 * @return the encoded uri components
 	 * @throws UnsupportedEncodingException if the given encoding is not supported
 	 */
@@ -216,15 +221,13 @@ final class HierarchicalUriComponents extends UriComponents {
 	/**
 	 * Encode the given source into an encoded String using the rules specified
 	 * by the given component and with the given options.
-	 * @param source the source string
-	 * @param encoding the encoding of the source string
+	 * @param source the source String
+	 * @param encoding the encoding of the source String
 	 * @param type the URI component for the source
 	 * @return the encoded URI
-	 * @throws IllegalArgumentException when the given uri parameter is not a valid URI
+	 * @throws IllegalArgumentException when the given value is not a valid URI component
 	 */
-	static String encodeUriComponent(String source, String encoding, Type type)
-			throws UnsupportedEncodingException {
-
+	static String encodeUriComponent(String source, String encoding, Type type) throws UnsupportedEncodingException {
 		if (source == null) {
 			return null;
 		}
@@ -256,11 +259,11 @@ final class HierarchicalUriComponents extends UriComponents {
 	}
 
 	private Type getHostType() {
-		return (this.host != null && this.host.startsWith("[")) ? Type.HOST_IPV6 : Type.HOST_IPV4;
+		return (this.host != null && this.host.startsWith("[") ? Type.HOST_IPV6 : Type.HOST_IPV4);
 	}
 
 
-	// verifying
+	// Verifying
 
 	/**
 	 * Verifies all URI components to determine whether they contain any illegal
@@ -316,7 +319,7 @@ final class HierarchicalUriComponents extends UriComponents {
 	}
 
 
-	// expanding
+	// Expanding
 
 	@Override
 	protected HierarchicalUriComponents expandInternal(UriTemplateVariables uriVariables) {
@@ -362,10 +365,10 @@ final class HierarchicalUriComponents extends UriComponents {
 	}
 
 
-	// other functionality
+	// Other functionality
 
 	/**
-	 * Returns a URI string from this {@code UriComponents} instance.
+	 * Returns a URI String from this {@code UriComponents} instance.
 	 */
 	@Override
 	public String toUriString() {
@@ -477,7 +480,7 @@ final class HierarchicalUriComponents extends UriComponents {
 	}
 
 
-	// inner types
+	// Nested types
 
 	/**
 	 * Enumeration used to identify the allowed characters per URI component.
@@ -575,7 +578,7 @@ final class HierarchicalUriComponents extends UriComponents {
 		 * @see <a href="http://www.ietf.org/rfc/rfc3986.txt">RFC 3986, appendix A</a>
 		 */
 		protected boolean isAlpha(int c) {
-			return c >= 'a' && c <= 'z' || c >= 'A' && c <= 'Z';
+			return (c >= 'a' && c <= 'z' || c >= 'A' && c <= 'Z');
 		}
 
 		/**
@@ -583,7 +586,7 @@ final class HierarchicalUriComponents extends UriComponents {
 		 * @see <a href="http://www.ietf.org/rfc/rfc3986.txt">RFC 3986, appendix A</a>
 		 */
 		protected boolean isDigit(int c) {
-			return c >= '0' && c <= '9';
+			return (c >= '0' && c <= '9');
 		}
 
 		/**
@@ -591,7 +594,7 @@ final class HierarchicalUriComponents extends UriComponents {
 		 * @see <a href="http://www.ietf.org/rfc/rfc3986.txt">RFC 3986, appendix A</a>
 		 */
 		protected boolean isGenericDelimiter(int c) {
-			return ':' == c || '/' == c || '?' == c || '#' == c || '[' == c || ']' == c || '@' == c;
+			return (':' == c || '/' == c || '?' == c || '#' == c || '[' == c || ']' == c || '@' == c);
 		}
 
 		/**
@@ -599,8 +602,8 @@ final class HierarchicalUriComponents extends UriComponents {
 		 * @see <a href="http://www.ietf.org/rfc/rfc3986.txt">RFC 3986, appendix A</a>
 		 */
 		protected boolean isSubDelimiter(int c) {
-			return '!' == c || '$' == c || '&' == c || '\'' == c || '(' == c || ')' == c || '*' == c || '+' == c ||
-					',' == c || ';' == c || '=' == c;
+			return ('!' == c || '$' == c || '&' == c || '\'' == c || '(' == c || ')' == c || '*' == c || '+' == c ||
+					',' == c || ';' == c || '=' == c);
 		}
 
 		/**
@@ -608,7 +611,7 @@ final class HierarchicalUriComponents extends UriComponents {
 		 * @see <a href="http://www.ietf.org/rfc/rfc3986.txt">RFC 3986, appendix A</a>
 		 */
 		protected boolean isReserved(int c) {
-			return isGenericDelimiter(c) || isSubDelimiter(c);
+			return (isGenericDelimiter(c) || isSubDelimiter(c));
 		}
 
 		/**
@@ -616,7 +619,7 @@ final class HierarchicalUriComponents extends UriComponents {
 		 * @see <a href="http://www.ietf.org/rfc/rfc3986.txt">RFC 3986, appendix A</a>
 		 */
 		protected boolean isUnreserved(int c) {
-			return isAlpha(c) || isDigit(c) || '-' == c || '.' == c || '_' == c || '~' == c;
+			return (isAlpha(c) || isDigit(c) || '-' == c || '.' == c || '_' == c || '~' == c);
 		}
 
 		/**
@@ -624,7 +627,7 @@ final class HierarchicalUriComponents extends UriComponents {
 		 * @see <a href="http://www.ietf.org/rfc/rfc3986.txt">RFC 3986, appendix A</a>
 		 */
 		protected boolean isPchar(int c) {
-			return isUnreserved(c) || isSubDelimiter(c) || ':' == c || '@' == c;
+			return (isUnreserved(c) || isSubDelimiter(c) || ':' == c || '@' == c);
 		}
 	}
 
@@ -649,13 +652,12 @@ final class HierarchicalUriComponents extends UriComponents {
 
 
 	/**
-	 * Represents a path backed by a string.
+	 * Represents a path backed by a String.
 	 */
 	static final class FullPathComponent implements PathComponent {
 
 		private final String path;
 
-
 		public FullPathComponent(String path) {
 			this.path = path;
 		}
@@ -667,19 +669,22 @@ final class HierarchicalUriComponents extends UriComponents {
 
 		@Override
 		public List<String> getPathSegments() {
-			String delimiter = new String(new char[]{PATH_DELIMITER});
-			String[] pathSegments = StringUtils.tokenizeToStringArray(path, delimiter);
-			return Collections.unmodifiableList(Arrays.asList(pathSegments));
+			String[] segments = StringUtils.tokenizeToStringArray(getPath(), PATH_DELIMITER_STRING);
+			if (segments == null) {
+				return Collections.emptyList();
+			}
+			return Collections.unmodifiableList(Arrays.asList(segments));
 		}
 
 		@Override
 		public PathComponent encode(String encoding) throws UnsupportedEncodingException {
-			String encodedPath = encodeUriComponent(getPath(),encoding, Type.PATH);
-			return new FullPathComponent(encodedPath);		}
+			String encodedPath = encodeUriComponent(getPath(), encoding, Type.PATH);
+			return new FullPathComponent(encodedPath);
+		}
 
 		@Override
 		public void verify() {
-			verifyUriComponent(this.path, Type.PATH);
+			verifyUriComponent(getPath(), Type.PATH);
 		}
 
 		@Override
@@ -696,25 +701,25 @@ final class HierarchicalUriComponents extends UriComponents {
 		@Override
 		public boolean equals(Object obj) {
 			return (this == obj || (obj instanceof FullPathComponent &&
-					getPath().equals(((FullPathComponent) obj).getPath())));
+					ObjectUtils.nullSafeEquals(getPath(), ((FullPathComponent) obj).getPath())));
 		}
 
 		@Override
 		public int hashCode() {
-			return getPath().hashCode();
+			return ObjectUtils.nullSafeHashCode(getPath());
 		}
 	}
 
 
 	/**
-	 * Represents a path backed by a string list (i.e. path segments).
+	 * Represents a path backed by a String list (i.e. path segments).
 	 */
 	static final class PathSegmentComponent implements PathComponent {
 
 		private final List<String> pathSegments;
 
 		public PathSegmentComponent(List<String> pathSegments) {
-			Assert.notNull(pathSegments);
+			Assert.notNull(pathSegments, "List must not be null");
 			this.pathSegments = Collections.unmodifiableList(new ArrayList<String>(pathSegments));
 		}
 
@@ -792,7 +797,7 @@ final class HierarchicalUriComponents extends UriComponents {
 		private final List<PathComponent> pathComponents;
 
 		public PathComponentComposite(List<PathComponent> pathComponents) {
-			Assert.notNull(pathComponents);
+			Assert.notNull(pathComponents, "PathComponent List must not be null");
 			this.pathComponents = pathComponents;
 		}
 
@@ -880,7 +885,7 @@ final class HierarchicalUriComponents extends UriComponents {
 		}
 		@Override
 		public int hashCode() {
-			return 42;
+			return getClass().hashCode();
 		}
 	};
 
