@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2014 the original author or authors.
+ * Copyright 2002-2016 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -96,6 +96,14 @@ public class UrlPathHelper {
 		this.urlDecode = urlDecode;
 	}
 
+	/**
+	 * Whether to decode the request URI when determining the lookup path.
+	 * @since 4.3.13
+	 */
+	public boolean isUrlDecode() {
+		return this.urlDecode;
+	}
+
 	/**
 	 * Set if ";" (semicolon) content should be stripped from the request URI.
 	 * <p>Default is "true".
@@ -165,6 +173,8 @@ public class UrlPathHelper {
 	 * i.e. the part of the request's URL beyond the part that called the servlet,
 	 * or "" if the whole URL has been used to identify the servlet.
 	 * <p>Detects include request URL if called within a RequestDispatcher include.
+	 * <p>E.g.: servlet mapping = "/*"; request URI = "/test/a" -> "/test/a".
+	 * <p>E.g.: servlet mapping = "/"; request URI = "/test/a" -> "/test/a".
 	 * <p>E.g.: servlet mapping = "/test/*"; request URI = "/test/a" -> "/a".
 	 * <p>E.g.: servlet mapping = "/test"; request URI = "/test" -> "".
 	 * <p>E.g.: servlet mapping = "/*.test"; request URI = "/a.test" -> "".
@@ -174,7 +184,17 @@ public class UrlPathHelper {
 	public String getPathWithinServletMapping(HttpServletRequest request) {
 		String pathWithinApp = getPathWithinApplication(request);
 		String servletPath = getServletPath(request);
-		String path = getRemainingPath(pathWithinApp, servletPath, false);
+		String sanitizedPathWithinApp = getSanitizedPath(pathWithinApp);
+		String path;
+
+		// If the app container sanitized the servletPath, check against the sanitized version
+		if (servletPath.contains(sanitizedPathWithinApp)) {
+			path = getRemainingPath(sanitizedPathWithinApp, servletPath, false);
+		}
+		else {
+			path = getRemainingPath(pathWithinApp, servletPath, false);
+		}
+
 		if (path != null) {
 			// Normal case: URI contains servlet path.
 			return path;
@@ -243,7 +263,7 @@ public class UrlPathHelper {
 			if (c1 == c2) {
 				continue;
 			}
-			if (ignoreCase && (Character.toLowerCase(c1) == Character.toLowerCase(c2))) {
+			else if (ignoreCase && (Character.toLowerCase(c1) == Character.toLowerCase(c2))) {
 				continue;
 			}
 			return null;
@@ -251,7 +271,7 @@ public class UrlPathHelper {
 		if (index2 != mapping.length()) {
 			return null;
 		}
-		if (index1 == requestUri.length()) {
+		else if (index1 == requestUri.length()) {
 			return "";
 		}
 		else if (requestUri.charAt(index1) == ';') {
@@ -260,6 +280,26 @@ public class UrlPathHelper {
 		return (index1 != -1 ? requestUri.substring(index1) : "");
 	}
 
+	/**
+	 * Sanitize the given path with the following rules:
+	 * <ul>
+	 *     <li>replace all "//" by "/"</li>
+	 * </ul>
+	 */
+	private String getSanitizedPath(final String path) {
+		String sanitized = path;
+		while (true) {
+			int index = sanitized.indexOf("//");
+			if (index < 0) {
+				break;
+			}
+			else {
+				sanitized = sanitized.substring(0, index) + sanitized.substring(index + 1);
+			}
+		}
+		return sanitized;
+	}
+
 	/**
 	 * Return the request URI for the given request, detecting an include request
 	 * URL if called within a RequestDispatcher include.
@@ -389,6 +429,7 @@ public class UrlPathHelper {
 	private String decodeAndCleanUriString(HttpServletRequest request, String uri) {
 		uri = removeSemicolonContent(uri);
 		uri = decodeRequestString(request, uri);
+		uri = getSanitizedPath(uri);
 		return uri;
 	}
 
@@ -405,7 +446,7 @@ public class UrlPathHelper {
 	 * @see java.net.URLDecoder#decode(String)
 	 */
 	public String decodeRequestString(HttpServletRequest request, String source) {
-		if (this.urlDecode) {
+		if (this.urlDecode && source != null) {
 			return decodeInternal(request, source);
 		}
 		return source;
@@ -452,8 +493,8 @@ public class UrlPathHelper {
 	 * @return the updated URI string
 	 */
 	public String removeSemicolonContent(String requestUri) {
-		return this.removeSemicolonContent ?
-				removeSemicolonContentInternal(requestUri) : removeJsessionid(requestUri);
+		return (this.removeSemicolonContent ?
+				removeSemicolonContentInternal(requestUri) : removeJsessionid(requestUri));
 	}
 
 	private String removeSemicolonContentInternal(String requestUri) {
