@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2015 the original author or authors.
+ * Copyright 2002-2016 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -39,7 +39,7 @@ import org.springframework.util.StreamUtils;
 import org.springframework.util.concurrent.ListenableFuture;
 import org.springframework.util.concurrent.ListenableFutureCallback;
 
-public abstract class AbstractAsyncHttpRequestFactoryTestCase extends AbstractJettyServerTestCase {
+public abstract class AbstractAsyncHttpRequestFactoryTestCase extends AbstractMockWebServerTestCase {
 
 	protected AsyncClientHttpRequestFactory factory;
 
@@ -222,4 +222,14 @@ public abstract class AbstractAsyncHttpRequestFactoryTestCase extends AbstractJe
 		}
 	}
 
+	@Test
+	public void cancel() throws Exception {
+		URI uri = new URI(baseUrl + "/status/notfound");
+		AsyncClientHttpRequest request = this.factory.createAsyncRequest(uri, HttpMethod.GET);
+		Future<ClientHttpResponse> futureResponse = request.executeAsync();
+		futureResponse.cancel(true);
+		assertTrue(futureResponse.isCancelled());
+	}
+
+
 }
