@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2012 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -24,6 +24,7 @@ import org.junit.Before;
 import org.junit.Test;
 
 import org.springframework.core.MethodParameter;
+import org.springframework.core.annotation.SynthesizingMethodParameter;
 import org.springframework.http.HttpHeaders;
 import org.springframework.mock.web.test.MockHttpServletRequest;
 import org.springframework.mock.web.test.MockHttpServletResponse;
@@ -57,20 +58,22 @@ public class RequestHeaderMapMethodArgumentResolverTests {
 
 	private MockHttpServletRequest request;
 
+
 	@Before
 	public void setUp() throws Exception {
 		resolver = new RequestHeaderMapMethodArgumentResolver();
 
 		Method method = getClass().getMethod("params", Map.class, MultiValueMap.class, HttpHeaders.class, Map.class);
-		paramMap = new MethodParameter(method, 0);
-		paramMultiValueMap = new MethodParameter(method, 1);
-		paramHttpHeaders = new MethodParameter(method, 2);
-		paramUnsupported = new MethodParameter(method, 3);
+		paramMap = new SynthesizingMethodParameter(method, 0);
+		paramMultiValueMap = new SynthesizingMethodParameter(method, 1);
+		paramHttpHeaders = new SynthesizingMethodParameter(method, 2);
+		paramUnsupported = new SynthesizingMethodParameter(method, 3);
 
 		request = new MockHttpServletRequest();
 		webRequest = new ServletWebRequest(request, new MockHttpServletResponse());
 	}
 
+
 	@Test
 	public void supportsParameter() {
 		assertTrue("Map parameter not supported", resolver.supportsParameter(paramMap));
@@ -130,10 +133,11 @@ public class RequestHeaderMapMethodArgumentResolverTests {
 		assertEquals("Invalid result", expected, result);
 	}
 
+
 	public void params(@RequestHeader Map<?, ?> param1,
 					   @RequestHeader MultiValueMap<?, ?> param2,
 					   @RequestHeader HttpHeaders param3,
 					   Map<?,?> unsupported) {
 	}
 
-}
\ No newline at end of file
+}
