@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2012 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -18,7 +18,6 @@ package org.springframework.web.util;
 
 import java.io.UnsupportedEncodingException;
 
-import org.junit.Before;
 import org.junit.Ignore;
 import org.junit.Test;
 
@@ -27,23 +26,20 @@ import org.springframework.mock.web.test.MockHttpServletRequest;
 import static org.junit.Assert.*;
 
 /**
+ * Unit tests for {@link UrlPathHelper}.
+ *
  * @author Rob Harrop
  * @author Juergen Hoeller
  * @author Costin Leau
  */
 public class UrlPathHelperTests {
 
-	private UrlPathHelper helper;
-
-	private MockHttpServletRequest request;
-
 	private static final String WEBSPHERE_URI_ATTRIBUTE = "com.ibm.websphere.servlet.uri_non_decoded";
 
-	@Before
-	public void setUp() {
-		helper = new UrlPathHelper();
-		request = new MockHttpServletRequest();
-	}
+	private final UrlPathHelper helper = new UrlPathHelper();
+
+	private final MockHttpServletRequest request = new MockHttpServletRequest();
+
 
 	@Test
 	public void getPathWithinApplication() {
@@ -78,6 +74,16 @@ public class UrlPathHelperTests {
 		assertEquals("Incorrect path returned", "/welcome.html", helper.getPathWithinServletMapping(request));
 	}
 
+	@Test
+	public void alwaysUseFullPath() {
+		helper.setAlwaysUseFullPath(true);
+		request.setContextPath("/petclinic");
+		request.setServletPath("/main");
+		request.setRequestURI("/petclinic/main/welcome.html");
+
+		assertEquals("Incorrect path returned", "/main/welcome.html", helper.getLookupPathForRequest(request));
+	}
+
 	// SPR-11101
 
 	@Test
@@ -102,7 +108,6 @@ public class UrlPathHelperTests {
 
 		request.setRequestURI("/foo+bar");
 		assertEquals("Incorrect path returned", "/foo+bar", helper.getRequestUri(request));
-
 	}
 
 	@Test
@@ -111,6 +116,13 @@ public class UrlPathHelperTests {
 
 		request.setRequestURI("/foo;f=F;o=O;o=O/bar;b=B;a=A;r=R");
 		assertEquals("/foo/bar", helper.getRequestUri(request));
+
+		// SPR-13455
+
+		request.setServletPath("/foo/1");
+		request.setRequestURI("/foo/;test/1");
+
+		assertEquals("/foo/1", helper.getRequestUri(request));
 	}
 
 	@Test
@@ -194,6 +206,28 @@ public class UrlPathHelperTests {
 		assertEquals("/foo/", helper.getLookupPathForRequest(request));
 	}
 
+	//SPR-12372 & SPR-13455
+	@Test
+	public void removeDuplicateSlashesInPath() throws Exception {
+		request.setContextPath("/SPR-12372");
+		request.setPathInfo(null);
+		request.setServletPath("/foo/bar/");
+		request.setRequestURI("/SPR-12372/foo//bar/");
+
+		assertEquals("/foo/bar/", helper.getLookupPathForRequest(request));
+
+		request.setServletPath("/foo/bar/");
+		request.setRequestURI("/SPR-12372/foo/bar//");
+
+		assertEquals("/foo/bar/", helper.getLookupPathForRequest(request));
+
+		// "normal" case
+		request.setServletPath("/foo/bar//");
+		request.setRequestURI("/SPR-12372/foo/bar//");
+
+		assertEquals("/foo/bar//", helper.getLookupPathForRequest(request));
+	}
+
 	@Test
 	public void wasDefaultServletRoot() throws Exception {
 		request.setContextPath("/test");
@@ -315,7 +349,8 @@ public class UrlPathHelperTests {
 	}
 
 	// test the root mapping for /foo/* w/o a trailing slash - <host>/<context>/foo
-	@Test @Ignore
+	@Ignore
+	@Test
 	public void wasCasualServletRootWithMissingSlash() throws Exception {
 		request.setContextPath("/test");
 		request.setPathInfo(null);
@@ -326,7 +361,8 @@ public class UrlPathHelperTests {
 		assertEquals("/", helper.getLookupPathForRequest(request));
 	}
 
-	@Test @Ignore
+	@Ignore
+	@Test
 	public void wasCasualServletRootWithMissingSlashWithCompliantSetting() throws Exception {
 		request.setAttribute(WEBSPHERE_URI_ATTRIBUTE, "/test/foo");
 		tomcatCasualServletRootWithMissingSlash();
@@ -366,6 +402,26 @@ public class UrlPathHelperTests {
 		tomcatCasualServletFolder();
 	}
 
+	@Test
+	public void getOriginatingRequestUri() {
+		request.setAttribute(WebUtils.FORWARD_REQUEST_URI_ATTRIBUTE, "/path");
+		request.setRequestURI("/forwarded");
+		assertEquals("/path", helper.getOriginatingRequestUri(request));
+	}
+
+	@Test
+	public void getOriginatingRequestUriWebsphere() {
+		request.setAttribute(WEBSPHERE_URI_ATTRIBUTE, "/path");
+		request.setRequestURI("/forwarded");
+		assertEquals("/path", helper.getOriginatingRequestUri(request));
+	}
+
+	@Test
+	public void getOriginatingRequestUriDefault() {
+		request.setRequestURI("/forwarded");
+		assertEquals("/forwarded", helper.getOriginatingRequestUri(request));
+	}
+
 	@Test
 	public void getOriginatingQueryString() {
 		request.setQueryString("forward=on");
