@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2013 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -18,6 +18,7 @@ package org.springframework.web.portlet.context;
 
 import javax.servlet.ServletException;
 
+import org.junit.Test;
 import org.springframework.beans.factory.DisposableBean;
 import org.springframework.beans.factory.InitializingBean;
 import org.springframework.context.AbstractApplicationContextTests;
@@ -26,6 +27,8 @@ import org.springframework.context.TestListener;
 import org.springframework.tests.sample.beans.TestBean;
 import org.springframework.web.context.ConfigurableWebApplicationContext;
 
+import static org.junit.Assert.*;
+
 /**
  * Should ideally be eliminated.  Copied when splitting .testsuite up into individual bundles.
  *
@@ -53,13 +56,15 @@ public abstract class AbstractXmlWebApplicationContextTests extends AbstractAppl
 
 	};
 
+	@Test
 	@Override
-	public void testCount() {
+	public void count() {
 		assertTrue("should have 14 beans, not "+ this.applicationContext.getBeanDefinitionCount(),
 			this.applicationContext.getBeanDefinitionCount() == 14);
 	}
 
-	public void testContextNesting() {
+	@Test
+	public void contextNesting() {
 		TestBean father = (TestBean) this.applicationContext.getBean("father");
 		assertTrue("Bean from root context", father != null);
 		assertTrue("Custom BeanPostProcessor applied", father.getFriends().contains("myFriend"));
@@ -74,7 +79,8 @@ public abstract class AbstractXmlWebApplicationContextTests extends AbstractAppl
 		assertTrue("Custom BeanPostProcessor applied", rod.getFriends().contains("myFriend"));
 	}
 
-	public void testInitializingBeanAndInitMethod() throws Exception {
+	@Test
+	public void initializingBeanAndInitMethod() throws Exception {
 		assertFalse(InitAndIB.constructed);
 		InitAndIB iib = (InitAndIB) this.applicationContext.getBean("init-and-ib");
 		assertTrue(InitAndIB.constructed);
