@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2014 the original author or authors.
+ * Copyright 2002-2016 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -43,17 +43,11 @@ import org.springframework.web.util.UriUtils;
  * populating the data for their view. The name of this form object can be
  * configured using the {@link #setModelAttribute "modelAttribute"} property.
  *
- * <p>The default value for the {@link #setModelAttribute "modelAttribute"}
- * property is '{@code command}' which corresponds to the default name
- * when using the
- * {@link org.springframework.web.servlet.mvc.SimpleFormController SimpleFormController}.
- *
  * @author Rob Harrop
  * @author Juergen Hoeller
  * @author Scott Andrews
  * @author Rossen Stoyanchev
  * @since 2.0
- * @see org.springframework.web.servlet.mvc.SimpleFormController
  */
 @SuppressWarnings("serial")
 public class FormTag extends AbstractHtmlElementTag {
@@ -153,7 +147,9 @@ public class FormTag extends AbstractHtmlElementTag {
 	 * Set the name of the form attribute in the model.
 	 * <p>May be a runtime expression.
 	 * @see #setModelAttribute
+	 * @deprecated as of Spring 4.3, in favor of {@link #setModelAttribute}
 	 */
+	@Deprecated
 	public void setCommandName(String commandName) {
 		this.modelAttribute = commandName;
 	}
@@ -161,7 +157,9 @@ public class FormTag extends AbstractHtmlElementTag {
 	/**
 	 * Get the name of the form attribute in the model.
 	 * @see #getModelAttribute
+	 * @deprecated as of Spring 4.3, in favor of {@link #getModelAttribute}
 	 */
+	@Deprecated
 	protected String getCommandName() {
 		return this.modelAttribute;
 	}
@@ -200,15 +198,18 @@ public class FormTag extends AbstractHtmlElementTag {
 	}
 
 	/**
-	 * Set the value of the '{@code action}' attribute.
+	 * Set the value of the '{@code action}' attribute through a value
+	 * that is to be appended to the current servlet path.
 	 * <p>May be a runtime expression.
+	 * @since 3.2.3
 	 */
-	public void setServletRelativeAction(String servletRelativeaction) {
-		this.servletRelativeAction = (servletRelativeaction != null ? servletRelativeaction : "");
+	public void setServletRelativeAction(String servletRelativeAction) {
+		this.servletRelativeAction = (servletRelativeAction != null ? servletRelativeAction : "");
 	}
 
 	/**
-	 * Get the value of the '{@code action}' attribute.
+	 * Get the servlet-relative value of the '{@code action}' attribute.
+	 * @since 3.2.3
 	 */
 	protected String getServletRelativeAction() {
 		return this.servletRelativeAction;
@@ -328,7 +329,19 @@ public class FormTag extends AbstractHtmlElementTag {
 
 	/**
 	 * Get the name of the request param for non-browser supported HTTP methods.
+	 * @since 4.2.3
 	 */
+	@SuppressWarnings("deprecation")
+	protected String getMethodParam() {
+		return getMethodParameter();
+	}
+
+	/**
+	 * Get the name of the request param for non-browser supported HTTP methods.
+	 * @deprecated as of 4.2.3, in favor of {@link #getMethodParam()} which is
+	 * a proper pairing for {@link #setMethodParam(String)}
+	 */
+	@Deprecated
 	protected String getMethodParameter() {
 		return this.methodParam;
 	}
@@ -340,6 +353,7 @@ public class FormTag extends AbstractHtmlElementTag {
 		return ("get".equalsIgnoreCase(method) || "post".equalsIgnoreCase(method));
 	}
 
+
 	/**
 	 * Writes the opening part of the block	'{@code form}' tag and exposes
 	 * the form object name in the {@link javax.servlet.jsp.PageContext}.
@@ -365,7 +379,7 @@ public class FormTag extends AbstractHtmlElementTag {
 
 		if (!isMethodBrowserSupported(getMethod())) {
 			assertHttpMethod(getMethod());
-			String inputName = getMethodParameter();
+			String inputName = getMethodParam();
 			String inputType = "hidden";
 			tagWriter.startTag(INPUT_TAG);
 			writeOptionalAttribute(tagWriter, TYPE_ATTRIBUTE, inputType);
@@ -377,7 +391,6 @@ public class FormTag extends AbstractHtmlElementTag {
 		// Expose the form object name for nested tags...
 		String modelAttribute = resolveModelAttribute();
 		this.pageContext.setAttribute(MODEL_ATTRIBUTE_VARIABLE_NAME, modelAttribute, PageContext.REQUEST_SCOPE);
-		this.pageContext.setAttribute(COMMAND_NAME_VARIABLE_NAME, modelAttribute, PageContext.REQUEST_SCOPE);
 
 		// Save previous nestedPath value, build and expose current nestedPath value.
 		// Use request scope to expose nestedPath to included pages too.
@@ -483,7 +496,7 @@ public class FormTag extends AbstractHtmlElementTag {
 		RequestDataValueProcessor processor = getRequestContext().getRequestDataValueProcessor();
 		ServletRequest request = this.pageContext.getRequest();
 		if (processor != null && request instanceof HttpServletRequest) {
-			action = processor.processAction((HttpServletRequest) request, action);
+			action = processor.processAction((HttpServletRequest) request, action, getHttpMethod());
 		}
 		return action;
 	}
@@ -508,11 +521,13 @@ public class FormTag extends AbstractHtmlElementTag {
 	 */
 	private void writeHiddenFields(Map<String, String> hiddenFields) throws JspException {
 		if (hiddenFields != null) {
+			this.tagWriter.appendValue("<div>\n");
 			for (String name : hiddenFields.keySet()) {
 				this.tagWriter.appendValue("<input type=\"hidden\" ");
 				this.tagWriter.appendValue("name=\"" + name + "\" value=\"" + hiddenFields.get(name) + "\" ");
 				this.tagWriter.appendValue("/>\n");
 			}
+			this.tagWriter.appendValue("</div>");
 		}
 	}
 
@@ -523,7 +538,6 @@ public class FormTag extends AbstractHtmlElementTag {
 	public void doFinally() {
 		super.doFinally();
 		this.pageContext.removeAttribute(MODEL_ATTRIBUTE_VARIABLE_NAME, PageContext.REQUEST_SCOPE);
-		this.pageContext.removeAttribute(COMMAND_NAME_VARIABLE_NAME, PageContext.REQUEST_SCOPE);
 		if (this.previousNestedPath != null) {
 			// Expose previous nestedPath value.
 			this.pageContext.setAttribute(NESTED_PATH_VARIABLE_NAME, this.previousNestedPath, PageContext.REQUEST_SCOPE);
