@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2014 the original author or authors.
+ * Copyright 2002-2017 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -18,10 +18,13 @@ package org.springframework.web.servlet.view;
 
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
+import java.util.Arrays;
 import java.util.Collections;
+import java.util.HashSet;
 import java.util.LinkedHashMap;
 import java.util.Map;
 import java.util.Properties;
+import java.util.Set;
 import java.util.StringTokenizer;
 import javax.servlet.ServletOutputStream;
 import javax.servlet.http.HttpServletRequest;
@@ -30,6 +33,7 @@ import javax.servlet.http.HttpServletResponse;
 import org.springframework.beans.factory.BeanNameAware;
 import org.springframework.http.MediaType;
 import org.springframework.util.CollectionUtils;
+import org.springframework.web.context.support.ContextExposingHttpServletRequest;
 import org.springframework.web.context.support.WebApplicationObjectSupport;
 import org.springframework.web.servlet.View;
 import org.springframework.web.servlet.support.RequestContext;
@@ -62,34 +66,20 @@ public abstract class AbstractView extends WebApplicationObjectSupport implement
 	private static final int OUTPUT_BYTE_ARRAY_INITIAL_SIZE = 4096;
 
 
-	private String beanName;
-
 	private String contentType = DEFAULT_CONTENT_TYPE;
 
 	private String requestContextAttribute;
 
-	/** Map of static attributes, keyed by attribute name (String) */
 	private final Map<String, Object> staticAttributes = new LinkedHashMap<String, Object>();
 
-	/** Whether or not the view should add path variables in the model */
 	private boolean exposePathVariables = true;
 
+	private boolean exposeContextBeansAsAttributes = false;
 
-	/**
-	 * Set the view's name. Helpful for traceability.
-	 * <p>Framework code must call this when constructing views.
-	 */
-	public void setBeanName(String beanName) {
-		this.beanName = beanName;
-	}
+	private Set<String> exposedContextBeanNames;
+
+	private String beanName;
 
-	/**
-	 * Return the view's name. Should never be {@code null},
-	 * if the view was correctly configured.
-	 */
-	public String getBeanName() {
-		return this.beanName;
-	}
 
 	/**
 	 * Set the content type for this view.
@@ -104,6 +94,7 @@ public abstract class AbstractView extends WebApplicationObjectSupport implement
 	/**
 	 * Return the content type for this view.
 	 */
+	@Override
 	public String getContentType() {
 		return this.contentType;
 	}
@@ -246,6 +237,53 @@ public abstract class AbstractView extends WebApplicationObjectSupport implement
 		return this.exposePathVariables;
 	}
 
+	/**
+	 * Set whether to make all Spring beans in the application context accessible
+	 * as request attributes, through lazy checking once an attribute gets accessed.
+	 * <p>This will make all such beans accessible in plain {@code ${...}}
+	 * expressions in a JSP 2.0 page, as well as in JSTL's {@code c:out}
+	 * value expressions.
+	 * <p>Default is "false". Switch this flag on to transparently expose all
+	 * Spring beans in the request attribute namespace.
+	 * <p><b>NOTE:</b> Context beans will override any custom request or session
+	 * attributes of the same name that have been manually added. However, model
+	 * attributes (as explicitly exposed to this view) of the same name will
+	 * always override context beans.
+	 * @see #getRequestToExpose
+	 */
+	public void setExposeContextBeansAsAttributes(boolean exposeContextBeansAsAttributes) {
+		this.exposeContextBeansAsAttributes = exposeContextBeansAsAttributes;
+	}
+
+	/**
+	 * Specify the names of beans in the context which are supposed to be exposed.
+	 * If this is non-null, only the specified beans are eligible for exposure as
+	 * attributes.
+	 * <p>If you'd like to expose all Spring beans in the application context, switch
+	 * the {@link #setExposeContextBeansAsAttributes "exposeContextBeansAsAttributes"}
+	 * flag on but do not list specific bean names for this property.
+	 */
+	public void setExposedContextBeanNames(String... exposedContextBeanNames) {
+		this.exposedContextBeanNames = new HashSet<String>(Arrays.asList(exposedContextBeanNames));
+	}
+
+	/**
+	 * Set the view's name. Helpful for traceability.
+	 * <p>Framework code must call this when constructing views.
+	 */
+	@Override
+	public void setBeanName(String beanName) {
+		this.beanName = beanName;
+	}
+
+	/**
+	 * Return the view's name. Should never be {@code null},
+	 * if the view was correctly configured.
+	 */
+	public String getBeanName() {
+		return this.beanName;
+	}
+
 
 	/**
 	 * Prepares the view given the specified model, merging it with static
@@ -253,6 +291,7 @@ public abstract class AbstractView extends WebApplicationObjectSupport implement
 	 * Delegates to renderMergedOutputModel for the actual rendering.
 	 * @see #renderMergedOutputModel
 	 */
+	@Override
 	public void render(Map<String, ?> model, HttpServletRequest request, HttpServletResponse response) throws Exception {
 		if (logger.isTraceEnabled()) {
 			logger.trace("Rendering view with name '" + this.beanName + "' with model " + model +
@@ -261,7 +300,7 @@ public abstract class AbstractView extends WebApplicationObjectSupport implement
 
 		Map<String, Object> mergedModel = createMergedOutputModel(model, request, response);
 		prepareResponse(request, response);
-		renderMergedOutputModel(mergedModel, request, response);
+		renderMergedOutputModel(mergedModel, getRequestToExpose(request), response);
 	}
 
 	/**
@@ -299,7 +338,7 @@ public abstract class AbstractView extends WebApplicationObjectSupport implement
 
 	/**
 	 * Create a RequestContext to expose under the specified attribute name.
-	 * <p>Default implementation creates a standard RequestContext instance for the
+	 * <p>The default implementation creates a standard RequestContext instance for the
 	 * given request and model. Can be overridden in subclasses for custom instances.
 	 * @param request current HTTP request
 	 * @param model combined output Map (never {@code null}),
@@ -342,6 +381,24 @@ public abstract class AbstractView extends WebApplicationObjectSupport implement
 		return false;
 	}
 
+	/**
+	 * Get the request handle to expose to {@link #renderMergedOutputModel}, i.e. to the view.
+	 * <p>The default implementation wraps the original request for exposure of Spring beans
+	 * as request attributes (if demanded).
+	 * @param originalRequest the original servlet request as provided by the engine
+	 * @return the wrapped request, or the original request if no wrapping is necessary
+	 * @see #setExposeContextBeansAsAttributes
+	 * @see #setExposedContextBeanNames
+	 * @see org.springframework.web.context.support.ContextExposingHttpServletRequest
+	 */
+	protected HttpServletRequest getRequestToExpose(HttpServletRequest originalRequest) {
+		if (this.exposeContextBeansAsAttributes || this.exposedContextBeanNames != null) {
+			return new ContextExposingHttpServletRequest(
+					originalRequest, getWebApplicationContext(), this.exposedContextBeanNames);
+		}
+		return originalRequest;
+	}
+
 	/**
 	 * Subclasses must implement this method to actually render the view.
 	 * <p>The first step will be preparing the request: In the JSP case,
