@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2013 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,8 +17,11 @@
 package org.springframework.web.context;
 
 import java.util.Locale;
+
 import javax.servlet.ServletException;
 
+import org.junit.Test;
+
 import org.springframework.beans.BeansException;
 import org.springframework.beans.factory.DisposableBean;
 import org.springframework.beans.factory.InitializingBean;
@@ -57,7 +60,6 @@ public class XmlWebApplicationContextTests extends AbstractApplicationContextTes
 			public void postProcessBeanFactory(ConfigurableListableBeanFactory beanFactory) {
 				beanFactory.addBeanPostProcessor(new BeanPostProcessor() {
 					@Override
-					@SuppressWarnings("unchecked")
 					public Object postProcessBeforeInitialization(Object bean, String name) throws BeansException {
 						if (bean instanceof TestBean) {
 							((TestBean) bean).getFriends().add("myFriend");
@@ -82,7 +84,8 @@ public class XmlWebApplicationContextTests extends AbstractApplicationContextTes
 		return wac;
 	}
 
-	public void testEnvironmentMerge() {
+	@Test
+	public void environmentMerge() {
 		assertThat(this.root.getEnvironment().acceptsProfiles("rootProfile1"), is(true));
 		assertThat(this.root.getEnvironment().acceptsProfiles("wacProfile1"), is(false));
 		assertThat(this.applicationContext.getEnvironment().acceptsProfiles("rootProfile1"), is(true));
@@ -101,13 +104,16 @@ public class XmlWebApplicationContextTests extends AbstractApplicationContextTes
 		super.doTestEvents(listenerBean, parentListenerBean, event);
 	}
 
+	@Test
 	@Override
-	public void testCount() {
+	public void count() {
 		assertTrue("should have 14 beans, not "+ this.applicationContext.getBeanDefinitionCount(),
 			this.applicationContext.getBeanDefinitionCount() == 14);
 	}
 
-	public void testWithoutMessageSource() throws Exception {
+	@Test
+	@SuppressWarnings("resource")
+	public void withoutMessageSource() throws Exception {
 		MockServletContext sc = new MockServletContext("");
 		XmlWebApplicationContext wac = new XmlWebApplicationContext();
 		wac.setParent(root);
@@ -126,7 +132,8 @@ public class XmlWebApplicationContextTests extends AbstractApplicationContextTes
 		assertTrue("Default message returned", "default".equals(msg));
 	}
 
-	public void testContextNesting() {
+	@Test
+	public void contextNesting() {
 		TestBean father = (TestBean) this.applicationContext.getBean("father");
 		assertTrue("Bean from root context", father != null);
 		assertTrue("Custom BeanPostProcessor applied", father.getFriends().contains("myFriend"));
@@ -141,7 +148,8 @@ public class XmlWebApplicationContextTests extends AbstractApplicationContextTes
 		assertTrue("Custom BeanPostProcessor applied", rod.getFriends().contains("myFriend"));
 	}
 
-	public void testInitializingBeanAndInitMethod() throws Exception {
+	@Test
+	public void initializingBeanAndInitMethod() throws Exception {
 		assertFalse(InitAndIB.constructed);
 		InitAndIB iib = (InitAndIB) this.applicationContext.getBean("init-and-ib");
 		assertTrue(InitAndIB.constructed);
