@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2014 the original author or authors.
+ * Copyright 2002-2017 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -42,6 +42,7 @@ public class ContentNegotiationConfigurerTests {
 
 	private MockHttpServletRequest servletRequest;
 
+
 	@Before
 	public void setup() {
 		this.servletRequest = new MockHttpServletRequest();
@@ -49,9 +50,10 @@ public class ContentNegotiationConfigurerTests {
 		this.configurer = new ContentNegotiationConfigurer(this.servletRequest.getServletContext());
 	}
 
+
 	@Test
 	public void defaultSettings() throws Exception {
-		ContentNegotiationManager manager = this.configurer.getContentNegotiationManager();
+		ContentNegotiationManager manager = this.configurer.buildContentNegotiationManager();
 
 		this.servletRequest.setRequestURI("/flower.gif");
 
@@ -74,7 +76,7 @@ public class ContentNegotiationConfigurerTests {
 	@Test
 	public void addMediaTypes() throws Exception {
 		this.configurer.mediaTypes(Collections.singletonMap("json", MediaType.APPLICATION_JSON));
-		ContentNegotiationManager manager = this.configurer.getContentNegotiationManager();
+		ContentNegotiationManager manager = this.configurer.buildContentNegotiationManager();
 
 		this.servletRequest.setRequestURI("/flower.json");
 		assertEquals(Arrays.asList(MediaType.APPLICATION_JSON), manager.resolveMediaTypes(this.webRequest));
@@ -85,7 +87,7 @@ public class ContentNegotiationConfigurerTests {
 		this.configurer.favorParameter(true);
 		this.configurer.parameterName("f");
 		this.configurer.mediaTypes(Collections.singletonMap("json", MediaType.APPLICATION_JSON));
-		ContentNegotiationManager manager = this.configurer.getContentNegotiationManager();
+		ContentNegotiationManager manager = this.configurer.buildContentNegotiationManager();
 
 		this.servletRequest.setRequestURI("/flower");
 		this.servletRequest.addParameter("f", "json");
@@ -96,7 +98,7 @@ public class ContentNegotiationConfigurerTests {
 	@Test
 	public void ignoreAcceptHeader() throws Exception {
 		this.configurer.ignoreAcceptHeader(true);
-		ContentNegotiationManager manager = this.configurer.getContentNegotiationManager();
+		ContentNegotiationManager manager = this.configurer.buildContentNegotiationManager();
 
 		this.servletRequest.setRequestURI("/flower");
 		this.servletRequest.addHeader("Accept", MediaType.IMAGE_GIF_VALUE);
@@ -107,7 +109,7 @@ public class ContentNegotiationConfigurerTests {
 	@Test
 	public void setDefaultContentType() throws Exception {
 		this.configurer.defaultContentType(MediaType.APPLICATION_JSON);
-		ContentNegotiationManager manager = this.configurer.getContentNegotiationManager();
+		ContentNegotiationManager manager = this.configurer.buildContentNegotiationManager();
 
 		assertEquals(Arrays.asList(MediaType.APPLICATION_JSON), manager.resolveMediaTypes(this.webRequest));
 	}
@@ -115,8 +117,9 @@ public class ContentNegotiationConfigurerTests {
 	@Test
 	public void setDefaultContentTypeStrategy() throws Exception {
 		this.configurer.defaultContentTypeStrategy(new FixedContentNegotiationStrategy(MediaType.APPLICATION_JSON));
-		ContentNegotiationManager manager = this.configurer.getContentNegotiationManager();
+		ContentNegotiationManager manager = this.configurer.buildContentNegotiationManager();
 
 		assertEquals(Arrays.asList(MediaType.APPLICATION_JSON), manager.resolveMediaTypes(this.webRequest));
 	}
+
 }
