@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2014 the original author or authors.
+ * Copyright 2002-2016 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,7 +17,7 @@
 package org.springframework.web.servlet.config.annotation;
 
 import java.util.ArrayList;
-import java.util.Arrays;
+import java.util.Collections;
 import java.util.List;
 
 import org.junit.Before;
@@ -29,7 +29,6 @@ import org.mockito.MockitoAnnotations;
 
 import org.springframework.core.convert.ConversionService;
 import org.springframework.format.support.FormattingConversionService;
-import org.springframework.http.HttpMessage;
 import org.springframework.http.converter.HttpMessageConverter;
 import org.springframework.http.converter.StringHttpMessageConverter;
 import org.springframework.util.PathMatcher;
@@ -90,10 +89,10 @@ public class DelegatingWebMvcConfigurationTests {
 		delegatingConfig = new DelegatingWebMvcConfiguration();
 	}
 
+
 	@Test
 	public void requestMappingHandlerAdapter() throws Exception {
-
-		delegatingConfig.setConfigurers(Arrays.asList(webMvcConfigurer));
+		delegatingConfig.setConfigurers(Collections.singletonList(webMvcConfigurer));
 		RequestMappingHandlerAdapter adapter = delegatingConfig.requestMappingHandlerAdapter();
 
 		ConfigurableWebBindingInitializer initializer = (ConfigurableWebBindingInitializer) adapter.getWebBindingInitializer();
@@ -142,7 +141,7 @@ public class DelegatingWebMvcConfigurationTests {
 	public void getCustomValidator() {
 		given(webMvcConfigurer.getValidator()).willReturn(new LocalValidatorFactoryBean());
 
-		delegatingConfig.setConfigurers(Arrays.asList(webMvcConfigurer));
+		delegatingConfig.setConfigurers(Collections.singletonList(webMvcConfigurer));
 		delegatingConfig.mvcValidator();
 
 		verify(webMvcConfigurer).getValidator();
@@ -152,7 +151,7 @@ public class DelegatingWebMvcConfigurationTests {
 	public void getCustomMessageCodesResolver() {
 		given(webMvcConfigurer.getMessageCodesResolver()).willReturn(new DefaultMessageCodesResolver());
 
-		delegatingConfig.setConfigurers(Arrays.asList(webMvcConfigurer));
+		delegatingConfig.setConfigurers(Collections.singletonList(webMvcConfigurer));
 		delegatingConfig.getMessageCodesResolver();
 
 		verify(webMvcConfigurer).getMessageCodesResolver();
@@ -160,8 +159,7 @@ public class DelegatingWebMvcConfigurationTests {
 
 	@Test
 	public void handlerExceptionResolver() throws Exception {
-
-		delegatingConfig.setConfigurers(Arrays.asList(webMvcConfigurer));
+		delegatingConfig.setConfigurers(Collections.singletonList(webMvcConfigurer));
 		delegatingConfig.handlerExceptionResolver();
 
 		verify(webMvcConfigurer).configureMessageConverters(converters.capture());
@@ -187,7 +185,7 @@ public class DelegatingWebMvcConfigurationTests {
 		delegatingConfig.setConfigurers(configurers);
 
 		HandlerExceptionResolverComposite composite =
-			(HandlerExceptionResolverComposite) delegatingConfig.handlerExceptionResolver();
+				(HandlerExceptionResolverComposite) delegatingConfig.handlerExceptionResolver();
 		assertEquals("Only one custom converter is expected", 1, composite.getExceptionResolvers().size());
 	}
 
@@ -201,9 +199,9 @@ public class DelegatingWebMvcConfigurationTests {
 			@Override
 			public void configurePathMatch(PathMatchConfigurer configurer) {
 				configurer.setUseRegisteredSuffixPatternMatch(true)
-					.setUseTrailingSlashMatch(false)
-					.setUrlPathHelper(pathHelper)
-					.setPathMatcher(pathMatcher);
+						.setUseTrailingSlashMatch(false)
+						.setUrlPathHelper(pathHelper)
+						.setPathMatcher(pathMatcher);
 			}
 		});
 		delegatingConfig.setConfigurers(configurers);
