@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2013 the original author or authors.
+ * Copyright 2002-2016 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -13,19 +13,21 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
+
 package org.springframework.web.servlet.mvc.method.annotation;
 
 import java.lang.reflect.Method;
 import java.util.Arrays;
 import java.util.EnumSet;
 import java.util.List;
-import javax.servlet.http.HttpServletRequest;
 
 import org.junit.Before;
 import org.junit.Test;
+import org.mockito.Mockito;
 
 import org.springframework.beans.ConversionNotSupportedException;
 import org.springframework.beans.TypeMismatchException;
+import org.springframework.core.MethodParameter;
 import org.springframework.http.HttpHeaders;
 import org.springframework.http.HttpMethod;
 import org.springframework.http.HttpStatus;
@@ -41,12 +43,14 @@ import org.springframework.web.HttpMediaTypeNotAcceptableException;
 import org.springframework.web.HttpMediaTypeNotSupportedException;
 import org.springframework.web.HttpRequestMethodNotSupportedException;
 import org.springframework.web.bind.MethodArgumentNotValidException;
+import org.springframework.web.bind.MissingPathVariableException;
 import org.springframework.web.bind.MissingServletRequestParameterException;
 import org.springframework.web.bind.ServletRequestBindingException;
 import org.springframework.web.bind.annotation.ControllerAdvice;
 import org.springframework.web.bind.annotation.ExceptionHandler;
 import org.springframework.web.context.request.ServletWebRequest;
 import org.springframework.web.context.request.WebRequest;
+import org.springframework.web.context.request.async.AsyncRequestTimeoutException;
 import org.springframework.web.context.support.StaticWebApplicationContext;
 import org.springframework.web.multipart.support.MissingServletRequestPartException;
 import org.springframework.web.servlet.NoHandlerFoundException;
@@ -68,14 +72,14 @@ public class ResponseEntityExceptionHandlerTests {
 
 	private WebRequest request;
 
-	private HttpServletRequest servletRequest;
+	private MockHttpServletRequest servletRequest;
 
 	private MockHttpServletResponse servletResponse;
 
 
 	@Before
 	public void setup() {
-		this.servletRequest = new MockHttpServletRequest();
+		this.servletRequest = new MockHttpServletRequest("GET", "/");
 		this.servletResponse = new MockHttpServletResponse();
 		this.request = new ServletWebRequest(this.servletRequest, this.servletResponse);
 
@@ -86,15 +90,16 @@ public class ResponseEntityExceptionHandlerTests {
 	@Test
 	public void supportsAllDefaultHandlerExceptionResolverExceptionTypes() throws Exception {
 
-		Method annotMethod = ResponseEntityExceptionHandler.class.getMethod("handleException", Exception.class, WebRequest.class);
-		ExceptionHandler annot = annotMethod.getAnnotation(ExceptionHandler.class);
-		List<Class<? extends Throwable>> supportedTypes = Arrays.asList(annot.value());
+		Class<ResponseEntityExceptionHandler> clazz = ResponseEntityExceptionHandler.class;
+		Method handleExceptionMethod = clazz.getMethod("handleException", Exception.class, WebRequest.class);
+		ExceptionHandler annotation = handleExceptionMethod.getAnnotation(ExceptionHandler.class);
+		List<Class<?>> exceptionTypes = Arrays.asList(annotation.value());
 
 		for (Method method : DefaultHandlerExceptionResolver.class.getDeclaredMethods()) {
 			Class<?>[] paramTypes = method.getParameterTypes();
 			if (method.getName().startsWith("handle") && (paramTypes.length == 4)) {
 				String name = paramTypes[0].getSimpleName();
-				assertTrue("@ExceptionHandler is missing " + name, supportedTypes.contains(paramTypes[0]));
+				assertTrue("@ExceptionHandler is missing " + name, exceptionTypes.contains(paramTypes[0]));
 			}
 		}
 	}
@@ -130,6 +135,14 @@ public class ResponseEntityExceptionHandlerTests {
 		testException(ex);
 	}
 
+	@Test
+	public void missingPathVariable() throws NoSuchMethodException {
+		Method method = getClass().getDeclaredMethod("handle", String.class);
+		MethodParameter parameter = new MethodParameter(method, 0);
+		Exception ex = new MissingPathVariableException("param", parameter);
+		testException(ex);
+	}
+
 	@Test
 	public void missingServletRequestParameter() {
 		Exception ex = new MissingServletRequestParameterException("param", "type");
@@ -168,7 +181,7 @@ public class ResponseEntityExceptionHandlerTests {
 
 	@Test
 	public void methodArgumentNotValid() {
-		Exception ex = new MethodArgumentNotValidException(null, null);
+		Exception ex = Mockito.mock(MethodArgumentNotValidException.class);
 		testException(ex);
 	}
 
@@ -193,6 +206,11 @@ public class ResponseEntityExceptionHandlerTests {
 		testException(ex);
 	}
 
+	@Test
+	public void asyncRequestTimeoutException() {
+		testException(new AsyncRequestTimeoutException());
+	}
+
 	@Test
 	public void controllerAdvice() throws Exception {
 		StaticWebApplicationContext cxt = new StaticWebApplicationContext();
@@ -241,8 +259,10 @@ public class ResponseEntityExceptionHandlerTests {
 			headers.set("someHeader", "someHeaderValue");
 			return handleExceptionInternal(ex, "error content", headers, status, request);
 		}
+	}
 
-
+	@SuppressWarnings("unused")
+	void handle(String arg) {
 	}
 
 }
