@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2012 the original author or authors.
+ * Copyright 2002-2017 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -33,7 +33,7 @@ import org.springframework.web.method.support.ModelAndViewContainer;
 import static org.junit.Assert.*;
 
 /**
- * Test fixture with {@link org.springframework.web.servlet.mvc.method.annotation.ServletRequestMethodArgumentResolver}.
+ * Test fixture with {@link ServletResponseMethodArgumentResolver}.
  *
  * @author Arjen Poutsma
  */
@@ -41,27 +41,29 @@ public class ServletResponseMethodArgumentResolverTests {
 
 	private ServletResponseMethodArgumentResolver resolver;
 
-	private Method method;
-
 	private ModelAndViewContainer mavContainer;
 
-	private ServletWebRequest webRequest;
-
 	private MockHttpServletResponse servletResponse;
 
+	private ServletWebRequest webRequest;
+
+	private Method method;
+
+
 	@Before
-	public void setUp() throws Exception {
+	public void setup() throws Exception {
 		resolver = new ServletResponseMethodArgumentResolver();
-		method = getClass().getMethod("supportedParams", ServletResponse.class, OutputStream.class, Writer.class);
-		servletResponse = new MockHttpServletResponse();
 		mavContainer = new ModelAndViewContainer();
+		servletResponse = new MockHttpServletResponse();
 		webRequest = new ServletWebRequest(new MockHttpServletRequest(), servletResponse);
+
+		method = getClass().getMethod("supportedParams", ServletResponse.class, OutputStream.class, Writer.class);
 	}
 
+
 	@Test
 	public void servletResponse() throws Exception {
 		MethodParameter servletResponseParameter = new MethodParameter(method, 0);
-
 		assertTrue("ServletResponse not supported", resolver.supportsParameter(servletResponseParameter));
 
 		Object result = resolver.resolveArgument(servletResponseParameter, mavContainer, webRequest, null);
@@ -69,8 +71,7 @@ public class ServletResponseMethodArgumentResolverTests {
 		assertTrue(mavContainer.isRequestHandled());
 	}
 
-	// SPR-8983
-
+	@Test  // SPR-8983
 	public void servletResponseNoMavContainer() throws Exception {
 		MethodParameter servletResponseParameter = new MethodParameter(method, 0);
 		assertTrue("ServletResponse not supported", resolver.supportsParameter(servletResponseParameter));
@@ -82,7 +83,6 @@ public class ServletResponseMethodArgumentResolverTests {
 	@Test
 	public void outputStream() throws Exception {
 		MethodParameter outputStreamParameter = new MethodParameter(method, 1);
-
 		assertTrue("OutputStream not supported", resolver.supportsParameter(outputStreamParameter));
 
 		Object result = resolver.resolveArgument(outputStreamParameter, mavContainer, webRequest, null);
@@ -93,7 +93,6 @@ public class ServletResponseMethodArgumentResolverTests {
 	@Test
 	public void writer() throws Exception {
 		MethodParameter writerParameter = new MethodParameter(method, 2);
-
 		assertTrue("Writer not supported", resolver.supportsParameter(writerParameter));
 
 		Object result = resolver.resolveArgument(writerParameter, mavContainer, webRequest, null);
@@ -101,7 +100,9 @@ public class ServletResponseMethodArgumentResolverTests {
 		assertTrue(mavContainer.isRequestHandled());
 	}
 
-	public void supportedParams(ServletResponse p0, OutputStream p1, Writer p2) {
 
+	@SuppressWarnings("unused")
+	public void supportedParams(ServletResponse p0, OutputStream p1, Writer p2) {
 	}
-}
\ No newline at end of file
+
+}
