@@ -16,6 +16,8 @@
 
 package org.springframework.web.servlet.mvc.multiaction;
 
+import org.junit.Test;
+
 import java.io.IOException;
 import java.sql.SQLException;
 import java.util.HashMap;
@@ -26,7 +28,7 @@ import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import javax.servlet.http.HttpSession;
 
-import junit.framework.TestCase;
+import static org.junit.Assert.*;
 
 import org.springframework.beans.FatalBeanException;
 import org.springframework.context.ApplicationContextException;
@@ -45,9 +47,10 @@ import org.springframework.web.servlet.ModelAndView;
  * @author Rob Harrop
  * @author Sam Brannen
  */
-public class MultiActionControllerTests extends TestCase {
+public class MultiActionControllerTests {
 
-	public void testDefaultInternalPathMethodNameResolver() throws Exception {
+	@Test
+	public void defaultInternalPathMethodNameResolver() throws Exception {
 		doDefaultTestInternalPathMethodNameResolver("/foo.html", "foo");
 		doDefaultTestInternalPathMethodNameResolver("/foo/bar.html", "bar");
 		doDefaultTestInternalPathMethodNameResolver("/bugal.xyz", "bugal");
@@ -62,7 +65,8 @@ public class MultiActionControllerTests extends TestCase {
 		assertEquals("Wrong method name resolved", expected, actual);
 	}
 
-	public void testCustomizedInternalPathMethodNameResolver() throws Exception {
+	@Test
+	public void customizedInternalPathMethodNameResolver() throws Exception {
 		doTestCustomizedInternalPathMethodNameResolver("/foo.html", "my", null, "myfoo");
 		doTestCustomizedInternalPathMethodNameResolver("/foo/bar.html", null, "Handler", "barHandler");
 		doTestCustomizedInternalPathMethodNameResolver("/Bugal.xyz", "your", "Method", "yourBugalMethod");
@@ -85,7 +89,8 @@ public class MultiActionControllerTests extends TestCase {
 		assertEquals("Wrong method name resolved", expected, actual);
 	}
 
-	public void testParameterMethodNameResolver() throws NoSuchRequestHandlingMethodException {
+	@Test
+	public void parameterMethodNameResolver() throws NoSuchRequestHandlingMethodException {
 		ParameterMethodNameResolver mnr = new ParameterMethodNameResolver();
 
 		MockHttpServletRequest request = new MockHttpServletRequest("GET", "/foo.html");
@@ -119,7 +124,8 @@ public class MultiActionControllerTests extends TestCase {
 		}
 	}
 
-	public void testParameterMethodNameResolverWithCustomParamName() throws NoSuchRequestHandlingMethodException {
+	@Test
+	public void parameterMethodNameResolverWithCustomParamName() throws NoSuchRequestHandlingMethodException {
 		ParameterMethodNameResolver mnr = new ParameterMethodNameResolver();
 		mnr.setParamName("myparam");
 		MockHttpServletRequest request = new MockHttpServletRequest("GET", "/foo.html");
@@ -127,7 +133,8 @@ public class MultiActionControllerTests extends TestCase {
 		assertEquals("bar", mnr.getHandlerMethodName(request));
 	}
 
-	public void testParameterMethodNameResolverWithParamNames() throws NoSuchRequestHandlingMethodException {
+	@Test
+	public void parameterMethodNameResolverWithParamNames() throws NoSuchRequestHandlingMethodException {
 		ParameterMethodNameResolver resolver = new ParameterMethodNameResolver();
 		resolver.setDefaultMethodName("default");
 		resolver.setMethodParamNames(new String[] { "hello", "spring", "colin" });
@@ -181,7 +188,8 @@ public class MultiActionControllerTests extends TestCase {
 		assertEquals("goodbye", resolver.getHandlerMethodName(request));
 	}
 
-	public void testParameterMethodNameResolverWithDefaultMethodName() throws NoSuchRequestHandlingMethodException {
+	@Test
+	public void parameterMethodNameResolverWithDefaultMethodName() throws NoSuchRequestHandlingMethodException {
 		ParameterMethodNameResolver mnr = new ParameterMethodNameResolver();
 		mnr.setDefaultMethodName("foo");
 		MockHttpServletRequest request = new MockHttpServletRequest("GET", "/foo.html");
@@ -191,7 +199,8 @@ public class MultiActionControllerTests extends TestCase {
 		assertEquals("foo", mnr.getHandlerMethodName(request));
 	}
 
-	public void testInvokesCorrectMethod() throws Exception {
+	@Test
+	public void invokesCorrectMethod() throws Exception {
 		TestMaController mc = new TestMaController();
 		HttpServletRequest request = new MockHttpServletRequest("GET", "/welcome.html");
 		HttpServletResponse response = new MockHttpServletResponse();
@@ -215,7 +224,8 @@ public class MultiActionControllerTests extends TestCase {
 		assertTrue("Only one method invoked", mc.getInvokedMethods() == 1);
 	}
 
-	public void testPathMatching() throws Exception {
+	@Test
+	public void pathMatching() throws Exception {
 		TestMaController mc = new TestMaController();
 		HttpServletRequest request = new MockHttpServletRequest("GET", "/welcome.html");
 		HttpServletResponse response = new MockHttpServletResponse();
@@ -243,7 +253,8 @@ public class MultiActionControllerTests extends TestCase {
 		assertTrue("No method invoked", mc.getInvokedMethods() == 0);
 	}
 
-	public void testInvokesCorrectMethodOnDelegate() throws Exception {
+	@Test
+	public void invokesCorrectMethodOnDelegate() throws Exception {
 		MultiActionController mac = new MultiActionController();
 		TestDelegate d = new TestDelegate();
 		mac.setDelegate(d);
@@ -254,7 +265,8 @@ public class MultiActionControllerTests extends TestCase {
 		assertTrue("Delegate was invoked", d.invoked);
 	}
 
-	public void testInvokesCorrectMethodWithSession() throws Exception {
+	@Test
+	public void invokesCorrectMethodWithSession() throws Exception {
 		TestMaController mc = new TestMaController();
 		MockHttpServletRequest request = new MockHttpServletRequest("GET", "/inSession.html");
 		request.setSession(new MockHttpSession(null));
@@ -275,7 +287,8 @@ public class MultiActionControllerTests extends TestCase {
 		}
 	}
 
-	public void testInvokesCommandMethodNoSession() throws Exception {
+	@Test
+	public void invokesCommandMethodNoSession() throws Exception {
 		TestMaController mc = new TestMaController();
 		MockHttpServletRequest request = new MockHttpServletRequest("GET", "/commandNoSession.html");
 		request.addParameter("name", "rod");
@@ -287,7 +300,8 @@ public class MultiActionControllerTests extends TestCase {
 		assertTrue("Only one method invoked", mc.getInvokedMethods() == 1);
 	}
 
-	public void testInvokesCommandMethodWithSession() throws Exception {
+	@Test
+	public void invokesCommandMethodWithSession() throws Exception {
 		TestMaController mc = new TestMaController();
 		MockHttpServletRequest request = new MockHttpServletRequest("GET", "/commandInSession.html");
 		request.addParameter("name", "rod");
@@ -311,7 +325,8 @@ public class MultiActionControllerTests extends TestCase {
 		}
 	}
 
-	public void testSessionRequiredCatchable() throws Exception {
+	@Test
+	public void sessionRequiredCatchable() throws Exception {
 		HttpServletRequest request = new MockHttpServletRequest("GET", "/testSession.html");
 		HttpServletResponse response = new MockHttpServletResponse();
 		TestMaController contr = new TestSessionRequiredController();
@@ -346,7 +361,8 @@ public class MultiActionControllerTests extends TestCase {
 		testExceptionNoHandler(new TestMaController(), t);
 	}
 
-	public void testExceptionNoHandler() throws Exception {
+	@Test
+	public void exceptionNoHandler() throws Exception {
 		testExceptionNoHandler(new Exception());
 
 		// must go straight through
@@ -358,14 +374,16 @@ public class MultiActionControllerTests extends TestCase {
 		testExceptionNoHandler(new Error());
 	}
 
-	public void testLastModifiedDefault() throws Exception {
+	@Test
+	public void lastModifiedDefault() throws Exception {
 		TestMaController mc = new TestMaController();
 		MockHttpServletRequest request = new MockHttpServletRequest("GET", "/welcome.html");
 		long lastMod = mc.getLastModified(request);
 		assertTrue("default last modified is -1", lastMod == -1L);
 	}
 
-	public void testLastModifiedWithMethod() throws Exception {
+	@Test
+	public void lastModifiedWithMethod() throws Exception {
 		LastModController mc = new LastModController();
 		MockHttpServletRequest request = new MockHttpServletRequest("GET", "/welcome.html");
 		long lastMod = mc.getLastModified(request);
@@ -379,7 +397,8 @@ public class MultiActionControllerTests extends TestCase {
 		return mc.handleRequest(request, response);
 	}
 
-	public void testHandlerCaughtException() throws Exception {
+	@Test
+	public void handlerCaughtException() throws Exception {
 		TestMaController mc = new TestExceptionHandler();
 		ModelAndView mv = testHandlerCaughtException(mc, new Exception());
 		assertNotNull("ModelAndView must not be null", mv);
@@ -416,7 +435,8 @@ public class MultiActionControllerTests extends TestCase {
 		testExceptionNoHandler(mc, new Exception());
 	}
 
-	public void testHandlerReturnsMap() throws Exception {
+	@Test
+	public void handlerReturnsMap() throws Exception {
 		Map model = new HashMap();
 		model.put("message", "Hello World!");
 
@@ -431,7 +451,8 @@ public class MultiActionControllerTests extends TestCase {
 		assertEquals(model, mav.getModel());
 	}
 
-	public void testExceptionHandlerReturnsMap() throws Exception {
+	@Test
+	public void exceptionHandlerReturnsMap() throws Exception {
 		Map model = new HashMap();
 
 		MultiActionController mac = new ModelOnlyMultiActionController(model);
@@ -445,7 +466,8 @@ public class MultiActionControllerTests extends TestCase {
 		assertTrue(model.containsKey("exception"));
 	}
 
-	public void testCannotCallExceptionHandlerDirectly() throws Exception {
+	@Test
+	public void cannotCallExceptionHandlerDirectly() throws Exception {
 		Map model = new HashMap();
 
 		MultiActionController mac = new ModelOnlyMultiActionController(model);
@@ -456,7 +478,8 @@ public class MultiActionControllerTests extends TestCase {
 		assertEquals(HttpServletResponse.SC_NOT_FOUND, response.getStatus());
 	}
 
-	public void testHandlerReturnsVoid() throws Exception {
+	@Test
+	public void handlerReturnsVoid() throws Exception {
 		MultiActionController mac = new VoidMultiActionController();
 
 		MockHttpServletRequest request = new MockHttpServletRequest("GET", "/welcome.html");
@@ -466,7 +489,8 @@ public class MultiActionControllerTests extends TestCase {
 		assertNull("ModelAndView must be null", mav);
 	}
 
-	public void testExceptionHandlerReturnsVoid() throws Exception {
+	@Test
+	public void exceptionHandlerReturnsVoid() throws Exception {
 		MultiActionController mac = new VoidMultiActionController();
 
 		MockHttpServletRequest request = new MockHttpServletRequest("GET", "/index.html");
@@ -477,7 +501,8 @@ public class MultiActionControllerTests extends TestCase {
 		assertEquals("exception", response.getContentAsString());
 	}
 
-	public void testHandlerReturnsString() throws Exception {
+	@Test
+	public void handlerReturnsString() throws Exception {
 		MultiActionController mac = new StringMultiActionController();
 
 		MockHttpServletRequest request = new MockHttpServletRequest("GET", "/welcome.html");
@@ -489,7 +514,8 @@ public class MultiActionControllerTests extends TestCase {
 		assertEquals("Verifying view name", "welcomeString", mav.getViewName());
 	}
 
-	public void testExceptionHandlerReturnsString() throws Exception {
+	@Test
+	public void exceptionHandlerReturnsString() throws Exception {
 		MultiActionController mac = new StringMultiActionController();
 
 		MockHttpServletRequest request = new MockHttpServletRequest("GET", "/index.html");
