@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2013 the original author or authors.
+ * Copyright 2002-2016 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,6 +16,7 @@
 
 package org.springframework.web.servlet.mvc.support;
 
+import java.lang.reflect.Method;
 import java.util.Collections;
 
 import org.junit.Before;
@@ -36,8 +37,10 @@ import org.springframework.validation.BindException;
 import org.springframework.web.HttpMediaTypeNotSupportedException;
 import org.springframework.web.HttpRequestMethodNotSupportedException;
 import org.springframework.web.bind.MethodArgumentNotValidException;
+import org.springframework.web.bind.MissingPathVariableException;
 import org.springframework.web.bind.MissingServletRequestParameterException;
 import org.springframework.web.bind.ServletRequestBindingException;
+import org.springframework.web.context.request.async.AsyncRequestTimeoutException;
 import org.springframework.web.multipart.support.MissingServletRequestPartException;
 import org.springframework.web.servlet.ModelAndView;
 import org.springframework.web.servlet.NoHandlerFoundException;
@@ -45,7 +48,9 @@ import org.springframework.web.servlet.mvc.multiaction.NoSuchRequestHandlingMeth
 
 import static org.junit.Assert.*;
 
-/** @author Arjen Poutsma */
+/**
+ * @author Arjen Poutsma
+ */
 public class DefaultHandlerExceptionResolverTests {
 
 	private DefaultHandlerExceptionResolver exceptionResolver;
@@ -57,6 +62,7 @@ public class DefaultHandlerExceptionResolverTests {
 	@Before
 	public void setUp() {
 		exceptionResolver = new DefaultHandlerExceptionResolver();
+		exceptionResolver.setWarnLogCategory(exceptionResolver.getClass().getName());
 		request = new MockHttpServletRequest();
 		response = new MockHttpServletResponse();
 		request.setMethod("GET");
@@ -93,6 +99,19 @@ public class DefaultHandlerExceptionResolverTests {
 		assertEquals("Invalid Accept header", "application/pdf", response.getHeader("Accept"));
 	}
 
+	@Test
+	public void handleMissingPathVariable() throws NoSuchMethodException {
+		Method method = getClass().getMethod("handle", String.class);
+		MethodParameter parameter = new MethodParameter(method, 0);
+		MissingPathVariableException ex = new MissingPathVariableException("foo", parameter);
+		ModelAndView mav = exceptionResolver.resolveException(request, response, null, ex);
+		assertNotNull("No ModelAndView returned", mav);
+		assertTrue("No Empty ModelAndView returned", mav.isEmpty());
+		assertEquals("Invalid status code", 500, response.getStatus());
+		assertEquals("Missing URI template variable 'foo' for method parameter of type String",
+				response.getErrorMessage());
+	}
+
 	@Test
 	public void handleMissingServletRequestParameter() {
 		MissingServletRequestParameterException ex = new MissingServletRequestParameterException("foo", "bar");
@@ -159,7 +178,9 @@ public class DefaultHandlerExceptionResolverTests {
 		assertNotNull("No ModelAndView returned", mav);
 		assertTrue("No Empty ModelAndView returned", mav.isEmpty());
 		assertEquals("Invalid status code", 400, response.getStatus());
-		assertEquals("Required request part 'name' is not present.", response.getErrorMessage());
+		assertTrue(response.getErrorMessage().contains("request part"));
+		assertTrue(response.getErrorMessage().contains("name"));
+		assertTrue(response.getErrorMessage().contains("not present"));
 	}
 
 	@Test
@@ -196,6 +217,17 @@ public class DefaultHandlerExceptionResolverTests {
 		assertSame(ex, request.getAttribute("javax.servlet.error.exception"));
 	}
 
+	@Test // SPR-14669
+	public void handleAsyncRequestTimeoutException() throws Exception {
+		Exception ex = new AsyncRequestTimeoutException();
+		ModelAndView mav = exceptionResolver.resolveException(request, response, null, ex);
+		assertNotNull("No ModelAndView returned", mav);
+		assertTrue("No Empty ModelAndView returned", mav.isEmpty());
+		assertEquals("Invalid status code", 503, response.getStatus());
+	}
+
+
+	@SuppressWarnings("unused")
 	public void handle(String arg) {
 	}
 
