@@ -21,6 +21,7 @@ import static org.junit.Assert.*;
 import java.net.URLEncoder;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collections;
 import java.util.List;
 import java.util.concurrent.CopyOnWriteArrayList;
 
@@ -318,6 +319,25 @@ public class FlashMapManagerTests {
 		assertEquals("value", flashMap.get("key"));
 	}
 
+	@Test // SPR-15505
+	public void retrieveAndUpdateMatchByOriginatingPathAndQueryString() {
+		FlashMap flashMap = new FlashMap();
+		flashMap.put("key", "value");
+		flashMap.setTargetRequestPath("/accounts");
+		flashMap.addTargetRequestParam("a", "b");
+
+		this.flashMapManager.setFlashMaps(Collections.singletonList(flashMap));
+
+		this.request.setAttribute(WebUtils.FORWARD_REQUEST_URI_ATTRIBUTE, "/accounts");
+		this.request.setAttribute(WebUtils.FORWARD_QUERY_STRING_ATTRIBUTE, "a=b");
+		this.request.setRequestURI("/mvc/accounts");
+		this.request.setQueryString("x=y");
+		FlashMap inputFlashMap = this.flashMapManager.retrieveAndUpdate(this.request, this.response);
+
+		assertEquals(flashMap, inputFlashMap);
+		assertEquals("Input FlashMap should have been removed", 0, this.flashMapManager.getFlashMaps().size());
+	}
+
 
 	private static class TestFlashMapManager extends AbstractFlashMapManager {
 
