@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2013 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -21,31 +21,35 @@ import javax.servlet.jsp.PageContext;
 import javax.servlet.jsp.tagext.Tag;
 import javax.servlet.jsp.tagext.TagSupport;
 
+import org.junit.Before;
+import org.junit.Test;
+
 import org.springframework.mock.web.test.MockBodyContent;
 import org.springframework.mock.web.test.MockHttpServletResponse;
 
+import static org.junit.Assert.*;
+
 /**
- * Unit tests for {@link ParamTag}
+ * Unit tests for {@link ParamTag}.
  *
  * @author Scott Andrews
  * @author Nicholas Williams
  */
 public class ParamTagTests extends AbstractTagTests {
 
-	private ParamTag tag;
+	private final ParamTag tag = new ParamTag();
 
-	private MockParamSupportTag parent;
+	private MockParamSupportTag parent = new MockParamSupportTag();
 
-	@Override
-	protected void setUp() throws Exception {
+	@Before
+	public void setUp() throws Exception {
 		PageContext context = createPageContext();
-		parent = new MockParamSupportTag();
-		tag = new ParamTag();
 		tag.setPageContext(context);
 		tag.setParent(parent);
 	}
 
-	public void testParamWithNameAndValue() throws JspException {
+	@Test
+	public void paramWithNameAndValue() throws JspException {
 		tag.setName("name");
 		tag.setValue("value");
 
@@ -56,10 +60,10 @@ public class ParamTagTests extends AbstractTagTests {
 		assertEquals("value", parent.getParam().getValue());
 	}
 
-	public void testParamWithBodyValue() throws JspException {
+	@Test
+	public void paramWithBodyValue() throws JspException {
 		tag.setName("name");
-		tag.setBodyContent(new MockBodyContent("value",
-				new MockHttpServletResponse()));
+		tag.setBodyContent(new MockBodyContent("value", new MockHttpServletResponse()));
 
 		int action = tag.doEndTag();
 
@@ -68,7 +72,8 @@ public class ParamTagTests extends AbstractTagTests {
 		assertEquals("value", parent.getParam().getValue());
 	}
 
-	public void testParamWithImplicitNullValue() throws JspException {
+	@Test
+	public void paramWithImplicitNullValue() throws JspException {
 		tag.setName("name");
 
 		int action = tag.doEndTag();
@@ -78,7 +83,8 @@ public class ParamTagTests extends AbstractTagTests {
 		assertNull(parent.getParam().getValue());
 	}
 
-	public void testParamWithExplicitNullValue() throws JspException {
+	@Test
+	public void paramWithExplicitNullValue() throws JspException {
 		tag.setName("name");
 		tag.setValue(null);
 
@@ -89,7 +95,8 @@ public class ParamTagTests extends AbstractTagTests {
 		assertNull(parent.getParam().getValue());
 	}
 
-	public void testParamWithValueThenReleaseThenBodyValue() throws JspException {
+	@Test
+	public void paramWithValueThenReleaseThenBodyValue() throws JspException {
 		tag.setName("name1");
 		tag.setValue("value1");
 
@@ -105,8 +112,7 @@ public class ParamTagTests extends AbstractTagTests {
 		tag.setPageContext(createPageContext());
 		tag.setParent(parent);
 		tag.setName("name2");
-		tag.setBodyContent(new MockBodyContent("value2",
-				new MockHttpServletResponse()));
+		tag.setBodyContent(new MockBodyContent("value2", new MockHttpServletResponse()));
 
 		action = tag.doEndTag();
 
@@ -115,19 +121,12 @@ public class ParamTagTests extends AbstractTagTests {
 		assertEquals("value2", parent.getParam().getValue());
 	}
 
-	public void testParamWithNoParent() {
+	@Test(expected = JspException.class)
+	public void paramWithNoParent() throws Exception {
 		tag.setName("name");
 		tag.setValue("value");
-
 		tag.setParent(null);
-
-		try {
-			tag.doEndTag();
-			fail("expected JspException");
-		}
-		catch (JspException e) {
-			// we want this
-		}
+		tag.doEndTag();
 	}
 
 	@SuppressWarnings("serial")
