@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2013 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,10 +17,15 @@
 package org.springframework.web.servlet.tags.form;
 
 import java.io.Writer;
+
 import javax.servlet.jsp.tagext.Tag;
 
+import org.junit.Test;
+
 import org.springframework.tests.sample.beans.TestBean;
 
+import static org.junit.Assert.*;
+
 /**
  * @author Rossen Stoyanchev
  */
@@ -38,7 +43,8 @@ public class ButtonTagTests extends AbstractFormTagTests {
 		this.tag.setValue("My Button");
 	}
 
-	public void testButtonTag() throws Exception {
+	@Test
+	public void buttonTag() throws Exception {
 		assertEquals(Tag.EVAL_BODY_INCLUDE, this.tag.doStartTag());
 		assertEquals(Tag.EVAL_PAGE, this.tag.doEndTag());
 
@@ -53,7 +59,8 @@ public class ButtonTagTests extends AbstractFormTagTests {
 		assertAttributeNotPresent(output, "disabled");
 	}
 
-	public void testDisabled() throws Exception {
+	@Test
+	public void disabled() throws Exception {
 		this.tag.setDisabled(true);
 
 		this.tag.doStartTag();
