@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2013 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -20,12 +20,16 @@ import java.io.Writer;
 import javax.servlet.jsp.JspException;
 import javax.servlet.jsp.tagext.Tag;
 
+import org.junit.Test;
+
 import org.springframework.tests.sample.beans.TestBean;
 import org.springframework.validation.BeanPropertyBindingResult;
 import org.springframework.web.servlet.support.BindStatus;
 import org.springframework.web.servlet.tags.BindTag;
 import org.springframework.web.servlet.tags.NestedPathTag;
 
+import static org.junit.Assert.*;
+
 /**
  * @author Rob Harrop
  * @author Rick Evans
@@ -64,7 +68,8 @@ public class InputTagTests extends AbstractFormTagTests {
 	}
 
 
-	public void testSimpleBind() throws Exception {
+	@Test
+	public void simpleBind() throws Exception {
 		this.tag.setPath("name");
 
 		assertEquals(Tag.SKIP_BODY, this.tag.doStartTag());
@@ -77,7 +82,8 @@ public class InputTagTests extends AbstractFormTagTests {
 		assertValueAttribute(output, "Rob");
 	}
 
-	public void testSimpleBindTagWithinForm() throws Exception {
+	@Test
+	public void simpleBindTagWithinForm() throws Exception {
 		BindTag bindTag = new BindTag();
 		bindTag.setPath("name");
 		bindTag.setPageContext(getPageContext());
@@ -87,7 +93,8 @@ public class InputTagTests extends AbstractFormTagTests {
 		assertEquals("Rob", bindStatus.getValue());
 	}
 
-	public void testSimpleBindWithHtmlEscaping() throws Exception {
+	@Test
+	public void simpleBindWithHtmlEscaping() throws Exception {
 		final String NAME = "Rob \"I Love Mangos\" Harrop";
 		final String HTML_ESCAPED_NAME = "Rob &quot;I Love Mangos&quot; Harrop";
 
@@ -108,7 +115,8 @@ public class InputTagTests extends AbstractFormTagTests {
 		assertContainsAttribute(output, "value", expectedValue);
 	}
 
-	public void testComplexBind() throws Exception {
+	@Test
+	public void complexBind() throws Exception {
 		this.tag.setPath("spouse.name");
 
 		assertEquals(Tag.SKIP_BODY, this.tag.doStartTag());
@@ -123,7 +131,8 @@ public class InputTagTests extends AbstractFormTagTests {
 		assertValueAttribute(output, "Sally");
 	}
 
-	public void testWithAllAttributes() throws Exception {
+	@Test
+	public void withAllAttributes() throws Exception {
 		String title = "aTitle";
 		String id = "123";
 		String size = "12";
@@ -228,7 +237,8 @@ public class InputTagTests extends AbstractFormTagTests {
 		assertContainsAttribute(output, dynamicAttribute2, dynamicAttribute2);
 	}
 
-	public void testWithNestedBind() throws Exception {
+	@Test
+	public void withNestedBind() throws Exception {
 		NestedPathTag nestedPathTag = new NestedPathTag();
 		nestedPathTag.setPath("spouse.");
 		nestedPathTag.setPageContext(getPageContext());
@@ -246,7 +256,8 @@ public class InputTagTests extends AbstractFormTagTests {
 		assertValueAttribute(output, "Sally");
 	}
 
-	public void testWithNestedBindTagWithinForm() throws Exception {
+	@Test
+	public void withNestedBindTagWithinForm() throws Exception {
 		NestedPathTag nestedPathTag = new NestedPathTag();
 		nestedPathTag.setPath("spouse.");
 		nestedPathTag.setPageContext(getPageContext());
@@ -261,7 +272,8 @@ public class InputTagTests extends AbstractFormTagTests {
 		assertEquals("Sally", bindStatus.getValue());
 	}
 
-	public void testWithErrors() throws Exception {
+	@Test
+	public void withErrors() throws Exception {
 		this.tag.setPath("name");
 		this.tag.setCssClass("good");
 		this.tag.setCssErrorClass("bad");
@@ -282,7 +294,8 @@ public class InputTagTests extends AbstractFormTagTests {
 		assertContainsAttribute(output, "class", "bad");
 	}
 
-	public void testDisabledFalse() throws Exception {
+	@Test
+	public void disabledFalse() throws Exception {
 		this.tag.setPath("name");
 		this.tag.setDisabled(false);
 		this.tag.doStartTag();
@@ -291,7 +304,8 @@ public class InputTagTests extends AbstractFormTagTests {
 		assertAttributeNotPresent(output, "disabled");
 	}
 
-	public void testWithCustomBinder() throws Exception {
+	@Test
+	public void withCustomBinder() throws Exception {
 		this.tag.setPath("myFloat");
 
 		BeanPropertyBindingResult errors = new BeanPropertyBindingResult(this.rob, COMMAND_NAME);
@@ -311,7 +325,8 @@ public class InputTagTests extends AbstractFormTagTests {
 	/**
 	 * See SPR-3127 (http://opensource.atlassian.com/projects/spring/browse/SPR-3127)
 	 */
-	public void testReadOnlyAttributeRenderingWhenReadonlyIsTrue() throws Exception {
+	@Test
+	public void readOnlyAttributeRenderingWhenReadonlyIsTrue() throws Exception {
 		this.tag.setPath("name");
 		this.tag.setReadonly(true);
 
@@ -326,7 +341,8 @@ public class InputTagTests extends AbstractFormTagTests {
 		assertValueAttribute(output, "Rob");
 	}
 
-	public void testDynamicTypeAttribute() throws JspException {
+	@Test
+	public void dynamicTypeAttribute() throws JspException {
 		this.tag.setPath("myFloat");
 		this.tag.setDynamicAttribute(null, "type", "number");
 
@@ -340,7 +356,8 @@ public class InputTagTests extends AbstractFormTagTests {
 		assertValueAttribute(output, "12.34");
 	}
 
-	public void testDynamicTypeRadioAttribute() throws JspException {
+	@Test
+	public void dynamicTypeRadioAttribute() throws JspException {
 		try {
 			this.tag.setDynamicAttribute(null, "type", "radio");
 			fail("Expected exception");
@@ -350,7 +367,8 @@ public class InputTagTests extends AbstractFormTagTests {
 		}
 	}
 
-	public void testDynamicTypeCheckboxAttribute() throws JspException {
+	@Test
+	public void dynamicTypeCheckboxAttribute() throws JspException {
 		try {
 			this.tag.setDynamicAttribute(null, "type", "checkbox");
 			fail("Expected exception");
