@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2012 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -20,6 +20,10 @@ import java.io.Writer;
 import javax.servlet.jsp.JspException;
 import javax.servlet.jsp.tagext.Tag;
 
+import org.junit.Test;
+
+import static org.junit.Assert.*;
+
 /**
  * @author Rob Harrop
  * @author Rick Evans
@@ -27,10 +31,11 @@ import javax.servlet.jsp.tagext.Tag;
  */
 public class PasswordInputTagTests extends InputTagTests {
 
-	/*
-	 * http://opensource.atlassian.com/projects/spring/browse/SPR-2866
+	/**
+	 * https://jira.spring.io/browse/SPR-2866
 	 */
-	public void testPasswordValueIsNotRenderedByDefault() throws Exception {
+	@Test
+	public void passwordValueIsNotRenderedByDefault() throws Exception {
 		this.getTag().setPath("name");
 
 		assertEquals(Tag.SKIP_BODY, this.getTag().doStartTag());
@@ -43,10 +48,11 @@ public class PasswordInputTagTests extends InputTagTests {
 		assertValueAttribute(output, "");
 	}
 
-	/*
-	 * http://opensource.atlassian.com/projects/spring/browse/SPR-2866
+	/**
+	 * https://jira.spring.io/browse/SPR-2866
 	 */
-	public void testPasswordValueIsRenderedIfShowPasswordAttributeIsSetToTrue() throws Exception {
+	@Test
+	public void passwordValueIsRenderedIfShowPasswordAttributeIsSetToTrue() throws Exception {
 		this.getTag().setPath("name");
 		this.getPasswordTag().setShowPassword(true);
 
@@ -60,10 +66,11 @@ public class PasswordInputTagTests extends InputTagTests {
 		assertValueAttribute(output, "Rob");
 	}
 
-	/*
-	 * http://opensource.atlassian.com/projects/spring/browse/SPR-2866
+	/**
+	 * https://jira.spring.io/browse/SPR-2866
 	 */
-	public void testPasswordValueIsNotRenderedIfShowPasswordAttributeIsSetToFalse() throws Exception {
+	@Test
+	public void passwordValueIsNotRenderedIfShowPasswordAttributeIsSetToFalse() throws Exception {
 		this.getTag().setPath("name");
 		this.getPasswordTag().setShowPassword(false);
 
@@ -77,8 +84,9 @@ public class PasswordInputTagTests extends InputTagTests {
 		assertValueAttribute(output, "");
 	}
 
+	@Test
 	@Override
-	public void testDynamicTypeAttribute() throws JspException {
+	public void dynamicTypeAttribute() throws JspException {
 		try {
 			this.getTag().setDynamicAttribute(null, "type", "email");
 			fail("Expected exception");
@@ -92,7 +100,8 @@ public class PasswordInputTagTests extends InputTagTests {
 	protected void assertValueAttribute(String output, String expectedValue) {
 		if (this.getPasswordTag().isShowPassword()) {
 			super.assertValueAttribute(output, expectedValue);
-		} else {
+		}
+		else {
 			super.assertValueAttribute(output, "");
 		}
 	}
@@ -116,4 +125,5 @@ public class PasswordInputTagTests extends InputTagTests {
 	private PasswordInputTag getPasswordTag() {
 		return (PasswordInputTag) this.getTag();
 	}
+
 }
