@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2013 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -26,11 +26,15 @@ import org.dom4j.Document;
 import org.dom4j.Element;
 import org.dom4j.io.SAXReader;
 
+import org.junit.Test;
+
 import org.springframework.tests.sample.beans.Pet;
 import org.springframework.tests.sample.beans.TestBean;
 import org.springframework.validation.BeanPropertyBindingResult;
 import org.springframework.validation.BindingResult;
 
+import static org.junit.Assert.*;
+
 /**
  * @author Rob Harrop
  * @author Juergen Hoeller
@@ -54,7 +58,8 @@ public class RadioButtonTagTests extends AbstractFormTagTests {
 		this.tag.setPageContext(getPageContext());
 	}
 
-	public void testWithCheckedValue() throws Exception {
+	@Test
+	public void withCheckedValue() throws Exception {
 		String dynamicAttribute1 = "attr1";
 		String dynamicAttribute2 = "attr2";
 
@@ -77,7 +82,8 @@ public class RadioButtonTagTests extends AbstractFormTagTests {
 		assertContainsAttribute(output, dynamicAttribute2, dynamicAttribute2);
 	}
 
-	public void testWithCheckedValueAndDynamicAttributes() throws Exception {
+	@Test
+	public void withCheckedValueAndDynamicAttributes() throws Exception {
 		this.tag.setPath("sex");
 		this.tag.setValue("M");
 		int result = this.tag.doStartTag();
@@ -92,7 +98,8 @@ public class RadioButtonTagTests extends AbstractFormTagTests {
 		assertContainsAttribute(output, "checked", "checked");
 	}
 
-	public void testWithCheckedObjectValue() throws Exception {
+	@Test
+	public void withCheckedObjectValue() throws Exception {
 		this.tag.setPath("myFloat");
 		this.tag.setValue(getFloat());
 		int result = this.tag.doStartTag();
@@ -107,7 +114,8 @@ public class RadioButtonTagTests extends AbstractFormTagTests {
 		assertContainsAttribute(output, "checked", "checked");
 	}
 
-	public void testWithCheckedObjectValueAndEditor() throws Exception {
+	@Test
+	public void withCheckedObjectValueAndEditor() throws Exception {
 		this.tag.setPath("myFloat");
 		this.tag.setValue("F12.99");
 
@@ -128,7 +136,8 @@ public class RadioButtonTagTests extends AbstractFormTagTests {
 		assertContainsAttribute(output, "checked", "checked");
 	}
 
-	public void testWithUncheckedObjectValue() throws Exception {
+	@Test
+	public void withUncheckedObjectValue() throws Exception {
 		Float value = new Float("99.45");
 		this.tag.setPath("myFloat");
 		this.tag.setValue(value);
@@ -144,7 +153,8 @@ public class RadioButtonTagTests extends AbstractFormTagTests {
 		assertAttributeNotPresent(output, "checked");
 	}
 
-	public void testWithUncheckedValue() throws Exception {
+	@Test
+	public void withUncheckedValue() throws Exception {
 		this.tag.setPath("sex");
 		this.tag.setValue("F");
 		int result = this.tag.doStartTag();
@@ -159,7 +169,8 @@ public class RadioButtonTagTests extends AbstractFormTagTests {
 		assertAttributeNotPresent(output, "checked");
 	}
 
-	public void testCollectionOfPets() throws Exception {
+	@Test
+	public void collectionOfPets() throws Exception {
 		this.tag.setPath("pets");
 		this.tag.setValue(new Pet("Rudiger"));
 
@@ -181,7 +192,8 @@ public class RadioButtonTagTests extends AbstractFormTagTests {
 		assertEquals("checked", checkboxElement.attribute("checked").getValue());
 	}
 
-	public void testCollectionOfPetsNotSelected() throws Exception {
+	@Test
+	public void collectionOfPetsNotSelected() throws Exception {
 		this.tag.setPath("pets");
 		this.tag.setValue(new Pet("Santa's Little Helper"));
 
@@ -203,7 +215,8 @@ public class RadioButtonTagTests extends AbstractFormTagTests {
 		assertNull(checkboxElement.attribute("checked"));
 	}
 
-	public void testCollectionOfPetsWithEditor() throws Exception {
+	@Test
+	public void collectionOfPetsWithEditor() throws Exception {
 		this.tag.setPath("pets");
 		this.tag.setValue(new ItemPet("Rudiger"));
 
@@ -230,7 +243,8 @@ public class RadioButtonTagTests extends AbstractFormTagTests {
 		assertEquals("checked", checkboxElement.attribute("checked").getValue());
 	}
 
-	public void testDynamicTypeAttribute() throws JspException {
+	@Test
+	public void dynamicTypeAttribute() throws JspException {
 		try {
 			this.tag.setDynamicAttribute(null, "type", "email");
 			fail("Expected exception");
