@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2013 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -18,15 +18,14 @@ package org.springframework.web.servlet.view;
 
 import java.io.IOException;
 import java.util.HashMap;
-import java.util.Iterator;
 import java.util.Map;
 import java.util.Properties;
-import java.util.Set;
+
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
-import junit.framework.TestCase;
+import org.junit.Test;
 
 import org.springframework.context.ApplicationContextException;
 import org.springframework.mock.web.test.MockHttpServletRequest;
@@ -35,17 +34,22 @@ import org.springframework.mock.web.test.MockServletContext;
 import org.springframework.web.context.WebApplicationContext;
 import org.springframework.web.servlet.View;
 
+import static org.junit.Assert.*;
 import static org.mockito.BDDMockito.*;
 
 /**
- * Tests for AbstractView. Not called AbstractViewTests as
- * would otherwise be excluded by Ant build script wildcard.
+ * Base tests for {@link AbstractView}.
+ *
+ * <p>Not called {@code AbstractViewTests} since doing so would cause it
+ * to be ignored in the Gradle build.
  *
  * @author Rod Johnson
+ * @author Sam Brannen
  */
-public class BaseViewTests extends TestCase {
+public class BaseViewTests {
 
-	public void testRenderWithoutStaticAttributes() throws Exception {
+	@Test
+	public void renderWithoutStaticAttributes() throws Exception {
 		WebApplicationContext wac = mock(WebApplicationContext.class);
 		given(wac.getServletContext()).willReturn(new MockServletContext());
 
@@ -62,16 +66,16 @@ public class BaseViewTests extends TestCase {
 		model.put("something", new Object());
 		tv.render(model, request, response);
 
-		// check it contains all
 		checkContainsAll(model, tv.model);
 
-		assertTrue(tv.inited);
+		assertTrue(tv.initialized);
 	}
 
 	/**
 	 * Test attribute passing, NOT CSV parsing.
 	 */
-	public void testRenderWithStaticAttributesNoCollision() throws Exception {
+	@Test
+	public void renderWithStaticAttributesNoCollision() throws Exception {
 		WebApplicationContext wac = mock(WebApplicationContext.class);
 		given(wac.getServletContext()).willReturn(new MockServletContext());
 
@@ -90,14 +94,14 @@ public class BaseViewTests extends TestCase {
 		model.put("two", new Object());
 		tv.render(model, request, response);
 
-		// Check it contains all
 		checkContainsAll(model, tv.model);
 		checkContainsAll(p, tv.model);
 
-		assertTrue(tv.inited);
+		assertTrue(tv.initialized);
 	}
 
-	public void testPathVarsOverrideStaticAttributes() throws Exception {
+	@Test
+	public void pathVarsOverrideStaticAttributes() throws Exception {
 		WebApplicationContext wac = mock(WebApplicationContext.class);
 		given(wac.getServletContext()).willReturn(new MockServletContext());
 
@@ -119,16 +123,15 @@ public class BaseViewTests extends TestCase {
 
 		tv.render(new HashMap<String, Object>(), request, response);
 
-		// Check it contains all
 		checkContainsAll(pathVars, tv.model);
-		assertTrue(tv.model.size() == 3);
-		// will have old something from properties
-		assertTrue(tv.model.get("something").equals("else"));
 
-		assertTrue(tv.inited);
+		assertEquals(3, tv.model.size());
+		assertEquals("else", tv.model.get("something"));
+		assertTrue(tv.initialized);
 	}
 
-	public void testDynamicModelOverridesStaticAttributesIfCollision() throws Exception {
+	@Test
+	public void dynamicModelOverridesStaticAttributesIfCollision() throws Exception {
 		WebApplicationContext wac = mock(WebApplicationContext.class);
 		given(wac.getServletContext()).willReturn(new MockServletContext());
 
@@ -149,14 +152,14 @@ public class BaseViewTests extends TestCase {
 
 		// Check it contains all
 		checkContainsAll(model, tv.model);
-		assertTrue(tv.model.size() == 3);
-		// will have old something from properties
-		assertTrue(tv.model.get("something").equals("else"));
 
-		assertTrue(tv.inited);
+		assertEquals(3, tv.model.size());
+		assertEquals("else", tv.model.get("something"));
+		assertTrue(tv.initialized);
 	}
 
-	public void testDynamicModelOverridesPathVariables() throws Exception {
+	@Test
+	public void dynamicModelOverridesPathVariables() throws Exception {
 		WebApplicationContext wac = mock(WebApplicationContext.class);
 		given(wac.getServletContext()).willReturn(new MockServletContext());
 
@@ -177,40 +180,41 @@ public class BaseViewTests extends TestCase {
 
 		tv.render(model, request, response);
 
-		// Check it contains all
 		checkContainsAll(model, tv.model);
 		assertEquals(3, tv.model.size());
-		// will have old something from path variables
-		assertTrue(tv.model.get("something").equals("else"));
-
-		assertTrue(tv.inited);
+		assertEquals("else", tv.model.get("something"));
+		assertTrue(tv.initialized);
 	}
 
-	public void testIgnoresNullAttributes() {
+	@Test
+	public void ignoresNullAttributes() {
 		AbstractView v = new ConcreteView();
 		v.setAttributes(null);
-		assertTrue(v.getStaticAttributes().size() == 0);
+		assertEquals(0, v.getStaticAttributes().size());
 	}
 
 	/**
 	 * Test only the CSV parsing implementation.
 	 */
-	public void testAttributeCSVParsingIgnoresNull() {
+	@Test
+	public void attributeCSVParsingIgnoresNull() {
 		AbstractView v = new ConcreteView();
 		v.setAttributesCSV(null);
-		assertTrue(v.getStaticAttributes().size() == 0);
+		assertEquals(0, v.getStaticAttributes().size());
 	}
 
-	public void testAttributeCSVParsingIgnoresEmptyString() {
+	@Test
+	public void attributeCSVParsingIgnoresEmptyString() {
 		AbstractView v = new ConcreteView();
 		v.setAttributesCSV("");
-		assertTrue(v.getStaticAttributes().size() == 0);
+		assertEquals(0, v.getStaticAttributes().size());
 	}
 
 	/**
 	 * Format is attname0={value1},attname1={value1}
 	 */
-	public void testAttributeCSVParsingValid() {
+	@Test
+	public void attributeCSVParsingValid() {
 		AbstractView v = new ConcreteView();
 		v.setAttributesCSV("foo=[bar],king=[kong]");
 		assertTrue(v.getStaticAttributes().size() == 2);
@@ -218,7 +222,8 @@ public class BaseViewTests extends TestCase {
 		assertTrue(v.getStaticAttributes().get("king").equals("kong"));
 	}
 
-	public void testAttributeCSVParsingValidWithWeirdCharacters() {
+	@Test
+	public void attributeCSVParsingValidWithWeirdCharacters() {
 		AbstractView v = new ConcreteView();
 		String fooval = "owfie   fue&3[][[[2 \n\n \r  \t 8\ufffd3";
 		// Also tests empty value
@@ -229,7 +234,8 @@ public class BaseViewTests extends TestCase {
 		assertTrue(v.getStaticAttributes().get("king").equals(kingval));
 	}
 
-	public void testAttributeCSVParsingInvalid() {
+	@Test
+	public void attributeCSVParsingInvalid() {
 		AbstractView v = new ConcreteView();
 		try {
 			// No equals
@@ -263,32 +269,29 @@ public class BaseViewTests extends TestCase {
 		}
 	}
 
-	public void testAttributeCSVParsingIgoresTrailingComma() {
+	@Test
+	public void attributeCSVParsingIgoresTrailingComma() {
 		AbstractView v = new ConcreteView();
 		v.setAttributesCSV("foo=[de],");
-		assertTrue(v.getStaticAttributes().size() == 1);
+		assertEquals(1, v.getStaticAttributes().size());
 	}
 
 	/**
-	 * Check that all keys in expected have same values in actual
-	 * @param expected
-	 * @param actual
+	 * Check that all keys in expected have same values in actual.
 	 */
 	@SuppressWarnings({ "rawtypes", "unchecked" })
 	private void checkContainsAll(Map expected, Map<String, Object> actual) {
-		Set<String> keys = expected.keySet();
-		for (Iterator<String> iter = keys.iterator(); iter.hasNext();) {
-			String key = iter.next();
-			//System.out.println("Checking model key " + key);
-			assertTrue("Value for model key '" + key + "' must match", actual.get(key) == expected.get(key));
-		}
+		expected.keySet().stream().forEach(
+			key -> assertEquals("Values for model key '" + key + "' must match", expected.get(key), actual.get(key))
+		);
 	}
 
+
 	/**
 	 * Trivial concrete subclass we can use when we're interested only
 	 * in CSV parsing, which doesn't require lifecycle management
 	 */
-	private class ConcreteView extends AbstractView {
+	private static class ConcreteView extends AbstractView {
 		// Do-nothing concrete subclass
 		@Override
 		protected void renderMergedOutputModel(Map<String, Object> model, HttpServletRequest request, HttpServletResponse response)
@@ -297,38 +300,40 @@ public class BaseViewTests extends TestCase {
 		}
 	}
 
+
 	/**
-	 * Single threaded subclass of AbstractView to check superclass
-	 * behaviour
+	 * Single threaded subclass of AbstractView to check superclass behavior.
 	 */
-	private class TestView extends AbstractView {
-		private WebApplicationContext wac;
-		public boolean inited;
+	private static class TestView extends AbstractView {
+
+		private final WebApplicationContext wac;
+
+		boolean initialized;
 
 		/** Captured model in render */
-		public Map<String, Object> model;
+		Map<String, Object> model;
 
-		public TestView(WebApplicationContext wac) {
+		TestView(WebApplicationContext wac) {
 			this.wac = wac;
-
 		}
+
 		@Override
-		protected void renderMergedOutputModel(Map<String, Object> model, HttpServletRequest request, HttpServletResponse response)
-			throws ServletException, IOException {
-				// do nothing
-				this.model = model;
-			}
+		protected void renderMergedOutputModel(Map<String, Object> model, HttpServletRequest request,
+				HttpServletResponse response) throws ServletException, IOException {
+			this.model = model;
+		}
+
 		/**
 		 * @see org.springframework.context.support.ApplicationObjectSupport#initApplicationContext()
 		 */
 		@Override
 		protected void initApplicationContext() throws ApplicationContextException {
-			if (inited)
+			if (initialized) {
 				throw new RuntimeException("Already initialized");
-			this.inited = true;
+			}
+			this.initialized = true;
 			assertTrue(getApplicationContext() == wac);
 		}
-
 	}
 
 }
