@@ -18,7 +18,6 @@ package org.springframework.web.socket;
 
 import java.io.File;
 import java.io.IOException;
-
 import javax.servlet.Filter;
 import javax.servlet.ServletContext;
 
@@ -82,15 +81,10 @@ public class TomcatWebSocketTestServer implements WebSocketTestServer {
 			return tempFolder;
 		}
 		catch (IOException ex) {
-			throw new RuntimeException("Unable to create temp directory", ex);
+			throw new IllegalStateException("Unable to create temp directory", ex);
 		}
 	}
 
-	@Override
-	public int getPort() {
-		return this.port;
-	}
-
 	@Override
 	public void deployConfig(WebApplicationContext wac, Filter... filters) {
 		Assert.state(this.port != -1, "setup() was never called.");
@@ -112,11 +106,6 @@ public class TomcatWebSocketTestServer implements WebSocketTestServer {
 		}
 	}
 
-	@Override
-	public ServletContext getServletContext() {
-		return this.context.getServletContext();
-	}
-
 	@Override
 	public void undeployConfig() {
 		if (this.context != null) {
@@ -143,4 +132,14 @@ public class TomcatWebSocketTestServer implements WebSocketTestServer {
 		this.tomcatServer.stop();
 	}
 
+	@Override
+	public int getPort() {
+		return this.port;
+	}
+
+	@Override
+	public ServletContext getServletContext() {
+		return this.context.getServletContext();
+	}
+
 }
