@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2014 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,24 +16,22 @@
 
 package org.springframework.context.annotation.ltw;
 
-import org.springframework.test.jpa.AbstractJpaTests;
-
 /**
- * Test to ensure that component scanning work with load-time weaver.
+ * Test to ensure that component scanning works with load-time weaver.
  * See SPR-3873 for more details.
  *
  * @author Ramnivas Laddad
  */
 @SuppressWarnings("deprecation")
-public class ComponentScanningWithLTWTests extends AbstractJpaTests {
+public class ComponentScanningWithLTWTests extends org.springframework.test.jpa.AbstractJpaTests {
 
-	public ComponentScanningWithLTWTests() {
+	{
 		setDependencyCheck(false);
 	}
 
 	@Override
-	protected String getConfigPath() {
-		return "ComponentScanningWithLTWTests.xml";
+	protected String[] getConfigPaths() {
+		return new String[] { "ComponentScanningWithLTWTests.xml" };
 	}
 
 	public void testLoading() {
